# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Province.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.geo import USState_pb2 as opencannabis_dot_geo_dot_USState__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Province.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/geo/Province.proto\x12\x10opencannabis.geo\x1a\x1eopencannabis/geo/USState.proto\"V\n\x08Province\x12.\n\x05state\x18\x01 \x01(\x0e\x32\x1d.opencannabis.geo.usa.USStateH\x00\x12\x12\n\x08province\x18\x02 \x01(\tH\x00\x42\x06\n\x04specB&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_geo_dot_USState__pb2.DESCRIPTOR,])




_PROVINCE = _descriptor.Descriptor(
  name='Province',
  full_name='opencannabis.geo.Province',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='opencannabis.geo.Province.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='province', full_name='opencannabis.geo.Province.province', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.geo.Province.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=85,
  serialized_end=171,
)

_PROVINCE.fields_by_name['state'].enum_type = opencannabis_dot_geo_dot_USState__pb2._USSTATE
_PROVINCE.oneofs_by_name['spec'].fields.append(
  _PROVINCE.fields_by_name['state'])
_PROVINCE.fields_by_name['state'].containing_oneof = _PROVINCE.oneofs_by_name['spec']
_PROVINCE.oneofs_by_name['spec'].fields.append(
  _PROVINCE.fields_by_name['province'])
_PROVINCE.fields_by_name['province'].containing_oneof = _PROVINCE.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Province'] = _PROVINCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Province = _reflection.GeneratedProtocolMessageType('Province', (_message.Message,), {
  'DESCRIPTOR' : _PROVINCE,
  '__module__' : 'opencannabis.geo.Province_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Province)
  })
_sym_db.RegisterMessage(Province)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
