# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Preroll.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Preroll.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\016PrerollProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/products/Preroll.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\xa7\x03\n\x07Preroll\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x33\n\x06\x66lower\x18\x02 \x01(\x0b\x32#.opencannabis.base.ProductReference\x12\x0e\n\x06length\x18\x03 \x01(\x01\x12\x11\n\tthickness\x18\x04 \x01(\x01\x12\x32\n\x05\x66lags\x18\x05 \x03(\x0e\x32#.opencannabis.products.Preroll.Flag\x12\x35\n\x07product\x18\x06 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x07 \x01(\x0b\x32#.opencannabis.content.MaterialsData\"v\n\x04\x46lag\x12\x14\n\x10NO_PREROLL_FLAGS\x10\x00\x12\x10\n\x0cHASH_INFUSED\x10\x01\x12\x10\n\x0cKIEF_INFUSED\x10\x02\x12\r\n\tFORTIFIED\x10\x03\x12\x0f\n\x0b\x46ULL_FLOWER\x10\x04\x12\x14\n\x10\x43ONTAINS_TOBACCO\x10\x05\x42:\n\x1eio.opencannabis.schema.productB\x0ePrerollProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_PREROLL_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.Preroll.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_PREROLL_FLAGS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HASH_INFUSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KIEF_INFUSED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORTIFIED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL_FLOWER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINS_TOBACCO', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=489,
  serialized_end=607,
)
_sym_db.RegisterEnumDescriptor(_PREROLL_FLAG)


_PREROLL = _descriptor.Descriptor(
  name='Preroll',
  full_name='opencannabis.products.Preroll',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Preroll.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flower', full_name='opencannabis.products.Preroll.flower', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='opencannabis.products.Preroll.length', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='thickness', full_name='opencannabis.products.Preroll.thickness', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.Preroll.flags', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Preroll.product', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Preroll.material', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PREROLL_FLAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=607,
)

_PREROLL.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_PREROLL.fields_by_name['flower'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_PREROLL.fields_by_name['flags'].enum_type = _PREROLL_FLAG
_PREROLL.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_PREROLL.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_PREROLL_FLAG.containing_type = _PREROLL
DESCRIPTOR.message_types_by_name['Preroll'] = _PREROLL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Preroll = _reflection.GeneratedProtocolMessageType('Preroll', (_message.Message,), {
  'DESCRIPTOR' : _PREROLL,
  '__module__' : 'opencannabis.products.Preroll_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Preroll)
  })
_sym_db.RegisterMessage(Preroll)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
