# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Flower.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Flower.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\rFlowerProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/products/Flower.proto\x12\x15opencannabis.products\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\xae\x04\n\x06\x46lower\x12Y\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB-\xc2\xb5\x03)\x12\'Key that uniquely identifies a product.\x12t\n\x07product\x18\x02 \x01(\x0b\x32$.opencannabis.content.ProductContentB=\xc2\xb5\x03\x39\x12\x37Specifies product-level information or collateral data.\x12\x81\x01\n\x08material\x18\x03 \x01(\x0b\x32#.opencannabis.content.MaterialsDataBJ\xc2\xb5\x03\x46\x12\x44Specifies information about the material that constitutes a product.\x12\x8c\x01\n\x04type\x18\x04 \x01(\x0e\x32\".opencannabis.products.Flower.TypeBZ\xc2\xb5\x03V\x12TSpecifies the specialized type of flower (TRIMMED, SHAKE, SMALL_NUGS, PREMIUM_NUGS).\"@\n\x04Type\x12\x0b\n\x07TRIMMED\x10\x00\x12\t\n\x05SHAKE\x10\x01\x12\x0e\n\nSMALL_NUGS\x10\x02\x12\x10\n\x0cPREMIUM_NUGS\x10\x03\x42\x39\n\x1eio.opencannabis.schema.productB\rFlowerProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_FLOWER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Flower.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TRIMMED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHAKE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SMALL_NUGS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREMIUM_NUGS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=704,
  serialized_end=768,
)
_sym_db.RegisterEnumDescriptor(_FLOWER_TYPE)


_FLOWER = _descriptor.Descriptor(
  name='Flower',
  full_name='opencannabis.products.Flower',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Flower.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003)\022\'Key that uniquely identifies a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Flower.product', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039\0227Specifies product-level information or collateral data.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Flower.material', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003F\022DSpecifies information about the material that constitutes a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Flower.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003V\022TSpecifies the specialized type of flower (TRIMMED, SHAKE, SMALL_NUGS, PREMIUM_NUGS).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FLOWER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=210,
  serialized_end=768,
)

_FLOWER.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_FLOWER.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_FLOWER.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_FLOWER.fields_by_name['type'].enum_type = _FLOWER_TYPE
_FLOWER_TYPE.containing_type = _FLOWER
DESCRIPTOR.message_types_by_name['Flower'] = _FLOWER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Flower = _reflection.GeneratedProtocolMessageType('Flower', (_message.Message,), {
  'DESCRIPTOR' : _FLOWER,
  '__module__' : 'opencannabis.products.Flower_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Flower)
  })
_sym_db.RegisterMessage(Flower)


DESCRIPTOR._options = None
_FLOWER.fields_by_name['key']._options = None
_FLOWER.fields_by_name['product']._options = None
_FLOWER.fields_by_name['material']._options = None
_FLOWER.fields_by_name['type']._options = None
# @@protoc_insertion_point(module_scope)
