# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.proximity`
  ---------------------------
  Objects and protocol definitions for Bluetooth Low Energy (BLE) proximity.

"""

# `opencannabis.proximity`
