# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/ProductKind.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/ProductKind.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\017BaseProductKindH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/base/ProductKind.proto\x12\x11opencannabis.base*\x80\x01\n\x0bProductKind\x12\x0b\n\x07\x46LOWERS\x10\x00\x12\x0b\n\x07\x45\x44IBLES\x10\x01\x12\x0c\n\x08\x45XTRACTS\x10\x02\x12\x0c\n\x08PREROLLS\x10\x03\x12\x0e\n\nAPOTHECARY\x10\x04\x12\x0e\n\nCARTRIDGES\x10\x05\x12\n\n\x06PLANTS\x10\x06\x12\x0f\n\x0bMERCHANDISE\x10\x07\x42\x38\n\x1bio.opencannabis.schema.baseB\x0f\x42\x61seProductKindH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_PRODUCTKIND = _descriptor.EnumDescriptor(
  name='ProductKind',
  full_name='opencannabis.base.ProductKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLOWERS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EDIBLES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTRACTS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREROLLS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APOTHECARY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARTRIDGES', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLANTS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MERCHANDISE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=59,
  serialized_end=187,
)
_sym_db.RegisterEnumDescriptor(_PRODUCTKIND)

ProductKind = enum_type_wrapper.EnumTypeWrapper(_PRODUCTKIND)
FLOWERS = 0
EDIBLES = 1
EXTRACTS = 2
PREROLLS = 3
APOTHECARY = 4
CARTRIDGES = 5
PLANTS = 6
MERCHANDISE = 7


DESCRIPTOR.enum_types_by_name['ProductKind'] = _PRODUCTKIND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
