# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Genetics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Genetics.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\017GeneticsStructsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/structs/Genetics.proto\x12\x14opencannabis.structs\x1a\"opencannabis/base/ProductKey.proto\"r\n\x08Genetics\x12\x31\n\x04male\x18\x01 \x01(\x0b\x32#.opencannabis.base.ProductReference\x12\x33\n\x06\x66\x65male\x18\x02 \x01(\x0b\x32#.opencannabis.base.ProductReferenceBB\n%io.opencannabis.schema.product.structB\x0fGeneticsStructsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,])




_GENETICS = _descriptor.Descriptor(
  name='Genetics',
  full_name='opencannabis.structs.Genetics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='male', full_name='opencannabis.structs.Genetics.male', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='female', full_name='opencannabis.structs.Genetics.female', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=211,
)

_GENETICS.fields_by_name['male'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_GENETICS.fields_by_name['female'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
DESCRIPTOR.message_types_by_name['Genetics'] = _GENETICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Genetics = _reflection.GeneratedProtocolMessageType('Genetics', (_message.Message,), {
  'DESCRIPTOR' : _GENETICS,
  '__module__' : 'opencannabis.structs.Genetics_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.Genetics)
  })
_sym_db.RegisterMessage(Genetics)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
