# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Data.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/content/Data.proto\x12\x14opencannabis.content*\xa8\x01\n\nDataFormat\x12\x12\n\x0eUNKNOWN_FORMAT\x10\x00\x12\x07\n\x03\x43SV\x10\n\x12\x07\n\x03TSV\x10\x0b\x12\r\n\tEXCEL_CSV\x10\x0c\x12\r\n\tEXCEL_XLS\x10\r\x12\x0e\n\nEXCEL_XLSX\x10\x0e\x12\x0b\n\x07MSGPACK\x10\x14\x12\x08\n\x04\x41VRO\x10\x1e\x12\x07\n\x03SQL\x10(\x12\x08\n\x04JSON\x10\x32\x12\x0c\n\x08OCP_TEXT\x10=\x12\x0e\n\nOCP_BINARY\x10>B*\n\x1eio.opencannabis.schema.contentH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_DATAFORMAT = _descriptor.EnumDescriptor(
  name='DataFormat',
  full_name='opencannabis.content.DataFormat',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_FORMAT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CSV', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TSV', index=2, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCEL_CSV', index=3, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCEL_XLS', index=4, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCEL_XLSX', index=5, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MSGPACK', index=6, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AVRO', index=7, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQL', index=8, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JSON', index=9, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OCP_TEXT', index=10, number=61,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OCP_BINARY', index=11, number=62,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=58,
  serialized_end=226,
)
_sym_db.RegisterEnumDescriptor(_DATAFORMAT)

DataFormat = enum_type_wrapper.EnumTypeWrapper(_DATAFORMAT)
UNKNOWN_FORMAT = 0
CSV = 10
TSV = 11
EXCEL_CSV = 12
EXCEL_XLS = 13
EXCEL_XLSX = 14
MSGPACK = 20
AVRO = 30
SQL = 40
JSON = 50
OCP_TEXT = 61
OCP_BINARY = 62


DESCRIPTOR.enum_types_by_name['DataFormat'] = _DATAFORMAT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
