# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.contact`
  ---------------------------
  Contact information models, including email addresses/phone numbers, etc.

"""

# `opencannabis.contact`
