# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Date.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Date.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\014TemporalDateH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/temporal/Date.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"`\n\x04\x44\x61te\x12P\n\x07iso8601\x18\x01 \x01(\tB=\xc2\xb5\x03\x39\x12\x37ISO8601-formatted calendar date value, like YYYY-MM-DD.H\x00\x42\x06\n\x04specB9\n\x1fio.opencannabis.schema.temporalB\x0cTemporalDateH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_DATE = _descriptor.Descriptor(
  name='Date',
  full_name='opencannabis.temporal.Date',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iso8601', full_name='opencannabis.temporal.Date.iso8601', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039\0227ISO8601-formatted calendar date value, like YYYY-MM-DD.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.temporal.Date.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86,
  serialized_end=182,
)

_DATE.oneofs_by_name['spec'].fields.append(
  _DATE.fields_by_name['iso8601'])
_DATE.fields_by_name['iso8601'].containing_oneof = _DATE.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Date'] = _DATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Date = _reflection.GeneratedProtocolMessageType('Date', (_message.Message,), {
  'DESCRIPTOR' : _DATE,
  '__module__' : 'opencannabis.temporal.Date_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Date)
  })
_sym_db.RegisterMessage(Date)


DESCRIPTOR._options = None
_DATE.fields_by_name['iso8601']._options = None
# @@protoc_insertion_point(module_scope)
