# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.products.menu`
  -------------------------------------
  Objects that gather products into menu structures.

"""

# `opencannabis.products.menu`
