# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/Compression.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/Compression.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\017BaseCompressionH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/base/Compression.proto\x12\x11opencannabis.base\"\x8f\x01\n\x0b\x43ompression\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.opencannabis.base.Compression.Type\"<\n\x04Type\x12\x12\n\x0eNO_COMPRESSION\x10\x00\x12\x08\n\x04GZIP\x10\x01\x12\n\n\x06\x42ROTLI\x10\x02\x12\n\n\x06SNAPPY\x10\x03\x42\x38\n\x1bio.opencannabis.schema.baseB\x0f\x42\x61seCompressionH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)



_COMPRESSION_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.base.Compression.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_COMPRESSION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GZIP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROTLI', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPPY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=142,
  serialized_end=202,
)
_sym_db.RegisterEnumDescriptor(_COMPRESSION_TYPE)


_COMPRESSION = _descriptor.Descriptor(
  name='Compression',
  full_name='opencannabis.base.Compression',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='opencannabis.base.Compression.enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.base.Compression.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPRESSION_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=202,
)

_COMPRESSION.fields_by_name['type'].enum_type = _COMPRESSION_TYPE
_COMPRESSION_TYPE.containing_type = _COMPRESSION
DESCRIPTOR.message_types_by_name['Compression'] = _COMPRESSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Compression = _reflection.GeneratedProtocolMessageType('Compression', (_message.Message,), {
  'DESCRIPTOR' : _COMPRESSION,
  '__module__' : 'opencannabis.base.Compression_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.base.Compression)
  })
_sym_db.RegisterMessage(Compression)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
