# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/ProductContent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.content import Content_pb2 as opencannabis_dot_content_dot_Content__pb2
from opencannabis.content import Brand_pb2 as opencannabis_dot_content_dot_Brand__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2
from opencannabis.structs import ProductFlags_pb2 as opencannabis_dot_structs_dot_ProductFlags__pb2
from opencannabis.structs.labtesting import TestResults_pb2 as opencannabis_dot_structs_dot_labtesting_dot_TestResults__pb2
from opencannabis.structs.pricing import PricingDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/ProductContent.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\017AttachedContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)opencannabis/content/ProductContent.proto\x12\x14opencannabis.content\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/content/Name.proto\x1a\"opencannabis/content/Content.proto\x1a opencannabis/content/Brand.proto\x1a#opencannabis/temporal/Instant.proto\x1a!opencannabis/media/MediaKey.proto\x1a\'opencannabis/structs/ProductFlags.proto\x1a\x31opencannabis/structs/labtesting/TestResults.proto\x1a\x34opencannabis/structs/pricing/PricingDescriptor.proto\"\xa9\x01\n\x11ProductTimestamps\x12/\n\x07\x63reated\x18\x01 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x30\n\x08modified\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x31\n\tpublished\x18\x03 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\"\x98\x04\n\x0eProductContent\x12(\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.Name\x12*\n\x05\x62rand\x18\x02 \x01(\x0b\x32\x1b.opencannabis.content.Brand\x12.\n\x07summary\x18\x03 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12,\n\x05usage\x18\x04 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12-\n\x06\x64osage\x18\x05 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12@\n\x05media\x18\x06 \x03(\x0b\x32\".opencannabis.media.MediaReferenceB\r\xd2\xb5\x03\t\x08\x01\x1a\x05media\x12=\n\x07pricing\x18\x07 \x01(\x0b\x32,.opencannabis.structs.pricing.ProductPricing\x12;\n\x05tests\x18\x08 \x01(\x0b\x32,.opencannabis.structs.labtesting.TestResults\x12\x30\n\x05\x66lags\x18\t \x03(\x0e\x32!.opencannabis.structs.ProductFlag\x12\x33\n\x02ts\x18\n \x01(\x0b\x32\'.opencannabis.content.ProductTimestampsB;\n\x1eio.opencannabis.schema.contentB\x0f\x41ttachedContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Content__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Brand__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_ProductFlags__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_labtesting_dot_TestResults__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2.DESCRIPTOR,])




_PRODUCTTIMESTAMPS = _descriptor.Descriptor(
  name='ProductTimestamps',
  full_name='opencannabis.content.ProductTimestamps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.content.ProductTimestamps.created', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='opencannabis.content.ProductTimestamps.modified', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published', full_name='opencannabis.content.ProductTimestamps.published', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=416,
  serialized_end=585,
)


_PRODUCTCONTENT = _descriptor.Descriptor(
  name='ProductContent',
  full_name='opencannabis.content.ProductContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.content.ProductContent.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brand', full_name='opencannabis.content.ProductContent.brand', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='opencannabis.content.ProductContent.summary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usage', full_name='opencannabis.content.ProductContent.usage', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dosage', full_name='opencannabis.content.ProductContent.dosage', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.content.ProductContent.media', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\322\265\003\t\010\001\032\005media', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pricing', full_name='opencannabis.content.ProductContent.pricing', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tests', full_name='opencannabis.content.ProductContent.tests', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.content.ProductContent.flags', index=8,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ts', full_name='opencannabis.content.ProductContent.ts', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=1124,
)

_PRODUCTTIMESTAMPS.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_PRODUCTTIMESTAMPS.fields_by_name['modified'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_PRODUCTTIMESTAMPS.fields_by_name['published'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_PRODUCTCONTENT.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_PRODUCTCONTENT.fields_by_name['brand'].message_type = opencannabis_dot_content_dot_Brand__pb2._BRAND
_PRODUCTCONTENT.fields_by_name['summary'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_PRODUCTCONTENT.fields_by_name['usage'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_PRODUCTCONTENT.fields_by_name['dosage'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_PRODUCTCONTENT.fields_by_name['media'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_PRODUCTCONTENT.fields_by_name['pricing'].message_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRODUCTPRICING
_PRODUCTCONTENT.fields_by_name['tests'].message_type = opencannabis_dot_structs_dot_labtesting_dot_TestResults__pb2._TESTRESULTS
_PRODUCTCONTENT.fields_by_name['flags'].enum_type = opencannabis_dot_structs_dot_ProductFlags__pb2._PRODUCTFLAG
_PRODUCTCONTENT.fields_by_name['ts'].message_type = _PRODUCTTIMESTAMPS
DESCRIPTOR.message_types_by_name['ProductTimestamps'] = _PRODUCTTIMESTAMPS
DESCRIPTOR.message_types_by_name['ProductContent'] = _PRODUCTCONTENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProductTimestamps = _reflection.GeneratedProtocolMessageType('ProductTimestamps', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTTIMESTAMPS,
  '__module__' : 'opencannabis.content.ProductContent_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.ProductTimestamps)
  })
_sym_db.RegisterMessage(ProductTimestamps)

ProductContent = _reflection.GeneratedProtocolMessageType('ProductContent', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTCONTENT,
  '__module__' : 'opencannabis.content.ProductContent_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.ProductContent)
  })
_sym_db.RegisterMessage(ProductContent)


DESCRIPTOR._options = None
_PRODUCTCONTENT.fields_by_name['media']._options = None
# @@protoc_insertion_point(module_scope)
