# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Extract.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Extract.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\016ExtractProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/products/Extract.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"\x80\x04\n\x07\x45xtract\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x31\n\x04type\x18\x02 \x01(\x0e\x32#.opencannabis.products.Extract.Type\x12\x31\n\x04\x66lag\x18\x03 \x03(\x0e\x32#.opencannabis.products.Extract.Flag\x12\x33\n\x06\x66lower\x18\x04 \x01(\x0b\x32#.opencannabis.base.ProductReference\x12\x35\n\x07product\x18\x05 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x06 \x01(\x0b\x32#.opencannabis.content.MaterialsData\"-\n\x04\x46lag\x12\x14\n\x10NO_EXTRACT_FLAGS\x10\x00\x12\x0f\n\x0bSOLVENTLESS\x10\x01\"\x90\x01\n\x04Type\x12\x17\n\x13UNSPECIFIED_EXTRACT\x10\x00\x12\x07\n\x03OIL\x10\x01\x12\x07\n\x03WAX\x10\x02\x12\x0b\n\x07SHATTER\x10\x03\x12\x08\n\x04KIEF\x10\x04\x12\x08\n\x04HASH\x10\x05\x12\x0e\n\nLIVE_RESIN\x10\x06\x12\t\n\x05ROSIN\x10\x07\x12\x0b\n\x07\x43RUMBLE\x10\x08\x12\t\n\x05SAUCE\x10\t\x12\t\n\x05SUGAR\x10\nB:\n\x1eio.opencannabis.schema.productB\x0e\x45xtractProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_EXTRACT_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.Extract.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_EXTRACT_FLAGS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOLVENTLESS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=504,
  serialized_end=549,
)
_sym_db.RegisterEnumDescriptor(_EXTRACT_FLAG)

_EXTRACT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Extract.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_EXTRACT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OIL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAX', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHATTER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KIEF', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HASH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIVE_RESIN', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROSIN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CRUMBLE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SAUCE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUGAR', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=552,
  serialized_end=696,
)
_sym_db.RegisterEnumDescriptor(_EXTRACT_TYPE)


_EXTRACT = _descriptor.Descriptor(
  name='Extract',
  full_name='opencannabis.products.Extract',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Extract.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Extract.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flag', full_name='opencannabis.products.Extract.flag', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flower', full_name='opencannabis.products.Extract.flower', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Extract.product', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Extract.material', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EXTRACT_FLAG,
    _EXTRACT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=184,
  serialized_end=696,
)

_EXTRACT.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_EXTRACT.fields_by_name['type'].enum_type = _EXTRACT_TYPE
_EXTRACT.fields_by_name['flag'].enum_type = _EXTRACT_FLAG
_EXTRACT.fields_by_name['flower'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTREFERENCE
_EXTRACT.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_EXTRACT.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_EXTRACT_FLAG.containing_type = _EXTRACT
_EXTRACT_TYPE.containing_type = _EXTRACT
DESCRIPTOR.message_types_by_name['Extract'] = _EXTRACT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Extract = _reflection.GeneratedProtocolMessageType('Extract', (_message.Message,), {
  'DESCRIPTOR' : _EXTRACT,
  '__module__' : 'opencannabis.products.Extract_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Extract)
  })
_sym_db.RegisterMessage(Extract)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
