# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/SKU.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.commerce import Item_pb2 as opencannabis_dot_commerce_dot_Item__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/SKU.proto',
  package='opencannabis.products.sku',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.skuH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/products/SKU.proto\x12\x19opencannabis.products.sku\x1a\x19gust/core/datamodel.proto\x1a opencannabis/commerce/Item.proto\"\x9c\x03\n\tMappedSKU\x12\x31\n\x03sku\x18\x01 \x01(\tB$\xc2\xb5\x03\x02\x08\x02\xc2\xb5\x03\x1a\x12\x18SKU value for this item.\x12\x35\n\x07\x66oreign\x18\x02 \x01(\tB$\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x1a\x12\x18SKU value for this item.\x12`\n\x04type\x18\x03 \x01(\x0e\x32\".opencannabis.products.sku.SKUTypeB.\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03$\x12\"Type of SKU this value represents.\x12\x65\n\x06system\x18\x04 \x01(\tBU\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03K\x12IIntegrating system, from which we are referencing a record with this SKU.\x12\x0e\n\x04unit\x18\n \x01(\x08H\x00\x12\x35\n\x07variant\x18\x0b \x01(\x0b\x32\".opencannabis.commerce.VariantSpecH\x00:\x0b\x8a\xf7\x02\x07\x08\x02\x12\x03skuB\x08\n\x06target* \n\x07SKUType\x12\x08\n\x04ITEM\x10\x00\x12\x0b\n\x07PRODUCT\x10\x01\x42&\n\x1aio.opencannabis.schema.skuH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Item__pb2.DESCRIPTOR,])

_SKUTYPE = _descriptor.EnumDescriptor(
  name='SKUType',
  full_name='opencannabis.products.sku.SKUType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ITEM', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRODUCT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=538,
  serialized_end=570,
)
_sym_db.RegisterEnumDescriptor(_SKUTYPE)

SKUType = enum_type_wrapper.EnumTypeWrapper(_SKUTYPE)
ITEM = 0
PRODUCT = 1



_MAPPEDSKU = _descriptor.Descriptor(
  name='MappedSKU',
  full_name='opencannabis.products.sku.MappedSKU',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sku', full_name='opencannabis.products.sku.MappedSKU.sku', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\302\265\003\032\022\030SKU value for this item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foreign', full_name='opencannabis.products.sku.MappedSKU.foreign', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003\032\022\030SKU value for this item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.sku.MappedSKU.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003$\022\"Type of SKU this value represents.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='system', full_name='opencannabis.products.sku.MappedSKU.system', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003K\022IIntegrating system, from which we are referencing a record with this SKU.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.products.sku.MappedSKU.unit', index=4,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.products.sku.MappedSKU.variant', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\007\010\002\022\003sku',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='opencannabis.products.sku.MappedSKU.target',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=124,
  serialized_end=536,
)

_MAPPEDSKU.fields_by_name['type'].enum_type = _SKUTYPE
_MAPPEDSKU.fields_by_name['variant'].message_type = opencannabis_dot_commerce_dot_Item__pb2._VARIANTSPEC
_MAPPEDSKU.oneofs_by_name['target'].fields.append(
  _MAPPEDSKU.fields_by_name['unit'])
_MAPPEDSKU.fields_by_name['unit'].containing_oneof = _MAPPEDSKU.oneofs_by_name['target']
_MAPPEDSKU.oneofs_by_name['target'].fields.append(
  _MAPPEDSKU.fields_by_name['variant'])
_MAPPEDSKU.fields_by_name['variant'].containing_oneof = _MAPPEDSKU.oneofs_by_name['target']
DESCRIPTOR.message_types_by_name['MappedSKU'] = _MAPPEDSKU
DESCRIPTOR.enum_types_by_name['SKUType'] = _SKUTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MappedSKU = _reflection.GeneratedProtocolMessageType('MappedSKU', (_message.Message,), {
  'DESCRIPTOR' : _MAPPEDSKU,
  '__module__' : 'opencannabis.products.SKU_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.sku.MappedSKU)
  })
_sym_db.RegisterMessage(MappedSKU)


DESCRIPTOR._options = None
_MAPPEDSKU.fields_by_name['sku']._options = None
_MAPPEDSKU.fields_by_name['foreign']._options = None
_MAPPEDSKU.fields_by_name['type']._options = None
_MAPPEDSKU.fields_by_name['system']._options = None
_MAPPEDSKU._options = None
# @@protoc_insertion_point(module_scope)
