# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Timehash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Timehash.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Timehash.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"T\n\x08Timehash\x12H\n\tcomponent\x18\x01 \x03(\tB5\xc2\xb5\x03\x31\x12/Entire string, and substrings, of the timehash.B+\n\x1fio.opencannabis.schema.temporalH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_TIMEHASH = _descriptor.Descriptor(
  name='Timehash',
  full_name='opencannabis.temporal.Timehash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='opencannabis.temporal.Timehash.component', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Entire string, and substrings, of the timehash.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=174,
)

DESCRIPTOR.message_types_by_name['Timehash'] = _TIMEHASH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Timehash = _reflection.GeneratedProtocolMessageType('Timehash', (_message.Message,), {
  'DESCRIPTOR' : _TIMEHASH,
  '__module__' : 'opencannabis.temporal.Timehash_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Timehash)
  })
_sym_db.RegisterMessage(Timehash)


DESCRIPTOR._options = None
_TIMEHASH.fields_by_name['component']._options = None
# @@protoc_insertion_point(module_scope)
