# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Customer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.person import Person_pb2 as opencannabis_dot_person_dot_Person__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Customer.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\rOrderCustomerH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/commerce/Customer.proto\x12\x15opencannabis.commerce\x1a\x19gust/core/datamodel.proto\x1a opencannabis/person/Person.proto\"\xe3\x01\n\x08\x43ustomer\x12Z\n\x06person\x18\x01 \x01(\x0b\x32\x1b.opencannabis.person.PersonB-\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03#\x12!Person attached to this customer.\x12\x41\n\nforeign_id\x18\x02 \x01(\tB-\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03#\x12!Partner-scoped foreign system ID.\x12\x38\n\x08user_key\x18\x03 \x01(\tB&\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x1c\x12\x1aResolved subject user key.B:\n\x1fio.opencannabis.schema.commerceB\rOrderCustomerH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_person_dot_Person__pb2.DESCRIPTOR,])




_CUSTOMER = _descriptor.Descriptor(
  name='Customer',
  full_name='opencannabis.commerce.Customer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='person', full_name='opencannabis.commerce.Customer.person', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003#\022!Person attached to this customer.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='foreign_id', full_name='opencannabis.commerce.Customer.foreign_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003#\022!Partner-scoped foreign system ID.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_key', full_name='opencannabis.commerce.Customer.user_key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003\034\022\032Resolved subject user key.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=352,
)

_CUSTOMER.fields_by_name['person'].message_type = opencannabis_dot_person_dot_Person__pb2._PERSON
DESCRIPTOR.message_types_by_name['Customer'] = _CUSTOMER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Customer = _reflection.GeneratedProtocolMessageType('Customer', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMER,
  '__module__' : 'opencannabis.commerce.Customer_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Customer)
  })
_sym_db.RegisterMessage(Customer)


DESCRIPTOR._options = None
_CUSTOMER.fields_by_name['person']._options = None
_CUSTOMER.fields_by_name['foreign_id']._options = None
_CUSTOMER.fields_by_name['user_key']._options = None
# @@protoc_insertion_point(module_scope)
