# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/contact/PhoneNumber.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/contact/PhoneNumber.proto',
  package='opencannabis.contact',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contactB\014ContactPhoneH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/contact/PhoneNumber.proto\x12\x14opencannabis.contact\x1a\x19gust/core/datamodel.proto\"\xea\x02\n\x0bPhoneNumber\x12\x34\n\x04\x65\x31\x36\x34\x18\x01 \x01(\tB&\xc2\xb5\x03\"\x12 E164-formatted telephone number.\x12\x41\n\tvalidated\x18\x02 \x01(\x08\x42.\xc2\xb5\x03*\x12(Validation status for this phone number.\x12I\n\x07\x64isplay\x18\x03 \x01(\tB8\xc2\xb5\x03\x34\x12\x32\x44isplay text for this phone number, if applicable.\x12I\n\x0ctext_capable\x18\x04 \x01(\x08\x42\x33\xc2\xb5\x03/\x12-Whether this number can send and receive SMS.\x12L\n\rvoice_capable\x18\x05 \x01(\x08\x42\x35\xc2\xb5\x03\x31\x12/Whether this number can send and receive calls.B8\n\x1eio.opencannabis.schema.contactB\x0c\x43ontactPhoneH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_PHONENUMBER = _descriptor.Descriptor(
  name='PhoneNumber',
  full_name='opencannabis.contact.PhoneNumber',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='e164', full_name='opencannabis.contact.PhoneNumber.e164', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 E164-formatted telephone number.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validated', full_name='opencannabis.contact.PhoneNumber.validated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003*\022(Validation status for this phone number.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display', full_name='opencannabis.contact.PhoneNumber.display', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034\0222Display text for this phone number, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text_capable', full_name='opencannabis.contact.PhoneNumber.text_capable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003/\022-Whether this number can send and receive SMS.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voice_capable', full_name='opencannabis.contact.PhoneNumber.voice_capable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Whether this number can send and receive calls.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=92,
  serialized_end=454,
)

DESCRIPTOR.message_types_by_name['PhoneNumber'] = _PHONENUMBER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PhoneNumber = _reflection.GeneratedProtocolMessageType('PhoneNumber', (_message.Message,), {
  'DESCRIPTOR' : _PHONENUMBER,
  '__module__' : 'opencannabis.contact.PhoneNumber_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.contact.PhoneNumber)
  })
_sym_db.RegisterMessage(PhoneNumber)


DESCRIPTOR._options = None
_PHONENUMBER.fields_by_name['e164']._options = None
_PHONENUMBER.fields_by_name['validated']._options = None
_PHONENUMBER.fields_by_name['display']._options = None
_PHONENUMBER.fields_by_name['text_capable']._options = None
_PHONENUMBER.fields_by_name['voice_capable']._options = None
# @@protoc_insertion_point(module_scope)
