# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.structs.pricing`
  -------------------------------------
  Structures that define pricing data and sale/discount info.

"""

# `opencannabis.structs.pricing`
