# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/menu/Menu.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.products.menu import Section_pb2 as opencannabis_dot_products_dot_menu_dot_Section__pb2
from opencannabis.crypto.primitives import Integrity_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2
from opencannabis.products import SKU_pb2 as opencannabis_dot_products_dot_SKU__pb2
from opencannabis.products import Apothecary_pb2 as opencannabis_dot_products_dot_Apothecary__pb2
from opencannabis.products import Cartridge_pb2 as opencannabis_dot_products_dot_Cartridge__pb2
from opencannabis.products import Edible_pb2 as opencannabis_dot_products_dot_Edible__pb2
from opencannabis.products import Extract_pb2 as opencannabis_dot_products_dot_Extract__pb2
from opencannabis.products import Flower_pb2 as opencannabis_dot_products_dot_Flower__pb2
from opencannabis.products import Merchandise_pb2 as opencannabis_dot_products_dot_Merchandise__pb2
from opencannabis.products import Plant_pb2 as opencannabis_dot_products_dot_Plant__pb2
from opencannabis.products import Preroll_pb2 as opencannabis_dot_products_dot_Preroll__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/menu/Menu.proto',
  package='opencannabis.products.menu',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.menuH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%opencannabis/products/menu/Menu.proto\x12\x1aopencannabis.products.menu\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/base/ProductKey.proto\x1a!opencannabis/media/MediaKey.proto\x1a#opencannabis/temporal/Instant.proto\x1a(opencannabis/products/menu/Section.proto\x1a.opencannabis/crypto/primitives/Integrity.proto\x1a\x1fopencannabis/products/SKU.proto\x1a&opencannabis/products/Apothecary.proto\x1a%opencannabis/products/Cartridge.proto\x1a\"opencannabis/products/Edible.proto\x1a#opencannabis/products/Extract.proto\x1a\"opencannabis/products/Flower.proto\x1a\'opencannabis/products/Merchandise.proto\x1a!opencannabis/products/Plant.proto\x1a#opencannabis/products/Preroll.proto\"\x92\x02\n\x0cMenuSettings\x12\x0c\n\x04\x66ull\x18\x01 \x01(\x08\x12\x11\n\tkeys_only\x18\x02 \x01(\x08\x12+\n\x08snapshot\x18\x03 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\x12.\n\x0b\x66ingerprint\x18\x04 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\x12<\n\x07section\x18\x05 \x03(\x0e\x32+.opencannabis.products.menu.section.Section\x12\x46\n\x11\x61vailable_section\x18\x06 \x03(\x0e\x32+.opencannabis.products.menu.section.Section\"\xfe\x01\n\x08Metadata\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x04\x12\x32\n\x06status\x18\x03 \x01(\x0e\x32\".opencannabis.products.menu.Status\x12/\n\x05\x66lags\x18\x04 \x03(\x0e\x32 .opencannabis.products.menu.Flag\x12\x31\n\tpublished\x18\x05 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12:\n\x08settings\x18\x06 \x01(\x0b\x32(.opencannabis.products.menu.MenuSettings\"\xa4\x01\n\nProductTag\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xc2\xb5\x03\x02\x08\x02\xda\xb5\x03\x02\x10\x01\x12\x17\n\x07partner\x18\x02 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\x18\n\x08location\x18\x03 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\x17\n\x07\x64isplay\x18\x04 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\r\n\x05\x63olor\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t:\x0c\x8a\xf7\x02\x08\x08\x02\x12\x04tags\"\x93\x02\n\x10\x46oreignReference\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xc2\xb5\x03\x02\x08\x02\xda\xb5\x03\x02\x10\x01\x12\x13\n\x03key\x18\x02 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\x17\n\x07partner\x18\x03 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\x18\n\x08location\x18\x04 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\x16\n\x06\x64omain\x18\x05 \x01(\tB\x06\xda\xb5\x03\x02\x10\x01\x12\x0c\n\x04link\x18\x06 \x01(\t\x12\x30\n\x08\x61ttached\x18\x07 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x31\n\tvalidated\x18\x08 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant:\x12\x8a\xf7\x02\x0e\x08\x02\x12\nreferences\"\xf7\x07\n\x0bMenuProduct\x12\x32\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB\x06\xc2\xb5\x03\x02\x08\x01\x12M\n\x03tag\x18\x02 \x03(\x0b\x32&.opencannabis.products.menu.ProductTagB\x18\xc2\xb5\x03\x02@\x03\xd2\xb5\x03\x0e\x08\x02\x12\x04tags\x1a\x04tags\x12_\n\x03ref\x18\x03 \x03(\x0b\x32,.opencannabis.products.menu.ForeignReferenceB$\xc2\xb5\x03\x02@\x04\xd2\xb5\x03\x1a\x08\x02\x12\nreferences\x1a\nreferences\x12I\n\x05media\x18\x04 \x03(\x0b\x32\".opencannabis.media.MediaReferenceB\x16\xd2\xb5\x03\x12\x08\x02\x12\x05media\x1a\x05media \x01\x12\x46\n\x03sku\x18\x05 \x03(\x0b\x32$.opencannabis.products.sku.MappedSKUB\x13\xc2\xb5\x03\x02@\x04\xd2\xb5\x03\t\x08\x01\x1a\x03sku \x01\x12r\n\x05owner\x18\x06 \x01(\tBc\xc2\xb5\x03_\x08\x07\x12YDescribes the location scope that owns this product key, and the data associated with it.@\x04\x12?\n\napothecary\x18\n \x01(\x0b\x32!.opencannabis.products.ApothecaryB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12=\n\tcartridge\x18\x0b \x01(\x0b\x32 .opencannabis.products.CartridgeB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12\x37\n\x06\x65\x64ible\x18\x0c \x01(\x0b\x32\x1d.opencannabis.products.EdibleB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12\x39\n\x07\x65xtract\x18\r \x01(\x0b\x32\x1e.opencannabis.products.ExtractB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12\x37\n\x06\x66lower\x18\x0e \x01(\x0b\x32\x1d.opencannabis.products.FlowerB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12\x41\n\x0bmerchandise\x18\x0f \x01(\x0b\x32\".opencannabis.products.MerchandiseB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12\x35\n\x05plant\x18\x10 \x01(\x0b\x32\x1c.opencannabis.products.PlantB\x06\xda\xb5\x03\x02\x18\x01H\x00\x12\x39\n\x07preroll\x18\x11 \x01(\x0b\x32\x1e.opencannabis.products.PrerollB\x06\xda\xb5\x03\x02\x18\x01H\x00:\x10\x8a\xf7\x02\x0c\x08\x02\x12\x08productsB\t\n\x07product\"\x98\x01\n\x0bSectionData\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12@\n\x07section\x18\x02 \x01(\x0b\x32/.opencannabis.products.menu.section.SectionSpec\x12\x38\n\x07product\x18\x03 \x03(\x0b\x32\'.opencannabis.products.menu.MenuProduct\"X\n\rSectionedMenu\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x38\n\x07payload\x18\x02 \x03(\x0b\x32\'.opencannabis.products.menu.SectionData\"\xe6\t\n\nStaticMenu\x12J\n\napothecary\x18\x01 \x03(\x0b\x32\x36.opencannabis.products.menu.StaticMenu.ApothecaryEntry\x12J\n\ncartridges\x18\x02 \x03(\x0b\x32\x36.opencannabis.products.menu.StaticMenu.CartridgesEntry\x12\x44\n\x07\x65\x64ibles\x18\x03 \x03(\x0b\x32\x33.opencannabis.products.menu.StaticMenu.EdiblesEntry\x12\x46\n\x08\x65xtracts\x18\x04 \x03(\x0b\x32\x34.opencannabis.products.menu.StaticMenu.ExtractsEntry\x12\x44\n\x07\x66lowers\x18\x05 \x03(\x0b\x32\x33.opencannabis.products.menu.StaticMenu.FlowersEntry\x12L\n\x0bmerchandise\x18\x06 \x03(\x0b\x32\x37.opencannabis.products.menu.StaticMenu.MerchandiseEntry\x12\x42\n\x06plants\x18\x07 \x03(\x0b\x32\x32.opencannabis.products.menu.StaticMenu.PlantsEntry\x12\x46\n\x08prerolls\x18\x08 \x03(\x0b\x32\x34.opencannabis.products.menu.StaticMenu.PrerollsEntry\x1aT\n\x0f\x41pothecaryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.opencannabis.products.Apothecary:\x02\x38\x01\x1aS\n\x0f\x43\x61rtridgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .opencannabis.products.Cartridge:\x02\x38\x01\x1aM\n\x0c\x45\x64iblesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.opencannabis.products.Edible:\x02\x38\x01\x1aO\n\rExtractsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.opencannabis.products.Extract:\x02\x38\x01\x1aM\n\x0c\x46lowersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.opencannabis.products.Flower:\x02\x38\x01\x1aV\n\x10MerchandiseEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".opencannabis.products.Merchandise:\x02\x38\x01\x1aK\n\x0bPlantsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.opencannabis.products.Plant:\x02\x38\x01\x1aO\n\rPrerollsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.opencannabis.products.Preroll:\x02\x38\x01:\x02\x18\x01\"\xc3\x01\n\x04Menu\x12\x36\n\x08metadata\x18\x01 \x01(\x0b\x32$.opencannabis.products.menu.Metadata\x12<\n\x07payload\x18\x03 \x01(\x0b\x32).opencannabis.products.menu.SectionedMenuH\x00\x12:\n\x04menu\x18\x04 \x01(\x0b\x32&.opencannabis.products.menu.StaticMenuB\x02\x18\x01H\x00\x42\t\n\x07\x63ontent*#\n\x06Status\x12\x0f\n\x0bUNPUBLISHED\x10\x00\x12\x08\n\x04LIVE\x10\x01*/\n\x04\x46lag\x12\t\n\x05\x44RAFT\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\x0f\n\x0bOUT_OF_DATE\x10\x02\x42\'\n\x1bio.opencannabis.schema.menuH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_products_dot_menu_dot_Section__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2.DESCRIPTOR,opencannabis_dot_products_dot_SKU__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Apothecary__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Cartridge__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Edible__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Extract__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Flower__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Merchandise__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Plant__pb2.DESCRIPTOR,opencannabis_dot_products_dot_Preroll__pb2.DESCRIPTOR,])

_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='opencannabis.products.menu.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNPUBLISHED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIVE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4325,
  serialized_end=4360,
)
_sym_db.RegisterEnumDescriptor(_STATUS)

Status = enum_type_wrapper.EnumTypeWrapper(_STATUS)
_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.menu.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DRAFT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_DATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4362,
  serialized_end=4409,
)
_sym_db.RegisterEnumDescriptor(_FLAG)

Flag = enum_type_wrapper.EnumTypeWrapper(_FLAG)
UNPUBLISHED = 0
LIVE = 1
DRAFT = 0
PRIVATE = 1
OUT_OF_DATE = 2



_MENUSETTINGS = _descriptor.Descriptor(
  name='MenuSettings',
  full_name='opencannabis.products.menu.MenuSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='full', full_name='opencannabis.products.menu.MenuSettings.full', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keys_only', full_name='opencannabis.products.menu.MenuSettings.keys_only', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot', full_name='opencannabis.products.menu.MenuSettings.snapshot', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.products.menu.MenuSettings.fingerprint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='section', full_name='opencannabis.products.menu.MenuSettings.section', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_section', full_name='opencannabis.products.menu.MenuSettings.available_section', index=5,
      number=6, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=903,
)


_METADATA = _descriptor.Descriptor(
  name='Metadata',
  full_name='opencannabis.products.menu.Metadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scope', full_name='opencannabis.products.menu.Metadata.scope', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='opencannabis.products.menu.Metadata.version', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.products.menu.Metadata.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.menu.Metadata.flags', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published', full_name='opencannabis.products.menu.Metadata.published', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='settings', full_name='opencannabis.products.menu.Metadata.settings', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=906,
  serialized_end=1160,
)


_PRODUCTTAG = _descriptor.Descriptor(
  name='ProductTag',
  full_name='opencannabis.products.menu.ProductTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.products.menu.ProductTag.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.products.menu.ProductTag.partner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.products.menu.ProductTag.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display', full_name='opencannabis.products.menu.ProductTag.display', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='opencannabis.products.menu.ProductTag.color', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='opencannabis.products.menu.ProductTag.description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\010\010\002\022\004tags',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1163,
  serialized_end=1327,
)


_FOREIGNREFERENCE = _descriptor.Descriptor(
  name='ForeignReference',
  full_name='opencannabis.products.menu.ForeignReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.products.menu.ForeignReference.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.ForeignReference.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.products.menu.ForeignReference.partner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.products.menu.ForeignReference.location', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='opencannabis.products.menu.ForeignReference.domain', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='opencannabis.products.menu.ForeignReference.link', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached', full_name='opencannabis.products.menu.ForeignReference.attached', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validated', full_name='opencannabis.products.menu.ForeignReference.validated', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\016\010\002\022\nreferences',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1330,
  serialized_end=1605,
)


_MENUPRODUCT = _descriptor.Descriptor(
  name='MenuProduct',
  full_name='opencannabis.products.menu.MenuProduct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.MenuProduct.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='opencannabis.products.menu.MenuProduct.tag', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002@\003\322\265\003\016\010\002\022\004tags\032\004tags', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ref', full_name='opencannabis.products.menu.MenuProduct.ref', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002@\004\322\265\003\032\010\002\022\nreferences\032\nreferences', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.products.menu.MenuProduct.media', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\322\265\003\022\010\002\022\005media\032\005media \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sku', full_name='opencannabis.products.menu.MenuProduct.sku', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002@\004\322\265\003\t\010\001\032\003sku \001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='opencannabis.products.menu.MenuProduct.owner', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003_\010\007\022YDescribes the location scope that owns this product key, and the data associated with it.@\004', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apothecary', full_name='opencannabis.products.menu.MenuProduct.apothecary', index=6,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cartridge', full_name='opencannabis.products.menu.MenuProduct.cartridge', index=7,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edible', full_name='opencannabis.products.menu.MenuProduct.edible', index=8,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extract', full_name='opencannabis.products.menu.MenuProduct.extract', index=9,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flower', full_name='opencannabis.products.menu.MenuProduct.flower', index=10,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merchandise', full_name='opencannabis.products.menu.MenuProduct.merchandise', index=11,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plant', full_name='opencannabis.products.menu.MenuProduct.plant', index=12,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='preroll', full_name='opencannabis.products.menu.MenuProduct.preroll', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\014\010\002\022\010products',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='product', full_name='opencannabis.products.menu.MenuProduct.product',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1608,
  serialized_end=2623,
)


_SECTIONDATA = _descriptor.Descriptor(
  name='SectionData',
  full_name='opencannabis.products.menu.SectionData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='opencannabis.products.menu.SectionData.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='section', full_name='opencannabis.products.menu.SectionData.section', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.menu.SectionData.product', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2626,
  serialized_end=2778,
)


_SECTIONEDMENU = _descriptor.Descriptor(
  name='SectionedMenu',
  full_name='opencannabis.products.menu.SectionedMenu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='opencannabis.products.menu.SectionedMenu.count', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='opencannabis.products.menu.SectionedMenu.payload', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2780,
  serialized_end=2868,
)


_STATICMENU_APOTHECARYENTRY = _descriptor.Descriptor(
  name='ApothecaryEntry',
  full_name='opencannabis.products.menu.StaticMenu.ApothecaryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.ApothecaryEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.ApothecaryEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3467,
  serialized_end=3551,
)

_STATICMENU_CARTRIDGESENTRY = _descriptor.Descriptor(
  name='CartridgesEntry',
  full_name='opencannabis.products.menu.StaticMenu.CartridgesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.CartridgesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.CartridgesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3553,
  serialized_end=3636,
)

_STATICMENU_EDIBLESENTRY = _descriptor.Descriptor(
  name='EdiblesEntry',
  full_name='opencannabis.products.menu.StaticMenu.EdiblesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.EdiblesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.EdiblesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3638,
  serialized_end=3715,
)

_STATICMENU_EXTRACTSENTRY = _descriptor.Descriptor(
  name='ExtractsEntry',
  full_name='opencannabis.products.menu.StaticMenu.ExtractsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.ExtractsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.ExtractsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3717,
  serialized_end=3796,
)

_STATICMENU_FLOWERSENTRY = _descriptor.Descriptor(
  name='FlowersEntry',
  full_name='opencannabis.products.menu.StaticMenu.FlowersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.FlowersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.FlowersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3798,
  serialized_end=3875,
)

_STATICMENU_MERCHANDISEENTRY = _descriptor.Descriptor(
  name='MerchandiseEntry',
  full_name='opencannabis.products.menu.StaticMenu.MerchandiseEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.MerchandiseEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.MerchandiseEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3877,
  serialized_end=3963,
)

_STATICMENU_PLANTSENTRY = _descriptor.Descriptor(
  name='PlantsEntry',
  full_name='opencannabis.products.menu.StaticMenu.PlantsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.PlantsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.PlantsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3965,
  serialized_end=4040,
)

_STATICMENU_PREROLLSENTRY = _descriptor.Descriptor(
  name='PrerollsEntry',
  full_name='opencannabis.products.menu.StaticMenu.PrerollsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.menu.StaticMenu.PrerollsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.products.menu.StaticMenu.PrerollsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4042,
  serialized_end=4121,
)

_STATICMENU = _descriptor.Descriptor(
  name='StaticMenu',
  full_name='opencannabis.products.menu.StaticMenu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apothecary', full_name='opencannabis.products.menu.StaticMenu.apothecary', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cartridges', full_name='opencannabis.products.menu.StaticMenu.cartridges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='edibles', full_name='opencannabis.products.menu.StaticMenu.edibles', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extracts', full_name='opencannabis.products.menu.StaticMenu.extracts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flowers', full_name='opencannabis.products.menu.StaticMenu.flowers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='merchandise', full_name='opencannabis.products.menu.StaticMenu.merchandise', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='plants', full_name='opencannabis.products.menu.StaticMenu.plants', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prerolls', full_name='opencannabis.products.menu.StaticMenu.prerolls', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATICMENU_APOTHECARYENTRY, _STATICMENU_CARTRIDGESENTRY, _STATICMENU_EDIBLESENTRY, _STATICMENU_EXTRACTSENTRY, _STATICMENU_FLOWERSENTRY, _STATICMENU_MERCHANDISEENTRY, _STATICMENU_PLANTSENTRY, _STATICMENU_PREROLLSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\030\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2871,
  serialized_end=4125,
)


_MENU = _descriptor.Descriptor(
  name='Menu',
  full_name='opencannabis.products.menu.Menu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='opencannabis.products.menu.Menu.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='opencannabis.products.menu.Menu.payload', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='menu', full_name='opencannabis.products.menu.Menu.menu', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='opencannabis.products.menu.Menu.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4128,
  serialized_end=4323,
)

_MENUSETTINGS.fields_by_name['snapshot'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_MENUSETTINGS.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_MENUSETTINGS.fields_by_name['section'].enum_type = opencannabis_dot_products_dot_menu_dot_Section__pb2._SECTION
_MENUSETTINGS.fields_by_name['available_section'].enum_type = opencannabis_dot_products_dot_menu_dot_Section__pb2._SECTION
_METADATA.fields_by_name['status'].enum_type = _STATUS
_METADATA.fields_by_name['flags'].enum_type = _FLAG
_METADATA.fields_by_name['published'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_METADATA.fields_by_name['settings'].message_type = _MENUSETTINGS
_FOREIGNREFERENCE.fields_by_name['attached'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_FOREIGNREFERENCE.fields_by_name['validated'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MENUPRODUCT.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_MENUPRODUCT.fields_by_name['tag'].message_type = _PRODUCTTAG
_MENUPRODUCT.fields_by_name['ref'].message_type = _FOREIGNREFERENCE
_MENUPRODUCT.fields_by_name['media'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_MENUPRODUCT.fields_by_name['sku'].message_type = opencannabis_dot_products_dot_SKU__pb2._MAPPEDSKU
_MENUPRODUCT.fields_by_name['apothecary'].message_type = opencannabis_dot_products_dot_Apothecary__pb2._APOTHECARY
_MENUPRODUCT.fields_by_name['cartridge'].message_type = opencannabis_dot_products_dot_Cartridge__pb2._CARTRIDGE
_MENUPRODUCT.fields_by_name['edible'].message_type = opencannabis_dot_products_dot_Edible__pb2._EDIBLE
_MENUPRODUCT.fields_by_name['extract'].message_type = opencannabis_dot_products_dot_Extract__pb2._EXTRACT
_MENUPRODUCT.fields_by_name['flower'].message_type = opencannabis_dot_products_dot_Flower__pb2._FLOWER
_MENUPRODUCT.fields_by_name['merchandise'].message_type = opencannabis_dot_products_dot_Merchandise__pb2._MERCHANDISE
_MENUPRODUCT.fields_by_name['plant'].message_type = opencannabis_dot_products_dot_Plant__pb2._PLANT
_MENUPRODUCT.fields_by_name['preroll'].message_type = opencannabis_dot_products_dot_Preroll__pb2._PREROLL
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['apothecary'])
_MENUPRODUCT.fields_by_name['apothecary'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['cartridge'])
_MENUPRODUCT.fields_by_name['cartridge'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['edible'])
_MENUPRODUCT.fields_by_name['edible'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['extract'])
_MENUPRODUCT.fields_by_name['extract'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['flower'])
_MENUPRODUCT.fields_by_name['flower'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['merchandise'])
_MENUPRODUCT.fields_by_name['merchandise'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['plant'])
_MENUPRODUCT.fields_by_name['plant'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_MENUPRODUCT.oneofs_by_name['product'].fields.append(
  _MENUPRODUCT.fields_by_name['preroll'])
_MENUPRODUCT.fields_by_name['preroll'].containing_oneof = _MENUPRODUCT.oneofs_by_name['product']
_SECTIONDATA.fields_by_name['section'].message_type = opencannabis_dot_products_dot_menu_dot_Section__pb2._SECTIONSPEC
_SECTIONDATA.fields_by_name['product'].message_type = _MENUPRODUCT
_SECTIONEDMENU.fields_by_name['payload'].message_type = _SECTIONDATA
_STATICMENU_APOTHECARYENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Apothecary__pb2._APOTHECARY
_STATICMENU_APOTHECARYENTRY.containing_type = _STATICMENU
_STATICMENU_CARTRIDGESENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Cartridge__pb2._CARTRIDGE
_STATICMENU_CARTRIDGESENTRY.containing_type = _STATICMENU
_STATICMENU_EDIBLESENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Edible__pb2._EDIBLE
_STATICMENU_EDIBLESENTRY.containing_type = _STATICMENU
_STATICMENU_EXTRACTSENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Extract__pb2._EXTRACT
_STATICMENU_EXTRACTSENTRY.containing_type = _STATICMENU
_STATICMENU_FLOWERSENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Flower__pb2._FLOWER
_STATICMENU_FLOWERSENTRY.containing_type = _STATICMENU
_STATICMENU_MERCHANDISEENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Merchandise__pb2._MERCHANDISE
_STATICMENU_MERCHANDISEENTRY.containing_type = _STATICMENU
_STATICMENU_PLANTSENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Plant__pb2._PLANT
_STATICMENU_PLANTSENTRY.containing_type = _STATICMENU
_STATICMENU_PREROLLSENTRY.fields_by_name['value'].message_type = opencannabis_dot_products_dot_Preroll__pb2._PREROLL
_STATICMENU_PREROLLSENTRY.containing_type = _STATICMENU
_STATICMENU.fields_by_name['apothecary'].message_type = _STATICMENU_APOTHECARYENTRY
_STATICMENU.fields_by_name['cartridges'].message_type = _STATICMENU_CARTRIDGESENTRY
_STATICMENU.fields_by_name['edibles'].message_type = _STATICMENU_EDIBLESENTRY
_STATICMENU.fields_by_name['extracts'].message_type = _STATICMENU_EXTRACTSENTRY
_STATICMENU.fields_by_name['flowers'].message_type = _STATICMENU_FLOWERSENTRY
_STATICMENU.fields_by_name['merchandise'].message_type = _STATICMENU_MERCHANDISEENTRY
_STATICMENU.fields_by_name['plants'].message_type = _STATICMENU_PLANTSENTRY
_STATICMENU.fields_by_name['prerolls'].message_type = _STATICMENU_PREROLLSENTRY
_MENU.fields_by_name['metadata'].message_type = _METADATA
_MENU.fields_by_name['payload'].message_type = _SECTIONEDMENU
_MENU.fields_by_name['menu'].message_type = _STATICMENU
_MENU.oneofs_by_name['content'].fields.append(
  _MENU.fields_by_name['payload'])
_MENU.fields_by_name['payload'].containing_oneof = _MENU.oneofs_by_name['content']
_MENU.oneofs_by_name['content'].fields.append(
  _MENU.fields_by_name['menu'])
_MENU.fields_by_name['menu'].containing_oneof = _MENU.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['MenuSettings'] = _MENUSETTINGS
DESCRIPTOR.message_types_by_name['Metadata'] = _METADATA
DESCRIPTOR.message_types_by_name['ProductTag'] = _PRODUCTTAG
DESCRIPTOR.message_types_by_name['ForeignReference'] = _FOREIGNREFERENCE
DESCRIPTOR.message_types_by_name['MenuProduct'] = _MENUPRODUCT
DESCRIPTOR.message_types_by_name['SectionData'] = _SECTIONDATA
DESCRIPTOR.message_types_by_name['SectionedMenu'] = _SECTIONEDMENU
DESCRIPTOR.message_types_by_name['StaticMenu'] = _STATICMENU
DESCRIPTOR.message_types_by_name['Menu'] = _MENU
DESCRIPTOR.enum_types_by_name['Status'] = _STATUS
DESCRIPTOR.enum_types_by_name['Flag'] = _FLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MenuSettings = _reflection.GeneratedProtocolMessageType('MenuSettings', (_message.Message,), {
  'DESCRIPTOR' : _MENUSETTINGS,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.MenuSettings)
  })
_sym_db.RegisterMessage(MenuSettings)

Metadata = _reflection.GeneratedProtocolMessageType('Metadata', (_message.Message,), {
  'DESCRIPTOR' : _METADATA,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.Metadata)
  })
_sym_db.RegisterMessage(Metadata)

ProductTag = _reflection.GeneratedProtocolMessageType('ProductTag', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTTAG,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.ProductTag)
  })
_sym_db.RegisterMessage(ProductTag)

ForeignReference = _reflection.GeneratedProtocolMessageType('ForeignReference', (_message.Message,), {
  'DESCRIPTOR' : _FOREIGNREFERENCE,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.ForeignReference)
  })
_sym_db.RegisterMessage(ForeignReference)

MenuProduct = _reflection.GeneratedProtocolMessageType('MenuProduct', (_message.Message,), {
  'DESCRIPTOR' : _MENUPRODUCT,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.MenuProduct)
  })
_sym_db.RegisterMessage(MenuProduct)

SectionData = _reflection.GeneratedProtocolMessageType('SectionData', (_message.Message,), {
  'DESCRIPTOR' : _SECTIONDATA,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.SectionData)
  })
_sym_db.RegisterMessage(SectionData)

SectionedMenu = _reflection.GeneratedProtocolMessageType('SectionedMenu', (_message.Message,), {
  'DESCRIPTOR' : _SECTIONEDMENU,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.SectionedMenu)
  })
_sym_db.RegisterMessage(SectionedMenu)

StaticMenu = _reflection.GeneratedProtocolMessageType('StaticMenu', (_message.Message,), {

  'ApothecaryEntry' : _reflection.GeneratedProtocolMessageType('ApothecaryEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_APOTHECARYENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.ApothecaryEntry)
    })
  ,

  'CartridgesEntry' : _reflection.GeneratedProtocolMessageType('CartridgesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_CARTRIDGESENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.CartridgesEntry)
    })
  ,

  'EdiblesEntry' : _reflection.GeneratedProtocolMessageType('EdiblesEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_EDIBLESENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.EdiblesEntry)
    })
  ,

  'ExtractsEntry' : _reflection.GeneratedProtocolMessageType('ExtractsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_EXTRACTSENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.ExtractsEntry)
    })
  ,

  'FlowersEntry' : _reflection.GeneratedProtocolMessageType('FlowersEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_FLOWERSENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.FlowersEntry)
    })
  ,

  'MerchandiseEntry' : _reflection.GeneratedProtocolMessageType('MerchandiseEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_MERCHANDISEENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.MerchandiseEntry)
    })
  ,

  'PlantsEntry' : _reflection.GeneratedProtocolMessageType('PlantsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_PLANTSENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.PlantsEntry)
    })
  ,

  'PrerollsEntry' : _reflection.GeneratedProtocolMessageType('PrerollsEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATICMENU_PREROLLSENTRY,
    '__module__' : 'opencannabis.products.menu.Menu_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu.PrerollsEntry)
    })
  ,
  'DESCRIPTOR' : _STATICMENU,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.StaticMenu)
  })
_sym_db.RegisterMessage(StaticMenu)
_sym_db.RegisterMessage(StaticMenu.ApothecaryEntry)
_sym_db.RegisterMessage(StaticMenu.CartridgesEntry)
_sym_db.RegisterMessage(StaticMenu.EdiblesEntry)
_sym_db.RegisterMessage(StaticMenu.ExtractsEntry)
_sym_db.RegisterMessage(StaticMenu.FlowersEntry)
_sym_db.RegisterMessage(StaticMenu.MerchandiseEntry)
_sym_db.RegisterMessage(StaticMenu.PlantsEntry)
_sym_db.RegisterMessage(StaticMenu.PrerollsEntry)

Menu = _reflection.GeneratedProtocolMessageType('Menu', (_message.Message,), {
  'DESCRIPTOR' : _MENU,
  '__module__' : 'opencannabis.products.menu.Menu_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.menu.Menu)
  })
_sym_db.RegisterMessage(Menu)


DESCRIPTOR._options = None
_PRODUCTTAG.fields_by_name['id']._options = None
_PRODUCTTAG.fields_by_name['partner']._options = None
_PRODUCTTAG.fields_by_name['location']._options = None
_PRODUCTTAG.fields_by_name['display']._options = None
_PRODUCTTAG._options = None
_FOREIGNREFERENCE.fields_by_name['id']._options = None
_FOREIGNREFERENCE.fields_by_name['key']._options = None
_FOREIGNREFERENCE.fields_by_name['partner']._options = None
_FOREIGNREFERENCE.fields_by_name['location']._options = None
_FOREIGNREFERENCE.fields_by_name['domain']._options = None
_FOREIGNREFERENCE._options = None
_MENUPRODUCT.fields_by_name['key']._options = None
_MENUPRODUCT.fields_by_name['tag']._options = None
_MENUPRODUCT.fields_by_name['ref']._options = None
_MENUPRODUCT.fields_by_name['media']._options = None
_MENUPRODUCT.fields_by_name['sku']._options = None
_MENUPRODUCT.fields_by_name['owner']._options = None
_MENUPRODUCT.fields_by_name['apothecary']._options = None
_MENUPRODUCT.fields_by_name['cartridge']._options = None
_MENUPRODUCT.fields_by_name['edible']._options = None
_MENUPRODUCT.fields_by_name['extract']._options = None
_MENUPRODUCT.fields_by_name['flower']._options = None
_MENUPRODUCT.fields_by_name['merchandise']._options = None
_MENUPRODUCT.fields_by_name['plant']._options = None
_MENUPRODUCT.fields_by_name['preroll']._options = None
_MENUPRODUCT._options = None
_STATICMENU_APOTHECARYENTRY._options = None
_STATICMENU_CARTRIDGESENTRY._options = None
_STATICMENU_EDIBLESENTRY._options = None
_STATICMENU_EXTRACTSENTRY._options = None
_STATICMENU_FLOWERSENTRY._options = None
_STATICMENU_MERCHANDISEENTRY._options = None
_STATICMENU_PLANTSENTRY._options = None
_STATICMENU_PREROLLSENTRY._options = None
_STATICMENU._options = None
_MENU.fields_by_name['menu']._options = None
# @@protoc_insertion_point(module_scope)
