# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Instant.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Instant.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\017TemporalInstantH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/temporal/Instant.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"\x95\x01\n\x07Instant\x12\x35\n\x07iso8601\x18\x01 \x01(\tB\"\xc2\xb5\x03\x1e\x12\x1cISO8601-formatted timestamp.H\x00\x12K\n\ttimestamp\x18\x02 \x01(\x04\x42\x36\xc2\xb5\x03\x32\x12\x30Unix epoch timestamp, at millisecond resolution.H\x00\x42\x06\n\x04specB<\n\x1fio.opencannabis.schema.temporalB\x0fTemporalInstantH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_INSTANT = _descriptor.Descriptor(
  name='Instant',
  full_name='opencannabis.temporal.Instant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iso8601', full_name='opencannabis.temporal.Instant.iso8601', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\036\022\034ISO8601-formatted timestamp.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='opencannabis.temporal.Instant.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Unix epoch timestamp, at millisecond resolution.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.temporal.Instant.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=90,
  serialized_end=239,
)

_INSTANT.oneofs_by_name['spec'].fields.append(
  _INSTANT.fields_by_name['iso8601'])
_INSTANT.fields_by_name['iso8601'].containing_oneof = _INSTANT.oneofs_by_name['spec']
_INSTANT.oneofs_by_name['spec'].fields.append(
  _INSTANT.fields_by_name['timestamp'])
_INSTANT.fields_by_name['timestamp'].containing_oneof = _INSTANT.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Instant'] = _INSTANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Instant = _reflection.GeneratedProtocolMessageType('Instant', (_message.Message,), {
  'DESCRIPTOR' : _INSTANT,
  '__module__' : 'opencannabis.temporal.Instant_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Instant)
  })
_sym_db.RegisterMessage(Instant)


DESCRIPTOR._options = None
_INSTANT.fields_by_name['iso8601']._options = None
_INSTANT.fields_by_name['timestamp']._options = None
# @@protoc_insertion_point(module_scope)
