# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/device/Device.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/device/Device.proto',
  package='opencannabis.device',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.deviceH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/device/Device.proto\x12\x13opencannabis.device\x1a\x19gust/core/datamodel.proto\"\xbf\x02\n\x06\x44\x65vice\x12\x42\n\x04uuid\x18\x01 \x01(\tB4\xc2\xb5\x03\x30\x12.Universally unique identifier for this device.\x12I\n\x04type\x18\x02 \x01(\x0e\x32\x1f.opencannabis.device.DeviceTypeB\x1a\xc2\xb5\x03\x16\x12\x14Type of this device.\x12M\n\x05\x66lags\x18\x03 \x01(\x0b\x32 .opencannabis.device.DeviceFlagsB\x1c\xc2\xb5\x03\x18\x12\x16\x46lags for this device.\x12W\n\x03key\x18\x04 \x01(\x0b\x32&.opencannabis.device.DeviceCredentialsB\"\xc2\xb5\x03\x1e\x12\x1c\x43redentials for this device.\"\xbc\x01\n\x0b\x44\x65viceFlags\x12\x64\n\tephemeral\x18\x01 \x01(\x08\x42Q\xc2\xb5\x03M\x12KFlag to mark a device as ephemeral, i.e. attached to a disposable identity.\x12G\n\x07managed\x18\x02 \x01(\x08\x42\x36\xc2\xb5\x03\x32\x12\x30\x46lag to mark a device as managed by EMM systems.\"\xc3\x01\n\x11\x44\x65viceCredentials\x12\x1a\n\npublic_key\x18\x01 \x01(\x0c\x42\x06\xca\xb5\x03\x02\x10\x01\x12\x1b\n\x0bprivate_key\x18\x02 \x01(\x0c\x42\x06\xca\xb5\x03\x02\x10\x01\x12>\n\x06sha256\x18\x03 \x01(\tB.\xc2\xb5\x03*\x12(SHA256 hash of this device\'s public key.\x12\x18\n\x08identity\x18\x04 \x01(\tB\x06\xca\xb5\x03\x02\x10\x01\x12\x1b\n\x0b\x61uthorities\x18\x05 \x03(\x0c\x42\x06\xca\xb5\x03\x02\x10\x01*k\n\nDeviceType\x12\x17\n\x13UNKNOWN_DEVICE_TYPE\x10\x00\x12\x0b\n\x07\x44\x45SKTOP\x10\x01\x12\t\n\x05PHONE\x10\x02\x12\n\n\x06TABLET\x10\x03\x12\x06\n\x02TV\x10\x04\x12\x0c\n\x08\x45MBEDDED\x10\x05\x12\n\n\x06SERVER\x10\x06\x42)\n\x1dio.opencannabis.schema.deviceH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_DEVICETYPE = _descriptor.EnumDescriptor(
  name='DeviceType',
  full_name='opencannabis.device.DeviceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_DEVICE_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DESKTOP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHONE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TABLET', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TV', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EMBEDDED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SERVER', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=795,
  serialized_end=902,
)
_sym_db.RegisterEnumDescriptor(_DEVICETYPE)

DeviceType = enum_type_wrapper.EnumTypeWrapper(_DEVICETYPE)
UNKNOWN_DEVICE_TYPE = 0
DESKTOP = 1
PHONE = 2
TABLET = 3
TV = 4
EMBEDDED = 5
SERVER = 6



_DEVICE = _descriptor.Descriptor(
  name='Device',
  full_name='opencannabis.device.Device',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.device.Device.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0030\022.Universally unique identifier for this device.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.device.Device.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\026\022\024Type of this device.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.device.Device.flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\030\022\026Flags for this device.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.device.Device.key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\036\022\034Credentials for this device.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=404,
)


_DEVICEFLAGS = _descriptor.Descriptor(
  name='DeviceFlags',
  full_name='opencannabis.device.DeviceFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ephemeral', full_name='opencannabis.device.DeviceFlags.ephemeral', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003M\022KFlag to mark a device as ephemeral, i.e. attached to a disposable identity.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='managed', full_name='opencannabis.device.DeviceFlags.managed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Flag to mark a device as managed by EMM systems.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=407,
  serialized_end=595,
)


_DEVICECREDENTIALS = _descriptor.Descriptor(
  name='DeviceCredentials',
  full_name='opencannabis.device.DeviceCredentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='opencannabis.device.DeviceCredentials.public_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='private_key', full_name='opencannabis.device.DeviceCredentials.private_key', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha256', full_name='opencannabis.device.DeviceCredentials.sha256', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003*\022(SHA256 hash of this device\'s public key.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identity', full_name='opencannabis.device.DeviceCredentials.identity', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorities', full_name='opencannabis.device.DeviceCredentials.authorities', index=4,
      number=5, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=598,
  serialized_end=793,
)

_DEVICE.fields_by_name['type'].enum_type = _DEVICETYPE
_DEVICE.fields_by_name['flags'].message_type = _DEVICEFLAGS
_DEVICE.fields_by_name['key'].message_type = _DEVICECREDENTIALS
DESCRIPTOR.message_types_by_name['Device'] = _DEVICE
DESCRIPTOR.message_types_by_name['DeviceFlags'] = _DEVICEFLAGS
DESCRIPTOR.message_types_by_name['DeviceCredentials'] = _DEVICECREDENTIALS
DESCRIPTOR.enum_types_by_name['DeviceType'] = _DEVICETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Device = _reflection.GeneratedProtocolMessageType('Device', (_message.Message,), {
  'DESCRIPTOR' : _DEVICE,
  '__module__' : 'opencannabis.device.Device_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.device.Device)
  })
_sym_db.RegisterMessage(Device)

DeviceFlags = _reflection.GeneratedProtocolMessageType('DeviceFlags', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEFLAGS,
  '__module__' : 'opencannabis.device.Device_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.device.DeviceFlags)
  })
_sym_db.RegisterMessage(DeviceFlags)

DeviceCredentials = _reflection.GeneratedProtocolMessageType('DeviceCredentials', (_message.Message,), {
  'DESCRIPTOR' : _DEVICECREDENTIALS,
  '__module__' : 'opencannabis.device.Device_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.device.DeviceCredentials)
  })
_sym_db.RegisterMessage(DeviceCredentials)


DESCRIPTOR._options = None
_DEVICE.fields_by_name['uuid']._options = None
_DEVICE.fields_by_name['type']._options = None
_DEVICE.fields_by_name['flags']._options = None
_DEVICE.fields_by_name['key']._options = None
_DEVICEFLAGS.fields_by_name['ephemeral']._options = None
_DEVICEFLAGS.fields_by_name['managed']._options = None
_DEVICECREDENTIALS.fields_by_name['public_key']._options = None
_DEVICECREDENTIALS.fields_by_name['private_key']._options = None
_DEVICECREDENTIALS.fields_by_name['sha256']._options = None
_DEVICECREDENTIALS.fields_by_name['identity']._options = None
_DEVICECREDENTIALS.fields_by_name['authorities']._options = None
# @@protoc_insertion_point(module_scope)
