# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Point.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Point.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1copencannabis/geo/Point.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/geo/Distance.proto\"\xb3\x02\n\x05Point\x12\x35\n\x08latitude\x18\x01 \x01(\x01\x42#\xc2\xb5\x03\x1f\x12\x1dLatitude value of this point.\x12\x37\n\tlongitude\x18\x02 \x01(\x01\x42$\xc2\xb5\x03 \x12\x1eLongitude value of this point.\x12U\n\televation\x18\x03 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB&\xc2\xb5\x03\"\x12 Elevation of this point, if any.\x12\x63\n\x08\x61\x63\x63uracy\x18\x04 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB5\xc2\xb5\x03\x31\x12/Accuracy rating attached to this point, if any.\"\xc3\x02\n\x0fWorldCoordinate\x12:\n\x05right\x18\x01 \x01(\x01\x42+\xc2\xb5\x03\'\x12%\'Right\' value for a world coordinate.\x12\x38\n\x04\x64own\x18\x02 \x01(\x01\x42*\xc2\xb5\x03&\x12$\'Down\' value for a world coordinate.\x12U\n\televation\x18\x03 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB&\xc2\xb5\x03\"\x12 Elevation of this point, if any.\x12\x63\n\x08\x61\x63\x63uracy\x18\x04 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB5\xc2\xb5\x03\x31\x12/Accuracy rating attached to this point, if any.\"B\n\rMapCoordinate\x12\t\n\x01x\x18\x01 \x01(\r\x12\t\n\x01y\x18\x02 \x01(\r\x12\r\n\x05right\x18\x03 \x01(\r\x12\x0c\n\x04\x64own\x18\x04 \x01(\r\"\x95\x03\n\x0bMapPosition\x12\x66\n\x05point\x18\x01 \x01(\x0b\x32\x17.opencannabis.geo.PointB>\xc2\xb5\x03:\x12\x38Geo-point (latitude/longitude) for this retail location.\x12p\n\x04tile\x18\x02 \x01(\x0b\x32\x1f.opencannabis.geo.MapCoordinateBA\xc2\xb5\x03=\x12;Tile/pixel coordinate for this location, using coordinates.\x12\x7f\n\ncoordinate\x18\x03 \x01(\x0b\x32!.opencannabis.geo.WorldCoordinateBH\xc2\xb5\x03\x44\x12\x42Geo-coordinate (as a \'world coordinate\') for use with Google Maps.\x12+\n\x04zoom\x18\x04 \x01(\rB\x1d\xc2\xb5\x03\x19\x12\x17Zoom level for the map.B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,])




_POINT = _descriptor.Descriptor(
  name='Point',
  full_name='opencannabis.geo.Point',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='latitude', full_name='opencannabis.geo.Point.latitude', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\037\022\035Latitude value of this point.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='longitude', full_name='opencannabis.geo.Point.longitude', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003 \022\036Longitude value of this point.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='opencannabis.geo.Point.elevation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Elevation of this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Point.accuracy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Accuracy rating attached to this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=111,
  serialized_end=418,
)


_WORLDCOORDINATE = _descriptor.Descriptor(
  name='WorldCoordinate',
  full_name='opencannabis.geo.WorldCoordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='right', full_name='opencannabis.geo.WorldCoordinate.right', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'\022%\'Right\' value for a world coordinate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='down', full_name='opencannabis.geo.WorldCoordinate.down', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$\'Down\' value for a world coordinate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='opencannabis.geo.WorldCoordinate.elevation', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Elevation of this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.WorldCoordinate.accuracy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Accuracy rating attached to this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=421,
  serialized_end=744,
)


_MAPCOORDINATE = _descriptor.Descriptor(
  name='MapCoordinate',
  full_name='opencannabis.geo.MapCoordinate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='opencannabis.geo.MapCoordinate.x', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='opencannabis.geo.MapCoordinate.y', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right', full_name='opencannabis.geo.MapCoordinate.right', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='down', full_name='opencannabis.geo.MapCoordinate.down', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=812,
)


_MAPPOSITION = _descriptor.Descriptor(
  name='MapPosition',
  full_name='opencannabis.geo.MapPosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='point', full_name='opencannabis.geo.MapPosition.point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003:\0228Geo-point (latitude/longitude) for this retail location.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tile', full_name='opencannabis.geo.MapPosition.tile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003=\022;Tile/pixel coordinate for this location, using coordinates.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordinate', full_name='opencannabis.geo.MapPosition.coordinate', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003D\022BGeo-coordinate (as a \'world coordinate\') for use with Google Maps.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zoom', full_name='opencannabis.geo.MapPosition.zoom', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\031\022\027Zoom level for the map.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=1220,
)

_POINT.fields_by_name['elevation'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
_POINT.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
_WORLDCOORDINATE.fields_by_name['elevation'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
_WORLDCOORDINATE.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
_MAPPOSITION.fields_by_name['point'].message_type = _POINT
_MAPPOSITION.fields_by_name['tile'].message_type = _MAPCOORDINATE
_MAPPOSITION.fields_by_name['coordinate'].message_type = _WORLDCOORDINATE
DESCRIPTOR.message_types_by_name['Point'] = _POINT
DESCRIPTOR.message_types_by_name['WorldCoordinate'] = _WORLDCOORDINATE
DESCRIPTOR.message_types_by_name['MapCoordinate'] = _MAPCOORDINATE
DESCRIPTOR.message_types_by_name['MapPosition'] = _MAPPOSITION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Point = _reflection.GeneratedProtocolMessageType('Point', (_message.Message,), {
  'DESCRIPTOR' : _POINT,
  '__module__' : 'opencannabis.geo.Point_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Point)
  })
_sym_db.RegisterMessage(Point)

WorldCoordinate = _reflection.GeneratedProtocolMessageType('WorldCoordinate', (_message.Message,), {
  'DESCRIPTOR' : _WORLDCOORDINATE,
  '__module__' : 'opencannabis.geo.Point_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.WorldCoordinate)
  })
_sym_db.RegisterMessage(WorldCoordinate)

MapCoordinate = _reflection.GeneratedProtocolMessageType('MapCoordinate', (_message.Message,), {
  'DESCRIPTOR' : _MAPCOORDINATE,
  '__module__' : 'opencannabis.geo.Point_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.MapCoordinate)
  })
_sym_db.RegisterMessage(MapCoordinate)

MapPosition = _reflection.GeneratedProtocolMessageType('MapPosition', (_message.Message,), {
  'DESCRIPTOR' : _MAPPOSITION,
  '__module__' : 'opencannabis.geo.Point_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.MapPosition)
  })
_sym_db.RegisterMessage(MapPosition)


DESCRIPTOR._options = None
_POINT.fields_by_name['latitude']._options = None
_POINT.fields_by_name['longitude']._options = None
_POINT.fields_by_name['elevation']._options = None
_POINT.fields_by_name['accuracy']._options = None
_WORLDCOORDINATE.fields_by_name['right']._options = None
_WORLDCOORDINATE.fields_by_name['down']._options = None
_WORLDCOORDINATE.fields_by_name['elevation']._options = None
_WORLDCOORDINATE.fields_by_name['accuracy']._options = None
_MAPPOSITION.fields_by_name['point']._options = None
_MAPPOSITION.fields_by_name['tile']._options = None
_MAPPOSITION.fields_by_name['coordinate']._options = None
_MAPPOSITION.fields_by_name['zoom']._options = None
# @@protoc_insertion_point(module_scope)
