# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Schedule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.temporal import Time_pb2 as opencannabis_dot_temporal_dot_Time__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.temporal import Interval_pb2 as opencannabis_dot_temporal_dot_Interval__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Schedule.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\020TemporalScheduleH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Schedule.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\x1a opencannabis/temporal/Time.proto\x1a#opencannabis/temporal/Instant.proto\x1a$opencannabis/temporal/Interval.proto\"\xa8\x01\n\x08Schedule\x12\x32\n\x08\x61\x62solute\x18\x01 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantH\x00\x12+\n\x04time\x18\x02 \x01(\x0b\x32\x1b.opencannabis.temporal.TimeH\x00\x12\x33\n\x08interval\x18\x03 \x01(\x0e\x32\x1f.opencannabis.temporal.IntervalH\x00\x42\x06\n\x04specB=\n\x1fio.opencannabis.schema.temporalB\x10TemporalScheduleH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Time__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Interval__pb2.DESCRIPTOR,])




_SCHEDULE = _descriptor.Descriptor(
  name='Schedule',
  full_name='opencannabis.temporal.Schedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='absolute', full_name='opencannabis.temporal.Schedule.absolute', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='opencannabis.temporal.Schedule.time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='opencannabis.temporal.Schedule.interval', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.temporal.Schedule.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=200,
  serialized_end=368,
)

_SCHEDULE.fields_by_name['absolute'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_SCHEDULE.fields_by_name['time'].message_type = opencannabis_dot_temporal_dot_Time__pb2._TIME
_SCHEDULE.fields_by_name['interval'].enum_type = opencannabis_dot_temporal_dot_Interval__pb2._INTERVAL
_SCHEDULE.oneofs_by_name['spec'].fields.append(
  _SCHEDULE.fields_by_name['absolute'])
_SCHEDULE.fields_by_name['absolute'].containing_oneof = _SCHEDULE.oneofs_by_name['spec']
_SCHEDULE.oneofs_by_name['spec'].fields.append(
  _SCHEDULE.fields_by_name['time'])
_SCHEDULE.fields_by_name['time'].containing_oneof = _SCHEDULE.oneofs_by_name['spec']
_SCHEDULE.oneofs_by_name['spec'].fields.append(
  _SCHEDULE.fields_by_name['interval'])
_SCHEDULE.fields_by_name['interval'].containing_oneof = _SCHEDULE.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Schedule'] = _SCHEDULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Schedule = _reflection.GeneratedProtocolMessageType('Schedule', (_message.Message,), {
  'DESCRIPTOR' : _SCHEDULE,
  '__module__' : 'opencannabis.temporal.Schedule_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Schedule)
  })
_sym_db.RegisterMessage(Schedule)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
