# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Content.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.base import Language_pb2 as opencannabis_dot_base_dot_Language__pb2
from opencannabis.base import Compression_pb2 as opencannabis_dot_base_dot_Compression__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Content.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\016GenericContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/content/Content.proto\x12\x14opencannabis.content\x1a\x19gust/core/datamodel.proto\x1a opencannabis/base/Language.proto\x1a#opencannabis/base/Compression.proto\"\xd2\x02\n\x07\x43ontent\x12\x30\n\x04type\x18\x01 \x01(\x0e\x32\".opencannabis.content.Content.Type\x12\x30\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x1e.opencannabis.content.Encoding\x12-\n\x08language\x18\x03 \x01(\x0e\x32\x1b.opencannabis.base.Language\x12\x33\n\x0b\x63ompression\x18\x04 \x01(\x0b\x32\x1e.opencannabis.base.Compression\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\x11\n\x07\x63ontent\x18\n \x01(\tH\x00\x12\r\n\x03raw\x18\x14 \x01(\x0cH\x00\"4\n\x04Type\x12\x08\n\x04TEXT\x10\x00\x12\x0c\n\x08MARKDOWN\x10\x01\x12\x08\n\x04HTML\x10\x02\x12\n\n\x06\x42INARY\x10\x03\x42\t\n\x07payload*,\n\x08\x45ncoding\x12\x08\n\x04UTF8\x10\x00\x12\x07\n\x03\x42\x36\x34\x10\x01\x12\r\n\tB64_ASCII\x10\x02\x42:\n\x1eio.opencannabis.schema.contentB\x0eGenericContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_base_dot_Language__pb2.DESCRIPTOR,opencannabis_dot_base_dot_Compression__pb2.DESCRIPTOR,])

_ENCODING = _descriptor.EnumDescriptor(
  name='Encoding',
  full_name='opencannabis.content.Encoding',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UTF8', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='B64', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='B64_ASCII', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=499,
  serialized_end=543,
)
_sym_db.RegisterEnumDescriptor(_ENCODING)

Encoding = enum_type_wrapper.EnumTypeWrapper(_ENCODING)
UTF8 = 0
B64 = 1
B64_ASCII = 2


_CONTENT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.content.Content.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKDOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=434,
  serialized_end=486,
)
_sym_db.RegisterEnumDescriptor(_CONTENT_TYPE)


_CONTENT = _descriptor.Descriptor(
  name='Content',
  full_name='opencannabis.content.Content',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.content.Content.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='opencannabis.content.Content.encoding', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='opencannabis.content.Content.language', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='opencannabis.content.Content.compression', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.content.Content.id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='revision', full_name='opencannabis.content.Content.revision', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='opencannabis.content.Content.content', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.content.Content.raw', index=7,
      number=20, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CONTENT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='opencannabis.content.Content.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=159,
  serialized_end=497,
)

_CONTENT.fields_by_name['type'].enum_type = _CONTENT_TYPE
_CONTENT.fields_by_name['encoding'].enum_type = _ENCODING
_CONTENT.fields_by_name['language'].enum_type = opencannabis_dot_base_dot_Language__pb2._LANGUAGE
_CONTENT.fields_by_name['compression'].message_type = opencannabis_dot_base_dot_Compression__pb2._COMPRESSION
_CONTENT_TYPE.containing_type = _CONTENT
_CONTENT.oneofs_by_name['payload'].fields.append(
  _CONTENT.fields_by_name['content'])
_CONTENT.fields_by_name['content'].containing_oneof = _CONTENT.oneofs_by_name['payload']
_CONTENT.oneofs_by_name['payload'].fields.append(
  _CONTENT.fields_by_name['raw'])
_CONTENT.fields_by_name['raw'].containing_oneof = _CONTENT.oneofs_by_name['payload']
DESCRIPTOR.message_types_by_name['Content'] = _CONTENT
DESCRIPTOR.enum_types_by_name['Encoding'] = _ENCODING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Content = _reflection.GeneratedProtocolMessageType('Content', (_message.Message,), {
  'DESCRIPTOR' : _CONTENT,
  '__module__' : 'opencannabis.content.Content_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Content)
  })
_sym_db.RegisterMessage(Content)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
