# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/contact/ContactInfo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.geo import Location_pb2 as opencannabis_dot_geo_dot_Location__pb2
from opencannabis.contact import PhoneNumber_pb2 as opencannabis_dot_contact_dot_PhoneNumber__pb2
from opencannabis.contact import EmailAddress_pb2 as opencannabis_dot_contact_dot_EmailAddress__pb2
from opencannabis.contact import Website_pb2 as opencannabis_dot_contact_dot_Website__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/contact/ContactInfo.proto',
  package='opencannabis.contact',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contactB\016GenericContactH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/contact/ContactInfo.proto\x12\x14opencannabis.contact\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/geo/Location.proto\x1a&opencannabis/contact/PhoneNumber.proto\x1a\'opencannabis/contact/EmailAddress.proto\x1a\"opencannabis/contact/Website.proto\"\x88\x03\n\x0b\x43ontactInfo\x12n\n\x08location\x18\x01 \x01(\x0b\x32\x1a.opencannabis.geo.LocationB@\xc2\xb5\x03<\x12:Geographic location and physical mail contact information.\x12V\n\x05phone\x18\x02 \x01(\x0b\x32!.opencannabis.contact.PhoneNumberB$\xc2\xb5\x03 \x12\x1eTelephone contact information.\x12]\n\x05\x65mail\x18\x03 \x01(\x0b\x32\".opencannabis.contact.EmailAddressB*\xc2\xb5\x03&\x12$Electronic mail contact information.\x12R\n\x07website\x18\x04 \x01(\x0b\x32\x1d.opencannabis.contact.WebsiteB\"\xc2\xb5\x03\x1e\x12\x1cWebsite contact information.\"\x82\x03\n\nSocialInfo\x12?\n\x07profile\x18\x01 \x03(\x0b\x32..opencannabis.contact.SocialInfo.SocialProfile\x1a\xad\x01\n\rSocialProfile\x12@\n\x05known\x18\n \x01(\x0e\x32/.opencannabis.contact.SocialInfo.SocialProviderH\x00\x12\x10\n\x06\x63ustom\x18\x0b \x01(\tH\x00\x12\x10\n\x08username\x18\x01 \x01(\t\x12*\n\x03url\x18\x02 \x01(\x0b\x32\x1d.opencannabis.contact.WebsiteB\n\n\x08provider\"\x82\x01\n\x0eSocialProvider\x12\x1f\n\x1bUNSPECIFIED_SOCIAL_PROVIDER\x10\x00\x12\x0c\n\x08\x46\x41\x43\x45\x42OOK\x10\x01\x12\x0b\n\x07TWITTER\x10\x02\x12\r\n\tINSTAGRAM\x10\x03\x12\x0b\n\x07YOUTUBE\x10\x04\x12\n\n\x06LEAFLY\x10\x05\x12\x0c\n\x08WEEDMAPS\x10\x06\x42:\n\x1eio.opencannabis.schema.contactB\x0eGenericContactH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Location__pb2.DESCRIPTOR,opencannabis_dot_contact_dot_PhoneNumber__pb2.DESCRIPTOR,opencannabis_dot_contact_dot_EmailAddress__pb2.DESCRIPTOR,opencannabis_dot_contact_dot_Website__pb2.DESCRIPTOR,])



_SOCIALINFO_SOCIALPROVIDER = _descriptor.EnumDescriptor(
  name='SocialProvider',
  full_name='opencannabis.contact.SocialInfo.SocialProvider',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_SOCIAL_PROVIDER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FACEBOOK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TWITTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSTAGRAM', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YOUTUBE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEAFLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEDMAPS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=893,
  serialized_end=1023,
)
_sym_db.RegisterEnumDescriptor(_SOCIALINFO_SOCIALPROVIDER)


_CONTACTINFO = _descriptor.Descriptor(
  name='ContactInfo',
  full_name='opencannabis.contact.ContactInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.contact.ContactInfo.location', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003<\022:Geographic location and physical mail contact information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phone', full_name='opencannabis.contact.ContactInfo.phone', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003 \022\036Telephone contact information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='email', full_name='opencannabis.contact.ContactInfo.email', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Electronic mail contact information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='website', full_name='opencannabis.contact.ContactInfo.website', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\036\022\034Website contact information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=242,
  serialized_end=634,
)


_SOCIALINFO_SOCIALPROFILE = _descriptor.Descriptor(
  name='SocialProfile',
  full_name='opencannabis.contact.SocialInfo.SocialProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='known', full_name='opencannabis.contact.SocialInfo.SocialProfile.known', index=0,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='opencannabis.contact.SocialInfo.SocialProfile.custom', index=1,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='opencannabis.contact.SocialInfo.SocialProfile.username', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='opencannabis.contact.SocialInfo.SocialProfile.url', index=3,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='provider', full_name='opencannabis.contact.SocialInfo.SocialProfile.provider',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=717,
  serialized_end=890,
)

_SOCIALINFO = _descriptor.Descriptor(
  name='SocialInfo',
  full_name='opencannabis.contact.SocialInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='profile', full_name='opencannabis.contact.SocialInfo.profile', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOCIALINFO_SOCIALPROFILE, ],
  enum_types=[
    _SOCIALINFO_SOCIALPROVIDER,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=637,
  serialized_end=1023,
)

_CONTACTINFO.fields_by_name['location'].message_type = opencannabis_dot_geo_dot_Location__pb2._LOCATION
_CONTACTINFO.fields_by_name['phone'].message_type = opencannabis_dot_contact_dot_PhoneNumber__pb2._PHONENUMBER
_CONTACTINFO.fields_by_name['email'].message_type = opencannabis_dot_contact_dot_EmailAddress__pb2._EMAILADDRESS
_CONTACTINFO.fields_by_name['website'].message_type = opencannabis_dot_contact_dot_Website__pb2._WEBSITE
_SOCIALINFO_SOCIALPROFILE.fields_by_name['known'].enum_type = _SOCIALINFO_SOCIALPROVIDER
_SOCIALINFO_SOCIALPROFILE.fields_by_name['url'].message_type = opencannabis_dot_contact_dot_Website__pb2._WEBSITE
_SOCIALINFO_SOCIALPROFILE.containing_type = _SOCIALINFO
_SOCIALINFO_SOCIALPROFILE.oneofs_by_name['provider'].fields.append(
  _SOCIALINFO_SOCIALPROFILE.fields_by_name['known'])
_SOCIALINFO_SOCIALPROFILE.fields_by_name['known'].containing_oneof = _SOCIALINFO_SOCIALPROFILE.oneofs_by_name['provider']
_SOCIALINFO_SOCIALPROFILE.oneofs_by_name['provider'].fields.append(
  _SOCIALINFO_SOCIALPROFILE.fields_by_name['custom'])
_SOCIALINFO_SOCIALPROFILE.fields_by_name['custom'].containing_oneof = _SOCIALINFO_SOCIALPROFILE.oneofs_by_name['provider']
_SOCIALINFO.fields_by_name['profile'].message_type = _SOCIALINFO_SOCIALPROFILE
_SOCIALINFO_SOCIALPROVIDER.containing_type = _SOCIALINFO
DESCRIPTOR.message_types_by_name['ContactInfo'] = _CONTACTINFO
DESCRIPTOR.message_types_by_name['SocialInfo'] = _SOCIALINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ContactInfo = _reflection.GeneratedProtocolMessageType('ContactInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONTACTINFO,
  '__module__' : 'opencannabis.contact.ContactInfo_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.contact.ContactInfo)
  })
_sym_db.RegisterMessage(ContactInfo)

SocialInfo = _reflection.GeneratedProtocolMessageType('SocialInfo', (_message.Message,), {

  'SocialProfile' : _reflection.GeneratedProtocolMessageType('SocialProfile', (_message.Message,), {
    'DESCRIPTOR' : _SOCIALINFO_SOCIALPROFILE,
    '__module__' : 'opencannabis.contact.ContactInfo_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.contact.SocialInfo.SocialProfile)
    })
  ,
  'DESCRIPTOR' : _SOCIALINFO,
  '__module__' : 'opencannabis.contact.ContactInfo_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.contact.SocialInfo)
  })
_sym_db.RegisterMessage(SocialInfo)
_sym_db.RegisterMessage(SocialInfo.SocialProfile)


DESCRIPTOR._options = None
_CONTACTINFO.fields_by_name['location']._options = None
_CONTACTINFO.fields_by_name['phone']._options = None
_CONTACTINFO.fields_by_name['email']._options = None
_CONTACTINFO.fields_by_name['website']._options = None
# @@protoc_insertion_point(module_scope)
