# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/person/PersonName.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/person/PersonName.proto',
  package='opencannabis.person',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.personH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/person/PersonName.proto\x12\x13opencannabis.person\x1a\x19gust/core/datamodel.proto\"\xe8\x02\n\x04Name\x12Q\n\tfull_name\x18\x01 \x01(\tB>\xc2\xb5\x03:\x12\x38Person\'s full name, if a fulltext value should override.\x12\x39\n\nfirst_name\x18\x02 \x01(\tB%\xc2\xb5\x03!\x12\x1fPerson\'s given, or first, name.\x12\x38\n\tlast_name\x18\x03 \x01(\tB%\xc2\xb5\x03!\x12\x1fPerson\'s family, or last, name.\x12\x30\n\x0bmiddle_name\x18\x04 \x01(\tB\x1b\xc2\xb5\x03\x17\x12\x15Person\'s middle name.\x12\x31\n\x06prefix\x18\x05 \x01(\tB!\xc2\xb5\x03\x1d\x12\x1bPrefix for a person\'s name.\x12\x33\n\x07postfix\x18\x06 \x01(\tB\"\xc2\xb5\x03\x1e\x12\x1cPostfix for a person\'s name.B)\n\x1dio.opencannabis.schema.personH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_NAME = _descriptor.Descriptor(
  name='Name',
  full_name='opencannabis.person.Name',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='full_name', full_name='opencannabis.person.Name.full_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003:\0228Person\'s full name, if a fulltext value should override.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_name', full_name='opencannabis.person.Name.first_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003!\022\037Person\'s given, or first, name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_name', full_name='opencannabis.person.Name.last_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003!\022\037Person\'s family, or last, name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='middle_name', full_name='opencannabis.person.Name.middle_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\027\022\025Person\'s middle name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prefix', full_name='opencannabis.person.Name.prefix', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\035\022\033Prefix for a person\'s name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='postfix', full_name='opencannabis.person.Name.postfix', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\036\022\034Postfix for a person\'s name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=89,
  serialized_end=449,
)

DESCRIPTOR.message_types_by_name['Name'] = _NAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Name = _reflection.GeneratedProtocolMessageType('Name', (_message.Message,), {
  'DESCRIPTOR' : _NAME,
  '__module__' : 'opencannabis.person.PersonName_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.person.Name)
  })
_sym_db.RegisterMessage(Name)


DESCRIPTOR._options = None
_NAME.fields_by_name['full_name']._options = None
_NAME.fields_by_name['first_name']._options = None
_NAME.fields_by_name['last_name']._options = None
_NAME.fields_by_name['middle_name']._options = None
_NAME.fields_by_name['prefix']._options = None
_NAME.fields_by_name['postfix']._options = None
# @@protoc_insertion_point(module_scope)
