# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/person/Person.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.temporal import Date_pb2 as opencannabis_dot_temporal_dot_Date__pb2
from opencannabis.contact import ContactInfo_pb2 as opencannabis_dot_contact_dot_ContactInfo__pb2
from opencannabis.person import PersonName_pb2 as opencannabis_dot_person_dot_PersonName__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/person/Person.proto',
  package='opencannabis.person',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.personH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/person/Person.proto\x12\x13opencannabis.person\x1a\x19gust/core/datamodel.proto\x1a opencannabis/temporal/Date.proto\x1a&opencannabis/contact/ContactInfo.proto\x1a$opencannabis/person/PersonName.proto\"o\n\x0e\x43ustomPronouns\x12\x12\n\nnominative\x18\x01 \x01(\t\x12\x11\n\tobjective\x18\x02 \x01(\t\x12\x12\n\ndeterminer\x18\x03 \x01(\t\x12\x0f\n\x07pronoun\x18\x04 \x01(\t\x12\x11\n\treflexive\x18\x05 \x01(\t\"\xb5\x01\n\x06Gender\x12\x33\n\x06gender\x18\x01 \x01(\x0e\x32#.opencannabis.person.GenderCategory\x12\x33\n\x05known\x18\n \x01(\x0e\x32\".opencannabis.person.KnownPronounsH\x00\x12\x35\n\x06\x63ustom\x18\x0b \x01(\x0b\x32#.opencannabis.person.CustomPronounsH\x00\x42\n\n\x08pronouns\"\x88\x04\n\x06Person\x12Q\n\x04name\x18\x01 \x01(\x0b\x32\x19.opencannabis.person.NameB(\xc2\xb5\x03$\x12\"Person\'s primary name information.\x12p\n\nlegal_name\x18\x02 \x01(\x0b\x32\x19.opencannabis.person.NameBA\xc2\xb5\x03=\x12;Person\'s legal name, if it differs from their primary name.\x12Z\n\x0e\x61lternate_name\x18\x03 \x01(\x0b\x32\x19.opencannabis.person.NameB\'\xc2\xb5\x03#\x12!Person\'s optional alternate name.\x12W\n\x07\x63ontact\x18\x04 \x01(\x0b\x32!.opencannabis.contact.ContactInfoB#\xc2\xb5\x03\x1f\x12\x1dPerson\'s contact information.\x12H\n\rdate_of_birth\x18\x05 \x01(\x0b\x32\x1b.opencannabis.temporal.DateB\x14\xc2\xb5\x03\x10\x12\x0e\x44\x61te of birth.\x12:\n\x06gender\x18\x06 \x01(\x0b\x32\x1b.opencannabis.person.GenderB\r\xc2\xb5\x03\t\x12\x07Gender.*\xd2\x01\n\x0eGenderCategory\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\x0c\n\x08\x43IS_MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02\x12\x0e\n\nCIS_FEMALE\x10\x02\x12\x0e\n\nTRANS_MALE\x10\x03\x12\x10\n\x0cTRANS_FEMALE\x10\x04\x12\x0e\n\nNON_BINARY\x10\x05\x12\x10\n\x0cGENDER_FLUID\x10\x06\x12\r\n\tBI_GENDER\x10\x07\x12\x0e\n\nPAN_GENDER\x10\x08\x12\x14\n\x10\x44\x45\x43LINE_TO_STATE\x10\x63\x1a\x02\x10\x01*m\n\rKnownPronouns\x12\r\n\tNORMATIVE\x10\x00\x12\x06\n\x02HE\x10\x01\x12\x07\n\x03SHE\x10\x02\x12\x06\n\x02IT\x10\x03\x12\x08\n\x04THEY\x10\x04\x12\x06\n\x02NE\x10\x05\x12\x06\n\x02VE\x10\x06\x12\n\n\x06SPIVAK\x10\x07\x12\x06\n\x02ZE\x10\x08\x12\x06\n\x02XE\x10\tB)\n\x1dio.opencannabis.schema.personH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Date__pb2.DESCRIPTOR,opencannabis_dot_contact_dot_ContactInfo__pb2.DESCRIPTOR,opencannabis_dot_person_dot_PersonName__pb2.DESCRIPTOR,])

_GENDERCATEGORY = _descriptor.EnumDescriptor(
  name='GenderCategory',
  full_name='opencannabis.person.GenderCategory',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MALE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CIS_MALE', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEMALE', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CIS_FEMALE', index=4, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANS_MALE', index=5, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANS_FEMALE', index=6, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NON_BINARY', index=7, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GENDER_FLUID', index=8, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BI_GENDER', index=9, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAN_GENDER', index=10, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DECLINE_TO_STATE', index=11, number=99,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=1017,
  serialized_end=1227,
)
_sym_db.RegisterEnumDescriptor(_GENDERCATEGORY)

GenderCategory = enum_type_wrapper.EnumTypeWrapper(_GENDERCATEGORY)
_KNOWNPRONOUNS = _descriptor.EnumDescriptor(
  name='KnownPronouns',
  full_name='opencannabis.person.KnownPronouns',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMATIVE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THEY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPIVAK', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZE', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='XE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1229,
  serialized_end=1338,
)
_sym_db.RegisterEnumDescriptor(_KNOWNPRONOUNS)

KnownPronouns = enum_type_wrapper.EnumTypeWrapper(_KNOWNPRONOUNS)
UNSPECIFIED = 0
MALE = 1
CIS_MALE = 1
FEMALE = 2
CIS_FEMALE = 2
TRANS_MALE = 3
TRANS_FEMALE = 4
NON_BINARY = 5
GENDER_FLUID = 6
BI_GENDER = 7
PAN_GENDER = 8
DECLINE_TO_STATE = 99
NORMATIVE = 0
HE = 1
SHE = 2
IT = 3
THEY = 4
NE = 5
VE = 6
SPIVAK = 7
ZE = 8
XE = 9



_CUSTOMPRONOUNS = _descriptor.Descriptor(
  name='CustomPronouns',
  full_name='opencannabis.person.CustomPronouns',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nominative', full_name='opencannabis.person.CustomPronouns.nominative', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objective', full_name='opencannabis.person.CustomPronouns.objective', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='determiner', full_name='opencannabis.person.CustomPronouns.determiner', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pronoun', full_name='opencannabis.person.CustomPronouns.pronoun', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reflexive', full_name='opencannabis.person.CustomPronouns.reflexive', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=307,
)


_GENDER = _descriptor.Descriptor(
  name='Gender',
  full_name='opencannabis.person.Gender',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gender', full_name='opencannabis.person.Gender.gender', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='known', full_name='opencannabis.person.Gender.known', index=1,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom', full_name='opencannabis.person.Gender.custom', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='pronouns', full_name='opencannabis.person.Gender.pronouns',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=310,
  serialized_end=491,
)


_PERSON = _descriptor.Descriptor(
  name='Person',
  full_name='opencannabis.person.Person',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.person.Person.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003$\022\"Person\'s primary name information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='legal_name', full_name='opencannabis.person.Person.legal_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003=\022;Person\'s legal name, if it differs from their primary name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alternate_name', full_name='opencannabis.person.Person.alternate_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#\022!Person\'s optional alternate name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='opencannabis.person.Person.contact', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\037\022\035Person\'s contact information.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='date_of_birth', full_name='opencannabis.person.Person.date_of_birth', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\020\022\016Date of birth.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gender', full_name='opencannabis.person.Person.gender', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\t\022\007Gender.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=1014,
)

_GENDER.fields_by_name['gender'].enum_type = _GENDERCATEGORY
_GENDER.fields_by_name['known'].enum_type = _KNOWNPRONOUNS
_GENDER.fields_by_name['custom'].message_type = _CUSTOMPRONOUNS
_GENDER.oneofs_by_name['pronouns'].fields.append(
  _GENDER.fields_by_name['known'])
_GENDER.fields_by_name['known'].containing_oneof = _GENDER.oneofs_by_name['pronouns']
_GENDER.oneofs_by_name['pronouns'].fields.append(
  _GENDER.fields_by_name['custom'])
_GENDER.fields_by_name['custom'].containing_oneof = _GENDER.oneofs_by_name['pronouns']
_PERSON.fields_by_name['name'].message_type = opencannabis_dot_person_dot_PersonName__pb2._NAME
_PERSON.fields_by_name['legal_name'].message_type = opencannabis_dot_person_dot_PersonName__pb2._NAME
_PERSON.fields_by_name['alternate_name'].message_type = opencannabis_dot_person_dot_PersonName__pb2._NAME
_PERSON.fields_by_name['contact'].message_type = opencannabis_dot_contact_dot_ContactInfo__pb2._CONTACTINFO
_PERSON.fields_by_name['date_of_birth'].message_type = opencannabis_dot_temporal_dot_Date__pb2._DATE
_PERSON.fields_by_name['gender'].message_type = _GENDER
DESCRIPTOR.message_types_by_name['CustomPronouns'] = _CUSTOMPRONOUNS
DESCRIPTOR.message_types_by_name['Gender'] = _GENDER
DESCRIPTOR.message_types_by_name['Person'] = _PERSON
DESCRIPTOR.enum_types_by_name['GenderCategory'] = _GENDERCATEGORY
DESCRIPTOR.enum_types_by_name['KnownPronouns'] = _KNOWNPRONOUNS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CustomPronouns = _reflection.GeneratedProtocolMessageType('CustomPronouns', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMPRONOUNS,
  '__module__' : 'opencannabis.person.Person_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.person.CustomPronouns)
  })
_sym_db.RegisterMessage(CustomPronouns)

Gender = _reflection.GeneratedProtocolMessageType('Gender', (_message.Message,), {
  'DESCRIPTOR' : _GENDER,
  '__module__' : 'opencannabis.person.Person_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.person.Gender)
  })
_sym_db.RegisterMessage(Gender)

Person = _reflection.GeneratedProtocolMessageType('Person', (_message.Message,), {
  'DESCRIPTOR' : _PERSON,
  '__module__' : 'opencannabis.person.Person_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.person.Person)
  })
_sym_db.RegisterMessage(Person)


DESCRIPTOR._options = None
_GENDERCATEGORY._options = None
_PERSON.fields_by_name['name']._options = None
_PERSON.fields_by_name['legal_name']._options = None
_PERSON.fields_by_name['alternate_name']._options = None
_PERSON.fields_by_name['contact']._options = None
_PERSON.fields_by_name['date_of_birth']._options = None
_PERSON.fields_by_name['gender']._options = None
# @@protoc_insertion_point(module_scope)
