# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/rfid/LLRP.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.inventory.rfid import RFID_pb2 as opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/rfid/LLRP.proto',
  package='opencannabis.inventory.rfid',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/inventory/rfid/LLRP.proto\x12\x1bopencannabis.inventory.rfid\x1a\x19gust/core/datamodel.proto\x1a#opencannabis/temporal/Instant.proto\x1a&opencannabis/inventory/rfid/RFID.proto\"\xdc\x02\n\x0e\x42oundaryConfig\x12G\n\x05start\x18\x01 \x01(\x0b\x32\x38.opencannabis.inventory.rfid.BoundaryConfig.StartTrigger\x12\x45\n\x04stop\x18\x02 \x01(\x0b\x32\x37.opencannabis.inventory.rfid.BoundaryConfig.StopTrigger\x1a]\n\x0cStartTrigger\x12;\n\x04type\x18\x01 \x01(\x0e\x32-.opencannabis.inventory.rfid.StartTriggerType\x12\x10\n\x08schedule\x18\x02 \x01(\x04\x1a[\n\x0bStopTrigger\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.opencannabis.inventory.rfid.StopTriggerType\x12\x10\n\x08schedule\x18\x02 \x01(\x04\"\x11\n\x0fReportingConfig\"\xa6\x01\n\x06ROSpec\x12\n\n\x02id\x18\x01 \x01(\r\x12\x10\n\x08priority\x18\x02 \x01(\r\x12=\n\x08\x62oundary\x18\x03 \x01(\x0b\x32+.opencannabis.inventory.rfid.BoundaryConfig\x12?\n\treporting\x18\x04 \x01(\x0b\x32,.opencannabis.inventory.rfid.ReportingConfig\"\xed\x02\n\x0fTagReportOrigin\x12\x86\x01\n\x06reader\x18\x01 \x01(\x0b\x32#.opencannabis.inventory.rfid.ReaderBQ\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03G\x12\x45\x44\x65scribes info about the RFID reader device involved in a tag report.\x12\x62\n\x07partner\x18\x02 \x01(\tBQ\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03G\x12\x45\x44\x65scribes the partner account to which the reader device is assigned.\x12m\n\x08location\x18\x03 \x01(\tB[\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03Q\x12ODescribes the location, owned by the partner, where the RFID reader is located.\"\xae\x07\n\tTagReport\x12\x91\x01\n\x07\x61ntenna\x18\x01 \x01(\x0b\x32$.opencannabis.inventory.rfid.AntennaBZ\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03P\x12NDescribes info, if available, about the RFID antenna involved in a tag report.\x12\x7f\n\x03tag\x18\x02 \x01(\x0b\x32 .opencannabis.inventory.rfid.TagBP\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x46\x12\x44Specifies information about the tag that was detected in this event.\x12X\n\x04rssi\x18\x03 \x01(\x01\x42J\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03@\x12>Relative Signal Strength indicator value for this tag reading.\x12\x97\x01\n\nfirst_seen\x18\x04 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBc\xda\xb5\x03\x02\x10\x01\xca\xb5\x03\x0b\x1a\tTIMESTAMP\xc2\xb5\x03J\x12HTimestamp describing when this tag was first seen by the RFID apparatus.\x12\x9b\x01\n\tlast_seen\x18\x05 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBh\xda\xb5\x03\x02\x10\x01\xca\xb5\x03\x0b\x1a\tTIMESTAMP\xc2\xb5\x03O\x12MTimestamp describing the last moment this tag was seen by the RFID apparatus.\x12\x93\x01\n\x08received\x18\x06 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBa\xda\xb5\x03\x02\x10\x01\xca\xb5\x03\x0b\x1a\tTIMESTAMP\xc2\xb5\x03H\x12\x46Timestamp describing when the edge engine received this reading event.\x12\x64\n\x05peers\x18\x07 \x01(\rBU\xc2\xb5\x03Q\x12ODescribes the count of tags read at the same moment, or in the same tag report.\"\x96\x02\n\x0cTagReportSet\x12\x93\x01\n\x06origin\x18\x01 \x01(\x0b\x32,.opencannabis.inventory.rfid.TagReportOriginBU\xc2\xb5\x03Q\x12OSpecifies the origin of this tag report, including the reader device and scope.\x12p\n\x06report\x18\x02 \x03(\x0b\x32&.opencannabis.inventory.rfid.TagReportB8\xc2\xb5\x03\x34\x12\x32\x44\x65scribes the tags seen in a given tag report set.*\xf9\x01\n\x14RegulatoryCapability\x12!\n\x1dUNSPECIFIED_REGULATORY_REGION\x10\x00\x12\n\n\x06US_FCC\x10\x01\x12\x10\n\x0c\x45TSI_302_208\x10\x02\x12\x10\n\x0c\x45TSI_300_220\x10\x03\x12\x15\n\x11\x41USTRALIA_LIPD_1W\x10\x04\x12\x15\n\x11\x41USTRALIA_LIPD_4W\x10\x05\x12\x16\n\x12JAPAN_ARIB_STD_T89\x10\x06\x12\x16\n\x12HONGKONG_OFTA_1049\x10\x07\x12\x15\n\x11TAIWAN_DGT_LP0002\x10\x08\x12\x19\n\x15KOREA_MIC_ARTICLE_5_2\x10\t*U\n\x10StartTriggerType\x12\x14\n\x10NO_START_TRIGGER\x10\x00\x12\r\n\tIMMEDIATE\x10\x01\x12\x0c\n\x08PERIODIC\x10\x02\x12\x0e\n\nGPIO_START\x10\x03*C\n\x0fStopTriggerType\x12\x13\n\x0fNO_STOP_TRIGGER\x10\x00\x12\x0c\n\x08\x44URATION\x10\x01\x12\r\n\tGPIO_STOP\x10\x02\x42,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2.DESCRIPTOR,])

_REGULATORYCAPABILITY = _descriptor.EnumDescriptor(
  name='RegulatoryCapability',
  full_name='opencannabis.inventory.rfid.RegulatoryCapability',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_REGULATORY_REGION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='US_FCC', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ETSI_302_208', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ETSI_300_220', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUSTRALIA_LIPD_1W', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AUSTRALIA_LIPD_4W', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JAPAN_ARIB_STD_T89', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HONGKONG_OFTA_1049', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAIWAN_DGT_LP0002', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KOREA_MIC_ARTICLE_5_2', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2309,
  serialized_end=2558,
)
_sym_db.RegisterEnumDescriptor(_REGULATORYCAPABILITY)

RegulatoryCapability = enum_type_wrapper.EnumTypeWrapper(_REGULATORYCAPABILITY)
_STARTTRIGGERTYPE = _descriptor.EnumDescriptor(
  name='StartTriggerType',
  full_name='opencannabis.inventory.rfid.StartTriggerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_START_TRIGGER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMMEDIATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERIODIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPIO_START', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2560,
  serialized_end=2645,
)
_sym_db.RegisterEnumDescriptor(_STARTTRIGGERTYPE)

StartTriggerType = enum_type_wrapper.EnumTypeWrapper(_STARTTRIGGERTYPE)
_STOPTRIGGERTYPE = _descriptor.EnumDescriptor(
  name='StopTriggerType',
  full_name='opencannabis.inventory.rfid.StopTriggerType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_STOP_TRIGGER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURATION', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GPIO_STOP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2647,
  serialized_end=2714,
)
_sym_db.RegisterEnumDescriptor(_STOPTRIGGERTYPE)

StopTriggerType = enum_type_wrapper.EnumTypeWrapper(_STOPTRIGGERTYPE)
UNSPECIFIED_REGULATORY_REGION = 0
US_FCC = 1
ETSI_302_208 = 2
ETSI_300_220 = 3
AUSTRALIA_LIPD_1W = 4
AUSTRALIA_LIPD_4W = 5
JAPAN_ARIB_STD_T89 = 6
HONGKONG_OFTA_1049 = 7
TAIWAN_DGT_LP0002 = 8
KOREA_MIC_ARTICLE_5_2 = 9
NO_START_TRIGGER = 0
IMMEDIATE = 1
PERIODIC = 2
GPIO_START = 3
NO_STOP_TRIGGER = 0
DURATION = 1
GPIO_STOP = 2



_BOUNDARYCONFIG_STARTTRIGGER = _descriptor.Descriptor(
  name='StartTrigger',
  full_name='opencannabis.inventory.rfid.BoundaryConfig.StartTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.rfid.BoundaryConfig.StartTrigger.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='opencannabis.inventory.rfid.BoundaryConfig.StartTrigger.schedule', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=431,
)

_BOUNDARYCONFIG_STOPTRIGGER = _descriptor.Descriptor(
  name='StopTrigger',
  full_name='opencannabis.inventory.rfid.BoundaryConfig.StopTrigger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.rfid.BoundaryConfig.StopTrigger.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schedule', full_name='opencannabis.inventory.rfid.BoundaryConfig.StopTrigger.schedule', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=433,
  serialized_end=524,
)

_BOUNDARYCONFIG = _descriptor.Descriptor(
  name='BoundaryConfig',
  full_name='opencannabis.inventory.rfid.BoundaryConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='opencannabis.inventory.rfid.BoundaryConfig.start', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop', full_name='opencannabis.inventory.rfid.BoundaryConfig.stop', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BOUNDARYCONFIG_STARTTRIGGER, _BOUNDARYCONFIG_STOPTRIGGER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=524,
)


_REPORTINGCONFIG = _descriptor.Descriptor(
  name='ReportingConfig',
  full_name='opencannabis.inventory.rfid.ReportingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=543,
)


_ROSPEC = _descriptor.Descriptor(
  name='ROSpec',
  full_name='opencannabis.inventory.rfid.ROSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.inventory.rfid.ROSpec.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='priority', full_name='opencannabis.inventory.rfid.ROSpec.priority', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary', full_name='opencannabis.inventory.rfid.ROSpec.boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reporting', full_name='opencannabis.inventory.rfid.ROSpec.reporting', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=546,
  serialized_end=712,
)


_TAGREPORTORIGIN = _descriptor.Descriptor(
  name='TagReportOrigin',
  full_name='opencannabis.inventory.rfid.TagReportOrigin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reader', full_name='opencannabis.inventory.rfid.TagReportOrigin.reader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003G\022EDescribes info about the RFID reader device involved in a tag report.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.inventory.rfid.TagReportOrigin.partner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003G\022EDescribes the partner account to which the reader device is assigned.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.inventory.rfid.TagReportOrigin.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003Q\022ODescribes the location, owned by the partner, where the RFID reader is located.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=715,
  serialized_end=1080,
)


_TAGREPORT = _descriptor.Descriptor(
  name='TagReport',
  full_name='opencannabis.inventory.rfid.TagReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='antenna', full_name='opencannabis.inventory.rfid.TagReport.antenna', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003P\022NDescribes info, if available, about the RFID antenna involved in a tag report.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tag', full_name='opencannabis.inventory.rfid.TagReport.tag', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003F\022DSpecifies information about the tag that was detected in this event.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rssi', full_name='opencannabis.inventory.rfid.TagReport.rssi', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003@\022>Relative Signal Strength indicator value for this tag reading.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_seen', full_name='opencannabis.inventory.rfid.TagReport.first_seen', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\312\265\003\013\032\tTIMESTAMP\302\265\003J\022HTimestamp describing when this tag was first seen by the RFID apparatus.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_seen', full_name='opencannabis.inventory.rfid.TagReport.last_seen', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\312\265\003\013\032\tTIMESTAMP\302\265\003O\022MTimestamp describing the last moment this tag was seen by the RFID apparatus.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='received', full_name='opencannabis.inventory.rfid.TagReport.received', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\312\265\003\013\032\tTIMESTAMP\302\265\003H\022FTimestamp describing when the edge engine received this reading event.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peers', full_name='opencannabis.inventory.rfid.TagReport.peers', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003Q\022ODescribes the count of tags read at the same moment, or in the same tag report.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1083,
  serialized_end=2025,
)


_TAGREPORTSET = _descriptor.Descriptor(
  name='TagReportSet',
  full_name='opencannabis.inventory.rfid.TagReportSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='opencannabis.inventory.rfid.TagReportSet.origin', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003Q\022OSpecifies the origin of this tag report, including the reader device and scope.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='report', full_name='opencannabis.inventory.rfid.TagReportSet.report', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034\0222Describes the tags seen in a given tag report set.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2028,
  serialized_end=2306,
)

_BOUNDARYCONFIG_STARTTRIGGER.fields_by_name['type'].enum_type = _STARTTRIGGERTYPE
_BOUNDARYCONFIG_STARTTRIGGER.containing_type = _BOUNDARYCONFIG
_BOUNDARYCONFIG_STOPTRIGGER.fields_by_name['type'].enum_type = _STOPTRIGGERTYPE
_BOUNDARYCONFIG_STOPTRIGGER.containing_type = _BOUNDARYCONFIG
_BOUNDARYCONFIG.fields_by_name['start'].message_type = _BOUNDARYCONFIG_STARTTRIGGER
_BOUNDARYCONFIG.fields_by_name['stop'].message_type = _BOUNDARYCONFIG_STOPTRIGGER
_ROSPEC.fields_by_name['boundary'].message_type = _BOUNDARYCONFIG
_ROSPEC.fields_by_name['reporting'].message_type = _REPORTINGCONFIG
_TAGREPORTORIGIN.fields_by_name['reader'].message_type = opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2._READER
_TAGREPORT.fields_by_name['antenna'].message_type = opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2._ANTENNA
_TAGREPORT.fields_by_name['tag'].message_type = opencannabis_dot_inventory_dot_rfid_dot_RFID__pb2._TAG
_TAGREPORT.fields_by_name['first_seen'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_TAGREPORT.fields_by_name['last_seen'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_TAGREPORT.fields_by_name['received'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_TAGREPORTSET.fields_by_name['origin'].message_type = _TAGREPORTORIGIN
_TAGREPORTSET.fields_by_name['report'].message_type = _TAGREPORT
DESCRIPTOR.message_types_by_name['BoundaryConfig'] = _BOUNDARYCONFIG
DESCRIPTOR.message_types_by_name['ReportingConfig'] = _REPORTINGCONFIG
DESCRIPTOR.message_types_by_name['ROSpec'] = _ROSPEC
DESCRIPTOR.message_types_by_name['TagReportOrigin'] = _TAGREPORTORIGIN
DESCRIPTOR.message_types_by_name['TagReport'] = _TAGREPORT
DESCRIPTOR.message_types_by_name['TagReportSet'] = _TAGREPORTSET
DESCRIPTOR.enum_types_by_name['RegulatoryCapability'] = _REGULATORYCAPABILITY
DESCRIPTOR.enum_types_by_name['StartTriggerType'] = _STARTTRIGGERTYPE
DESCRIPTOR.enum_types_by_name['StopTriggerType'] = _STOPTRIGGERTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundaryConfig = _reflection.GeneratedProtocolMessageType('BoundaryConfig', (_message.Message,), {

  'StartTrigger' : _reflection.GeneratedProtocolMessageType('StartTrigger', (_message.Message,), {
    'DESCRIPTOR' : _BOUNDARYCONFIG_STARTTRIGGER,
    '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.BoundaryConfig.StartTrigger)
    })
  ,

  'StopTrigger' : _reflection.GeneratedProtocolMessageType('StopTrigger', (_message.Message,), {
    'DESCRIPTOR' : _BOUNDARYCONFIG_STOPTRIGGER,
    '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
    # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.BoundaryConfig.StopTrigger)
    })
  ,
  'DESCRIPTOR' : _BOUNDARYCONFIG,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.BoundaryConfig)
  })
_sym_db.RegisterMessage(BoundaryConfig)
_sym_db.RegisterMessage(BoundaryConfig.StartTrigger)
_sym_db.RegisterMessage(BoundaryConfig.StopTrigger)

ReportingConfig = _reflection.GeneratedProtocolMessageType('ReportingConfig', (_message.Message,), {
  'DESCRIPTOR' : _REPORTINGCONFIG,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.ReportingConfig)
  })
_sym_db.RegisterMessage(ReportingConfig)

ROSpec = _reflection.GeneratedProtocolMessageType('ROSpec', (_message.Message,), {
  'DESCRIPTOR' : _ROSPEC,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.ROSpec)
  })
_sym_db.RegisterMessage(ROSpec)

TagReportOrigin = _reflection.GeneratedProtocolMessageType('TagReportOrigin', (_message.Message,), {
  'DESCRIPTOR' : _TAGREPORTORIGIN,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.TagReportOrigin)
  })
_sym_db.RegisterMessage(TagReportOrigin)

TagReport = _reflection.GeneratedProtocolMessageType('TagReport', (_message.Message,), {
  'DESCRIPTOR' : _TAGREPORT,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.TagReport)
  })
_sym_db.RegisterMessage(TagReport)

TagReportSet = _reflection.GeneratedProtocolMessageType('TagReportSet', (_message.Message,), {
  'DESCRIPTOR' : _TAGREPORTSET,
  '__module__' : 'opencannabis.inventory.rfid.LLRP_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.TagReportSet)
  })
_sym_db.RegisterMessage(TagReportSet)


DESCRIPTOR._options = None
_TAGREPORTORIGIN.fields_by_name['reader']._options = None
_TAGREPORTORIGIN.fields_by_name['partner']._options = None
_TAGREPORTORIGIN.fields_by_name['location']._options = None
_TAGREPORT.fields_by_name['antenna']._options = None
_TAGREPORT.fields_by_name['tag']._options = None
_TAGREPORT.fields_by_name['rssi']._options = None
_TAGREPORT.fields_by_name['first_seen']._options = None
_TAGREPORT.fields_by_name['last_seen']._options = None
_TAGREPORT.fields_by_name['received']._options = None
_TAGREPORT.fields_by_name['peers']._options = None
_TAGREPORTSET.fields_by_name['origin']._options = None
_TAGREPORTSET.fields_by_name['report']._options = None
# @@protoc_insertion_point(module_scope)
