# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/oauth/AuthorizationScope.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/oauth/AuthorizationScope.proto',
  package='opencannabis.oauth',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.oauthH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+opencannabis/oauth/AuthorizationScope.proto\x12\x12opencannabis.oauth\"J\n\x12\x41uthorizationScope\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x0c\n\x04icon\x18\x04 \x01(\tB(\n\x1cio.opencannabis.schema.oauthH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)




_AUTHORIZATIONSCOPE = _descriptor.Descriptor(
  name='AuthorizationScope',
  full_name='opencannabis.oauth.AuthorizationScope',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.oauth.AuthorizationScope.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='label', full_name='opencannabis.oauth.AuthorizationScope.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.oauth.AuthorizationScope.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='opencannabis.oauth.AuthorizationScope.icon', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=141,
)

DESCRIPTOR.message_types_by_name['AuthorizationScope'] = _AUTHORIZATIONSCOPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthorizationScope = _reflection.GeneratedProtocolMessageType('AuthorizationScope', (_message.Message,), {
  'DESCRIPTOR' : _AUTHORIZATIONSCOPE,
  '__module__' : 'opencannabis.oauth.AuthorizationScope_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.oauth.AuthorizationScope)
  })
_sym_db.RegisterMessage(AuthorizationScope)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
