# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Interval.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Interval.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\020TemporalIntervalH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Interval.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"\xd8\x01\n\x0cTimeInterval\x12i\n\x08interval\x18\x01 \x01(\x0e\x32\x1f.opencannabis.temporal.IntervalB6\xc2\xb5\x03\x32\x12\x30Specifies the type/window for the time interval.\x12]\n\x05\x65very\x18\x02 \x01(\rBN\xc2\xb5\x03J\x12HSpecifies an optional interval border, i.e., the N in \'every N seconds\'.*H\n\x08Interval\x12\x0c\n\x08MINUTELY\x10\x00\x12\n\n\x06HOURLY\x10\x01\x12\t\n\x05\x44\x41ILY\x10\x02\x12\n\n\x06WEEKLY\x10\x03\x12\x0b\n\x07MONTHLY\x10\x04\x42=\n\x1fio.opencannabis.schema.temporalB\x10TemporalIntervalH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_INTERVAL = _descriptor.EnumDescriptor(
  name='Interval',
  full_name='opencannabis.temporal.Interval',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MINUTELY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOURLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAILY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEKLY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHLY', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=309,
  serialized_end=381,
)
_sym_db.RegisterEnumDescriptor(_INTERVAL)

Interval = enum_type_wrapper.EnumTypeWrapper(_INTERVAL)
MINUTELY = 0
HOURLY = 1
DAILY = 2
WEEKLY = 3
MONTHLY = 4



_TIMEINTERVAL = _descriptor.Descriptor(
  name='TimeInterval',
  full_name='opencannabis.temporal.TimeInterval',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='opencannabis.temporal.TimeInterval.interval', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Specifies the type/window for the time interval.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='every', full_name='opencannabis.temporal.TimeInterval.every', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003J\022HSpecifies an optional interval border, i.e., the N in \'every N seconds\'.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=307,
)

_TIMEINTERVAL.fields_by_name['interval'].enum_type = _INTERVAL
DESCRIPTOR.message_types_by_name['TimeInterval'] = _TIMEINTERVAL
DESCRIPTOR.enum_types_by_name['Interval'] = _INTERVAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeInterval = _reflection.GeneratedProtocolMessageType('TimeInterval', (_message.Message,), {
  'DESCRIPTOR' : _TIMEINTERVAL,
  '__module__' : 'opencannabis.temporal.Interval_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.TimeInterval)
  })
_sym_db.RegisterMessage(TimeInterval)


DESCRIPTOR._options = None
_TIMEINTERVAL.fields_by_name['interval']._options = None
_TIMEINTERVAL.fields_by_name['every']._options = None
# @@protoc_insertion_point(module_scope)
