# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaType.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaType.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\rMediaItemTypeH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/media/MediaType.proto\x12\x12opencannabis.media\x1a\x19gust/core/datamodel.proto\"\xcc\x06\n\tMediaType\x12x\n\x04kind\x18\x01 \x01(\x0e\x32\".opencannabis.media.MediaType.KindBF\xc2\xb5\x03\x42\x12@Specifies the generic kind of media being described or attached.\x12u\n\nimage_type\x18\x65 \x01(\x0e\x32\'.opencannabis.media.MediaType.ImageKindB6\xc2\xb5\x03\x32\x12\x30Specifies content for an image-based media item.H\x00\x12~\n\rdocument_type\x18\xc9\x01 \x01(\x0e\x32*.opencannabis.media.MediaType.DocumentKindB8\xc2\xb5\x03\x34\x12\x32Specifies content for a document-based media item.H\x00\x12u\n\nvideo_type\x18\xad\x02 \x01(\x0e\x32\'.opencannabis.media.MediaType.VideoKindB5\xc2\xb5\x03\x31\x12/Specifies content for a video-based media item.H\x00\"4\n\x04Kind\x12\x08\n\x04LINK\x10\x00\x12\t\n\x05IMAGE\x10\x01\x12\x0c\n\x08\x44OCUMENT\x10\x02\x12\t\n\x05VIDEO\x10\x03\"U\n\tImageKind\x12\x1a\n\x16UNSPECIFIED_IMAGE_TYPE\x10\x00\x12\x07\n\x03PNG\x10\x01\x12\x07\n\x03JPG\x10\x02\x12\x07\n\x03GIF\x10\x03\x12\x07\n\x03SVG\x10\x04\x12\x08\n\x04WEBP\x10\x05\"\"\n\x08ImageDPI\x12\x06\n\x02X1\x10\x00\x12\x06\n\x02X2\x10\x01\x12\x06\n\x02X3\x10\x02\"W\n\x0c\x44ocumentKind\x12\x1d\n\x19UNSPECIFIED_DOCUMENT_TYPE\x10\x00\x12\x07\n\x03TXT\x10\x01\x12\x08\n\x04HTML\x10\x02\x12\x07\n\x03PDF\x10\x03\x12\x0c\n\x08MARKDOWN\x10\x04\"B\n\tVideoKind\x12\x1a\n\x16UNSPECIFIED_VIDEO_TYPE\x10\x00\x12\x07\n\x03MP4\x10\x01\x12\x07\n\x03\x46LV\x10\x02\x12\x07\n\x03HLS\x10\x03\x42\t\n\x07\x63ontentB7\n\x1cio.opencannabis.schema.mediaB\rMediaItemTypeH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])



_MEDIATYPE_KIND = _descriptor.EnumDescriptor(
  name='Kind',
  full_name='opencannabis.media.MediaType.Kind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMAGE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOCUMENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VIDEO', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=587,
  serialized_end=639,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_KIND)

_MEDIATYPE_IMAGEKIND = _descriptor.EnumDescriptor(
  name='ImageKind',
  full_name='opencannabis.media.MediaType.ImageKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_IMAGE_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PNG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='JPG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GIF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SVG', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEBP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=641,
  serialized_end=726,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_IMAGEKIND)

_MEDIATYPE_IMAGEDPI = _descriptor.EnumDescriptor(
  name='ImageDPI',
  full_name='opencannabis.media.MediaType.ImageDPI',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='X1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X2', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=728,
  serialized_end=762,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_IMAGEDPI)

_MEDIATYPE_DOCUMENTKIND = _descriptor.EnumDescriptor(
  name='DocumentKind',
  full_name='opencannabis.media.MediaType.DocumentKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_DOCUMENT_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TXT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HTML', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PDF', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MARKDOWN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=764,
  serialized_end=851,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_DOCUMENTKIND)

_MEDIATYPE_VIDEOKIND = _descriptor.EnumDescriptor(
  name='VideoKind',
  full_name='opencannabis.media.MediaType.VideoKind',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_VIDEO_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MP4', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLV', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HLS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=853,
  serialized_end=919,
)
_sym_db.RegisterEnumDescriptor(_MEDIATYPE_VIDEOKIND)


_MEDIATYPE = _descriptor.Descriptor(
  name='MediaType',
  full_name='opencannabis.media.MediaType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='kind', full_name='opencannabis.media.MediaType.kind', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003B\022@Specifies the generic kind of media being described or attached.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_type', full_name='opencannabis.media.MediaType.image_type', index=1,
      number=101, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Specifies content for an image-based media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='document_type', full_name='opencannabis.media.MediaType.document_type', index=2,
      number=201, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034\0222Specifies content for a document-based media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='video_type', full_name='opencannabis.media.MediaType.video_type', index=3,
      number=301, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Specifies content for a video-based media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MEDIATYPE_KIND,
    _MEDIATYPE_IMAGEKIND,
    _MEDIATYPE_IMAGEDPI,
    _MEDIATYPE_DOCUMENTKIND,
    _MEDIATYPE_VIDEOKIND,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='opencannabis.media.MediaType.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=86,
  serialized_end=930,
)

_MEDIATYPE.fields_by_name['kind'].enum_type = _MEDIATYPE_KIND
_MEDIATYPE.fields_by_name['image_type'].enum_type = _MEDIATYPE_IMAGEKIND
_MEDIATYPE.fields_by_name['document_type'].enum_type = _MEDIATYPE_DOCUMENTKIND
_MEDIATYPE.fields_by_name['video_type'].enum_type = _MEDIATYPE_VIDEOKIND
_MEDIATYPE_KIND.containing_type = _MEDIATYPE
_MEDIATYPE_IMAGEKIND.containing_type = _MEDIATYPE
_MEDIATYPE_IMAGEDPI.containing_type = _MEDIATYPE
_MEDIATYPE_DOCUMENTKIND.containing_type = _MEDIATYPE
_MEDIATYPE_VIDEOKIND.containing_type = _MEDIATYPE
_MEDIATYPE.oneofs_by_name['content'].fields.append(
  _MEDIATYPE.fields_by_name['image_type'])
_MEDIATYPE.fields_by_name['image_type'].containing_oneof = _MEDIATYPE.oneofs_by_name['content']
_MEDIATYPE.oneofs_by_name['content'].fields.append(
  _MEDIATYPE.fields_by_name['document_type'])
_MEDIATYPE.fields_by_name['document_type'].containing_oneof = _MEDIATYPE.oneofs_by_name['content']
_MEDIATYPE.oneofs_by_name['content'].fields.append(
  _MEDIATYPE.fields_by_name['video_type'])
_MEDIATYPE.fields_by_name['video_type'].containing_oneof = _MEDIATYPE.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['MediaType'] = _MEDIATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaType = _reflection.GeneratedProtocolMessageType('MediaType', (_message.Message,), {
  'DESCRIPTOR' : _MEDIATYPE,
  '__module__' : 'opencannabis.media.MediaType_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaType)
  })
_sym_db.RegisterMessage(MediaType)


DESCRIPTOR._options = None
_MEDIATYPE.fields_by_name['kind']._options = None
_MEDIATYPE.fields_by_name['image_type']._options = None
_MEDIATYPE.fields_by_name['document_type']._options = None
_MEDIATYPE.fields_by_name['video_type']._options = None
# @@protoc_insertion_point(module_scope)
