# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Country.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Country.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/Country.proto\x12\x10opencannabis.geo\"\x17\n\x07\x43ountry\x12\x0c\n\x04\x63ode\x18\x01 \x01(\tB&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)




_COUNTRY = _descriptor.Descriptor(
  name='Country',
  full_name='opencannabis.geo.Country',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='opencannabis.geo.Country.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=52,
  serialized_end=75,
)

DESCRIPTOR.message_types_by_name['Country'] = _COUNTRY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Country = _reflection.GeneratedProtocolMessageType('Country', (_message.Message,), {
  'DESCRIPTOR' : _COUNTRY,
  '__module__' : 'opencannabis.geo.Country_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Country)
  })
_sym_db.RegisterMessage(Country)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
