# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Version.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Version.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.structB\007VersionH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/structs/Version.proto\x12\x14opencannabis.structs\x1a\x19gust/core/datamodel.proto\"Q\n\x0bVersionSpec\x12:\n\x04name\x18\x01 \x01(\tB*\xc2\xb5\x03&\x12$Version specified by arbitrary name.H\x00\x42\x06\n\x04specB2\n\x1dio.opencannabis.schema.structB\x07VersionH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_VERSIONSPEC = _descriptor.Descriptor(
  name='VersionSpec',
  full_name='opencannabis.structs.VersionSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.structs.VersionSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Version specified by arbitrary name.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.structs.VersionSpec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=87,
  serialized_end=168,
)

_VERSIONSPEC.oneofs_by_name['spec'].fields.append(
  _VERSIONSPEC.fields_by_name['name'])
_VERSIONSPEC.fields_by_name['name'].containing_oneof = _VERSIONSPEC.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['VersionSpec'] = _VERSIONSPEC
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VersionSpec = _reflection.GeneratedProtocolMessageType('VersionSpec', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONSPEC,
  '__module__' : 'opencannabis.structs.Version_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.structs.VersionSpec)
  })
_sym_db.RegisterMessage(VersionSpec)


DESCRIPTOR._options = None
_VERSIONSPEC.fields_by_name['name']._options = None
# @@protoc_insertion_point(module_scope)
