# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/Grow.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/Grow.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\014MaterialGrowH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/structs/Grow.proto\x12\x14opencannabis.structs*<\n\x04Grow\x12\x0b\n\x07GENERIC\x10\x00\x12\n\n\x06INDOOR\x10\x01\x12\x0e\n\nGREENHOUSE\x10\x02\x12\x0b\n\x07OUTDOOR\x10\x03\x42?\n%io.opencannabis.schema.product.structB\x0cMaterialGrowH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_GROW = _descriptor.EnumDescriptor(
  name='Grow',
  full_name='opencannabis.structs.Grow',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INDOOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREENHOUSE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTDOOR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=57,
  serialized_end=117,
)
_sym_db.RegisterEnumDescriptor(_GROW)

Grow = enum_type_wrapper.EnumTypeWrapper(_GROW)
GENERIC = 0
INDOOR = 1
GREENHOUSE = 2
OUTDOOR = 3


DESCRIPTOR.enum_types_by_name['Grow'] = _GROW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
