# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/labtesting/Cannabinoids.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/labtesting/Cannabinoids.proto',
  package='opencannabis.structs.labtesting',
  syntax='proto3',
  serialized_options=b'\n-io.opencannabis.schema.product.struct.testingB\024CannabinoidCompoundsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n2opencannabis/structs/labtesting/Cannabinoids.proto\x12\x1fopencannabis.structs.labtesting*\xe6\x01\n\x0b\x43\x61nnabinoid\x12\x07\n\x03THC\x10\x00\x12\t\n\x05THC_A\x10\x01\x12\t\n\x05THC_V\x10\x02\x12\n\n\x06THC_VA\x10\x03\x12\t\n\x05THC_8\x10\x04\x12\t\n\x05THC_9\x10\x05\x12\x07\n\x03\x43\x42\x44\x10\n\x12\t\n\x05\x43\x42\x44_A\x10\x0b\x12\t\n\x05\x43\x42\x44_V\x10\x0c\x12\n\n\x06\x43\x42\x44_VA\x10\r\x12\x07\n\x03\x43\x42\x43\x10\x14\x12\t\n\x05\x43\x42\x43_A\x10\x15\x12\x07\n\x03\x43\x42G\x10\x1e\x12\t\n\x05\x43\x42G_A\x10\x1f\x12\x07\n\x03\x43\x42N\x10(\x12\t\n\x05\x43\x42N_A\x10)\x12\x07\n\x03\x43\x42V\x10\x32\x12\t\n\x05\x43\x42V_A\x10\x33\x12\x07\n\x03TAC\x10<\x12\x07\n\x03\x43\x42L\x10\x46\x12\t\n\x05\x43\x42L_A\x10G*|\n\x10\x43\x61nnabinoidRatio\x12\x1d\n\x19NO_CANNABINOID_PREFERENCE\x10\x00\x12\x0c\n\x08THC_ONLY\x10\x01\x12\x10\n\x0cTHC_OVER_CBD\x10\x02\x12\t\n\x05\x45QUAL\x10\x03\x12\x10\n\x0c\x43\x42\x44_OVER_THC\x10\x04\x12\x0c\n\x08\x43\x42\x44_ONLY\x10\x05\x42O\n-io.opencannabis.schema.product.struct.testingB\x14\x43\x61nnabinoidCompoundsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_CANNABINOID = _descriptor.EnumDescriptor(
  name='Cannabinoid',
  full_name='opencannabis.structs.labtesting.Cannabinoid',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='THC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_A', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_V', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_VA', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_8', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_9', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD', index=6, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_A', index=7, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_V', index=8, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_VA', index=9, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBC', index=10, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBC_A', index=11, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBG', index=12, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBG_A', index=13, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBN', index=14, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBN_A', index=15, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBV', index=16, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBV_A', index=17, number=51,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TAC', index=18, number=60,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBL', index=19, number=70,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBL_A', index=20, number=71,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=88,
  serialized_end=318,
)
_sym_db.RegisterEnumDescriptor(_CANNABINOID)

Cannabinoid = enum_type_wrapper.EnumTypeWrapper(_CANNABINOID)
_CANNABINOIDRATIO = _descriptor.EnumDescriptor(
  name='CannabinoidRatio',
  full_name='opencannabis.structs.labtesting.CannabinoidRatio',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_CANNABINOID_PREFERENCE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='THC_OVER_CBD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EQUAL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_OVER_THC', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CBD_ONLY', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=320,
  serialized_end=444,
)
_sym_db.RegisterEnumDescriptor(_CANNABINOIDRATIO)

CannabinoidRatio = enum_type_wrapper.EnumTypeWrapper(_CANNABINOIDRATIO)
THC = 0
THC_A = 1
THC_V = 2
THC_VA = 3
THC_8 = 4
THC_9 = 5
CBD = 10
CBD_A = 11
CBD_V = 12
CBD_VA = 13
CBC = 20
CBC_A = 21
CBG = 30
CBG_A = 31
CBN = 40
CBN_A = 41
CBV = 50
CBV_A = 51
TAC = 60
CBL = 70
CBL_A = 71
NO_CANNABINOID_PREFERENCE = 0
THC_ONLY = 1
THC_OVER_CBD = 2
EQUAL = 3
CBD_OVER_THC = 4
CBD_ONLY = 5


DESCRIPTOR.enum_types_by_name['Cannabinoid'] = _CANNABINOID
DESCRIPTOR.enum_types_by_name['CannabinoidRatio'] = _CANNABINOIDRATIO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
