# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Address.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Address.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/Address.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\"\xd1\x03\n\x07\x41\x64\x64ress\x12\x34\n\nfirst_line\x18\x01 \x01(\tB \xc2\xb5\x03\x1c\x12\x1a\x46irst line of the address.\x12\x45\n\x0bsecond_line\x18\x02 \x01(\tB0\xc2\xb5\x03,\x12*Second line of the address, if applicable.\x12>\n\x04\x63ity\x18\x03 \x01(\tB0\xc2\xb5\x03,\x12*City or municipality name for the address.\x12S\n\x05state\x18\x04 \x01(\tBD\xc2\xb5\x03@\x12>State that contains the city or municipality for this address.\x12\x41\n\x07zipcode\x18\x05 \x01(\tB0\xc2\xb5\x03,\x12*USPS zipcode associated with this address.\x12q\n\x07\x63ountry\x18\x06 \x01(\tB`\xc2\xb5\x03\\\x12ZCountry code associated with this address (\'US\' or \'USA\' for United States, for instance).B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='opencannabis.geo.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='first_line', full_name='opencannabis.geo.Address.first_line', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\034\022\032First line of the address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='second_line', full_name='opencannabis.geo.Address.second_line', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Second line of the address, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='city', full_name='opencannabis.geo.Address.city', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*City or municipality name for the address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='opencannabis.geo.Address.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003@\022>State that contains the city or municipality for this address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zipcode', full_name='opencannabis.geo.Address.zipcode', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*USPS zipcode associated with this address.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='country', full_name='opencannabis.geo.Address.country', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\\\022ZCountry code associated with this address (\'US\' or \'USA\' for United States, for instance).', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=545,
)

DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'opencannabis.geo.Address_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Address)
  })
_sym_db.RegisterMessage(Address)


DESCRIPTOR._options = None
_ADDRESS.fields_by_name['first_line']._options = None
_ADDRESS.fields_by_name['second_line']._options = None
_ADDRESS.fields_by_name['city']._options = None
_ADDRESS.fields_by_name['state']._options = None
_ADDRESS.fields_by_name['zipcode']._options = None
_ADDRESS.fields_by_name['country']._options = None
# @@protoc_insertion_point(module_scope)
