# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/ProductFlags.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/ProductFlags.proto',
  package='opencannabis.structs',
  syntax='proto3',
  serialized_options=b'\n%io.opencannabis.schema.product.structB\013BaseStructsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'opencannabis/structs/ProductFlags.proto\x12\x14opencannabis.structs*\xa6\x01\n\x0bProductFlag\x12\x0b\n\x07VISIBLE\x10\x00\x12\n\n\x06HIDDEN\x10\x01\x12\x0b\n\x07PREMIUM\x10\x02\x12\x0c\n\x08\x46\x45\x41TURED\x10\x03\x12\r\n\tEXCLUSIVE\x10\x04\x12\x0c\n\x08IN_HOUSE\x10\x05\x12\x0f\n\x0bLAST_CHANCE\x10\x06\x12\x10\n\x0cLIMITED_TIME\x10\x07\x12\t\n\x05LOCAL\x10\x08\x12\x0b\n\x07\x44\x45LETED\x10\t\x12\x0b\n\x07ON_SALE\x10\x14\x42>\n%io.opencannabis.schema.product.structB\x0b\x42\x61seStructsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_PRODUCTFLAG = _descriptor.EnumDescriptor(
  name='ProductFlag',
  full_name='opencannabis.structs.ProductFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VISIBLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIDDEN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREMIUM', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEATURED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXCLUSIVE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IN_HOUSE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LAST_CHANCE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIMITED_TIME', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_SALE', index=10, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=66,
  serialized_end=232,
)
_sym_db.RegisterEnumDescriptor(_PRODUCTFLAG)

ProductFlag = enum_type_wrapper.EnumTypeWrapper(_PRODUCTFLAG)
VISIBLE = 0
HIDDEN = 1
PREMIUM = 2
FEATURED = 3
EXCLUSIVE = 4
IN_HOUSE = 5
LAST_CHANCE = 6
LIMITED_TIME = 7
LOCAL = 8
DELETED = 9
ON_SALE = 20


DESCRIPTOR.enum_types_by_name['ProductFlag'] = _PRODUCTFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
