# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/proximity/BluetoothBeacon.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.geo import Location_pb2 as opencannabis_dot_geo_dot_Location__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/proximity/BluetoothBeacon.proto',
  package='opencannabis.proximity',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.proximityH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,opencannabis/proximity/BluetoothBeacon.proto\x12\x16opencannabis.proximity\x1a\x1fopencannabis/geo/Location.proto\x1a\x1fopencannabis/geo/Distance.proto\x1a#opencannabis/temporal/Instant.proto\"\xcf\x01\n\x0f\x42luetoothBeacon\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\r\n\x05major\x18\x02 \x01(\r\x12\r\n\x05minor\x18\x03 \x01(\r\x12,\n\x04seen\x18\x04 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12,\n\x08location\x18\x05 \x01(\x0b\x32\x1a.opencannabis.geo.Location\x12\x34\n\x08\x61\x63\x63uracy\x18\x06 \x01(\x0b\x32\".opencannabis.geo.LocationAccuracyB,\n io.opencannabis.schema.proximityH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_geo_dot_Location__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])




_BLUETOOTHBEACON = _descriptor.Descriptor(
  name='BluetoothBeacon',
  full_name='opencannabis.proximity.BluetoothBeacon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.proximity.BluetoothBeacon.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='major', full_name='opencannabis.proximity.BluetoothBeacon.major', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='opencannabis.proximity.BluetoothBeacon.minor', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seen', full_name='opencannabis.proximity.BluetoothBeacon.seen', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.proximity.BluetoothBeacon.location', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.proximity.BluetoothBeacon.accuracy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=176,
  serialized_end=383,
)

_BLUETOOTHBEACON.fields_by_name['seen'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_BLUETOOTHBEACON.fields_by_name['location'].message_type = opencannabis_dot_geo_dot_Location__pb2._LOCATION
_BLUETOOTHBEACON.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._LOCATIONACCURACY
DESCRIPTOR.message_types_by_name['BluetoothBeacon'] = _BLUETOOTHBEACON
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BluetoothBeacon = _reflection.GeneratedProtocolMessageType('BluetoothBeacon', (_message.Message,), {
  'DESCRIPTOR' : _BLUETOOTHBEACON,
  '__module__' : 'opencannabis.proximity.BluetoothBeacon_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.proximity.BluetoothBeacon)
  })
_sym_db.RegisterMessage(BluetoothBeacon)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
