# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/InventoryLocation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.contact import ContactInfo_pb2 as opencannabis_dot_contact_dot_ContactInfo__pb2
from opencannabis.inventory import InventoryProduct_pb2 as opencannabis_dot_inventory_dot_InventoryProduct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/InventoryLocation.proto',
  package='opencannabis.inventory',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.opencannabis/inventory/InventoryLocation.proto\x12\x16opencannabis.inventory\x1a\x19gust/core/datamodel.proto\x1a&opencannabis/contact/ContactInfo.proto\x1a-opencannabis/inventory/InventoryProduct.proto\"O\n\x14InventoryLocationKey\x12\x14\n\x04uuid\x18\x01 \x01(\tB\x06\xc2\xb5\x03\x02\x08\x02\x12\x0f\n\x07partner\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\"\xd5\x01\n\x11InventoryLocation\x12\x41\n\x03key\x18\x01 \x01(\x0b\x32,.opencannabis.inventory.InventoryLocationKeyB\x06\xc2\xb5\x03\x02\x08\x01\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.opencannabis.inventory.InventoryLocationType\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x32\n\x07\x63ontact\x18\x04 \x01(\x0b\x32!.opencannabis.contact.ContactInfo\"\x89\x01\n\x10InventoryBinding\x12=\n\x07held_by\x18\x01 \x01(\x0b\x32,.opencannabis.inventory.InventoryLocationKey\x12\x36\n\x04item\x18\x02 \x01(\x0b\x32(.opencannabis.inventory.InventoryProduct*B\n\x15InventoryLocationType\x12\n\n\x06RETAIL\x10\x00\x12\r\n\tWAREHOUSE\x10\x01\x12\x0e\n\nPRODUCTION\x10\x02\x42,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_contact_dot_ContactInfo__pb2.DESCRIPTOR,opencannabis_dot_inventory_dot_InventoryProduct__pb2.DESCRIPTOR,])

_INVENTORYLOCATIONTYPE = _descriptor.EnumDescriptor(
  name='InventoryLocationType',
  full_name='opencannabis.inventory.InventoryLocationType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RETAIL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAREHOUSE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRODUCTION', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=625,
  serialized_end=691,
)
_sym_db.RegisterEnumDescriptor(_INVENTORYLOCATIONTYPE)

InventoryLocationType = enum_type_wrapper.EnumTypeWrapper(_INVENTORYLOCATIONTYPE)
RETAIL = 0
WAREHOUSE = 1
PRODUCTION = 2



_INVENTORYLOCATIONKEY = _descriptor.Descriptor(
  name='InventoryLocationKey',
  full_name='opencannabis.inventory.InventoryLocationKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.inventory.InventoryLocationKey.uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.inventory.InventoryLocationKey.partner', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.inventory.InventoryLocationKey.location', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=188,
  serialized_end=267,
)


_INVENTORYLOCATION = _descriptor.Descriptor(
  name='InventoryLocation',
  full_name='opencannabis.inventory.InventoryLocation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.inventory.InventoryLocation.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.InventoryLocation.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.inventory.InventoryLocation.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contact', full_name='opencannabis.inventory.InventoryLocation.contact', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=483,
)


_INVENTORYBINDING = _descriptor.Descriptor(
  name='InventoryBinding',
  full_name='opencannabis.inventory.InventoryBinding',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='held_by', full_name='opencannabis.inventory.InventoryBinding.held_by', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='opencannabis.inventory.InventoryBinding.item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=486,
  serialized_end=623,
)

_INVENTORYLOCATION.fields_by_name['key'].message_type = _INVENTORYLOCATIONKEY
_INVENTORYLOCATION.fields_by_name['type'].enum_type = _INVENTORYLOCATIONTYPE
_INVENTORYLOCATION.fields_by_name['contact'].message_type = opencannabis_dot_contact_dot_ContactInfo__pb2._CONTACTINFO
_INVENTORYBINDING.fields_by_name['held_by'].message_type = _INVENTORYLOCATIONKEY
_INVENTORYBINDING.fields_by_name['item'].message_type = opencannabis_dot_inventory_dot_InventoryProduct__pb2._INVENTORYPRODUCT
DESCRIPTOR.message_types_by_name['InventoryLocationKey'] = _INVENTORYLOCATIONKEY
DESCRIPTOR.message_types_by_name['InventoryLocation'] = _INVENTORYLOCATION
DESCRIPTOR.message_types_by_name['InventoryBinding'] = _INVENTORYBINDING
DESCRIPTOR.enum_types_by_name['InventoryLocationType'] = _INVENTORYLOCATIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InventoryLocationKey = _reflection.GeneratedProtocolMessageType('InventoryLocationKey', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYLOCATIONKEY,
  '__module__' : 'opencannabis.inventory.InventoryLocation_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryLocationKey)
  })
_sym_db.RegisterMessage(InventoryLocationKey)

InventoryLocation = _reflection.GeneratedProtocolMessageType('InventoryLocation', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYLOCATION,
  '__module__' : 'opencannabis.inventory.InventoryLocation_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryLocation)
  })
_sym_db.RegisterMessage(InventoryLocation)

InventoryBinding = _reflection.GeneratedProtocolMessageType('InventoryBinding', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYBINDING,
  '__module__' : 'opencannabis.inventory.InventoryLocation_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryBinding)
  })
_sym_db.RegisterMessage(InventoryBinding)


DESCRIPTOR._options = None
_INVENTORYLOCATIONKEY.fields_by_name['uuid']._options = None
_INVENTORYLOCATION.fields_by_name['key']._options = None
# @@protoc_insertion_point(module_scope)
