# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaKey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.media import MediaType_pb2 as opencannabis_dot_media_dot_MediaType__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaKey.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\014MediaItemKeyH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/media/MediaKey.proto\x12\x12opencannabis.media\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/media/MediaType.proto\"B\n\x08MediaKey\x12\x36\n\x02id\x18\x01 \x01(\tB*\xc2\xb5\x03\x02\x08\x02\xc2\xb5\x03 J\x1eUnique ID for this media item.\"\x9f\x02\n\x0eMediaReference\x12_\n\x03key\x18\x01 \x01(\x0b\x32\x1c.opencannabis.media.MediaKeyB4\xc2\xb5\x03\x02\x08\x01\xc2\xb5\x03*J(Key being referenced as this media item.\x12J\n\x03uri\x18\x02 \x01(\tB=\xc2\xb5\x03\x39J7URI at which the media item can be consumed/downloaded.\x12`\n\x04type\x18\x03 \x01(\x0b\x32\x1d.opencannabis.media.MediaTypeB3\xc2\xb5\x03/J-Specifies the type of media being referenced.B6\n\x1cio.opencannabis.schema.mediaB\x0cMediaItemKeyH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaType__pb2.DESCRIPTOR,])




_MEDIAKEY = _descriptor.Descriptor(
  name='MediaKey',
  full_name='opencannabis.media.MediaKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.media.MediaKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\302\265\003 J\036Unique ID for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=186,
)


_MEDIAREFERENCE = _descriptor.Descriptor(
  name='MediaReference',
  full_name='opencannabis.media.MediaReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.media.MediaReference.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001\302\265\003*J(Key being referenced as this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.media.MediaReference.uri', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039J7URI at which the media item can be consumed/downloaded.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.media.MediaReference.type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003/J-Specifies the type of media being referenced.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=476,
)

_MEDIAREFERENCE.fields_by_name['key'].message_type = _MEDIAKEY
_MEDIAREFERENCE.fields_by_name['type'].message_type = opencannabis_dot_media_dot_MediaType__pb2._MEDIATYPE
DESCRIPTOR.message_types_by_name['MediaKey'] = _MEDIAKEY
DESCRIPTOR.message_types_by_name['MediaReference'] = _MEDIAREFERENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaKey = _reflection.GeneratedProtocolMessageType('MediaKey', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAKEY,
  '__module__' : 'opencannabis.media.MediaKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaKey)
  })
_sym_db.RegisterMessage(MediaKey)

MediaReference = _reflection.GeneratedProtocolMessageType('MediaReference', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAREFERENCE,
  '__module__' : 'opencannabis.media.MediaKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaReference)
  })
_sym_db.RegisterMessage(MediaReference)


DESCRIPTOR._options = None
_MEDIAKEY.fields_by_name['id']._options = None
_MEDIAREFERENCE.fields_by_name['key']._options = None
_MEDIAREFERENCE.fields_by_name['uri']._options = None
_MEDIAREFERENCE.fields_by_name['type']._options = None
# @@protoc_insertion_point(module_scope)
