# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.structs`
  ---------------------------
  Generic structures and definitions that are shared across record types.

"""

# `opencannabis.structs`
