# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Item.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.structs.pricing import PricingDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Item.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\tOrderItemH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/commerce/Item.proto\x12\x15opencannabis.commerce\x1a\"opencannabis/base/ProductKey.proto\x1a\x34opencannabis/structs/pricing/PricingDescriptor.proto\"\xb1\x01\n\x0bVariantSpec\x12\x36\n\x07variant\x18\x01 \x01(\x0e\x32%.opencannabis.commerce.ProductVariant\x12\x41\n\x06weight\x18\x02 \x01(\x0e\x32/.opencannabis.structs.pricing.PricingWeightTierH\x00\x12\x0e\n\x04size\x18\x03 \x01(\tH\x00\x12\x0f\n\x05\x63olor\x18\x04 \x01(\tH\x00\x42\x06\n\x04spec\"\x96\x01\n\x04Item\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x33\n\x07variant\x18\x02 \x03(\x0b\x32\".opencannabis.commerce.VariantSpec\x12\r\n\x05\x63ount\x18\x03 \x01(\r\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x11\n\timage_uri\x18\x05 \x01(\t*1\n\x0eProductVariant\x12\n\n\x06WEIGHT\x10\x00\x12\t\n\x05\x43OLOR\x10\x01\x12\x08\n\x04SIZE\x10\x02\x42\x36\n\x1fio.opencannabis.schema.commerceB\tOrderItemH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2.DESCRIPTOR,])

_PRODUCTVARIANT = _descriptor.EnumDescriptor(
  name='ProductVariant',
  full_name='opencannabis.commerce.ProductVariant',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='WEIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COLOR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIZE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=531,
)
_sym_db.RegisterEnumDescriptor(_PRODUCTVARIANT)

ProductVariant = enum_type_wrapper.EnumTypeWrapper(_PRODUCTVARIANT)
WEIGHT = 0
COLOR = 1
SIZE = 2



_VARIANTSPEC = _descriptor.Descriptor(
  name='VariantSpec',
  full_name='opencannabis.commerce.VariantSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.commerce.VariantSpec.variant', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='opencannabis.commerce.VariantSpec.weight', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='opencannabis.commerce.VariantSpec.size', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color', full_name='opencannabis.commerce.VariantSpec.color', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.commerce.VariantSpec.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=150,
  serialized_end=327,
)


_ITEM = _descriptor.Descriptor(
  name='Item',
  full_name='opencannabis.commerce.Item',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.commerce.Item.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.commerce.Item.variant', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='opencannabis.commerce.Item.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.commerce.Item.uri', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_uri', full_name='opencannabis.commerce.Item.image_uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=480,
)

_VARIANTSPEC.fields_by_name['variant'].enum_type = _PRODUCTVARIANT
_VARIANTSPEC.fields_by_name['weight'].enum_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRICINGWEIGHTTIER
_VARIANTSPEC.oneofs_by_name['spec'].fields.append(
  _VARIANTSPEC.fields_by_name['weight'])
_VARIANTSPEC.fields_by_name['weight'].containing_oneof = _VARIANTSPEC.oneofs_by_name['spec']
_VARIANTSPEC.oneofs_by_name['spec'].fields.append(
  _VARIANTSPEC.fields_by_name['size'])
_VARIANTSPEC.fields_by_name['size'].containing_oneof = _VARIANTSPEC.oneofs_by_name['spec']
_VARIANTSPEC.oneofs_by_name['spec'].fields.append(
  _VARIANTSPEC.fields_by_name['color'])
_VARIANTSPEC.fields_by_name['color'].containing_oneof = _VARIANTSPEC.oneofs_by_name['spec']
_ITEM.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_ITEM.fields_by_name['variant'].message_type = _VARIANTSPEC
DESCRIPTOR.message_types_by_name['VariantSpec'] = _VARIANTSPEC
DESCRIPTOR.message_types_by_name['Item'] = _ITEM
DESCRIPTOR.enum_types_by_name['ProductVariant'] = _PRODUCTVARIANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VariantSpec = _reflection.GeneratedProtocolMessageType('VariantSpec', (_message.Message,), {
  'DESCRIPTOR' : _VARIANTSPEC,
  '__module__' : 'opencannabis.commerce.Item_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.VariantSpec)
  })
_sym_db.RegisterMessage(VariantSpec)

Item = _reflection.GeneratedProtocolMessageType('Item', (_message.Message,), {
  'DESCRIPTOR' : _ITEM,
  '__module__' : 'opencannabis.commerce.Item_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Item)
  })
_sym_db.RegisterMessage(Item)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
