# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.products.distribution`
  -------------------------------------
  Objects that describe and govern how products are distributed.

"""

# `opencannabis.products.distribution`
