# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/Order.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.commerce import Item_pb2 as opencannabis_dot_commerce_dot_Item__pb2
from opencannabis.commerce import Delivery_pb2 as opencannabis_dot_commerce_dot_Delivery__pb2
from opencannabis.commerce import Customer_pb2 as opencannabis_dot_commerce_dot_Customer__pb2
from opencannabis.commerce.payments import Payment_pb2 as opencannabis_dot_commerce_dot_payments_dot_Payment__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/Order.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\017CommercialOrderH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/commerce/Order.proto\x12\x15opencannabis.commerce\x1a\x19gust/core/datamodel.proto\x1a opencannabis/commerce/Item.proto\x1a$opencannabis/commerce/Delivery.proto\x1a$opencannabis/commerce/Customer.proto\x1a,opencannabis/commerce/payments/Payment.proto\x1a#opencannabis/temporal/Instant.proto\"\xec\x01\n\x0fOrderScheduling\x12w\n\nscheduling\x18\x01 \x01(\x0e\x32%.opencannabis.commerce.SchedulingTypeB<\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x32\x12\x30Scheduling type, either \'ASAP\' or a target time.\x12`\n\x0c\x64\x65sired_time\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB*\xc2\xb5\x03&\x12$Desired delivery time, if specified.\"\xce\x02\n\x0cOrderPayment\x12]\n\x06status\x18\x01 \x01(\x0e\x32$.opencannabis.commerce.PaymentStatusB\'\xc2\xb5\x03#\x12!Status of payment for this order.\x12\x61\n\x06method\x18\x02 \x01(\x0e\x32$.opencannabis.commerce.PaymentMethodB+\xc2\xb5\x03\'\x12%Method of payment used on this order.\x12\x37\n\x03tax\x18\x03 \x01(\x01\x42*\xc2\xb5\x03&\x12$Amount of tax added to the subtotal.\x12\x43\n\x04paid\x18\x04 \x01(\x01\x42\x35\xc2\xb5\x03\x31\x12/Amount the user has paid so far for this order.\"\x85\x01\n\rStatusCheckin\x12\x32\n\x06status\x18\x01 \x01(\x0e\x32\".opencannabis.commerce.OrderStatus\x12/\n\x07instant\x18\x02 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x0f\n\x07message\x18\x03 \x01(\t\"M\n\x08OrderKey\x12\x41\n\x02id\x18\x01 \x01(\tB5\xc2\xb5\x03\x31\x12/Order ID, assigned by the server upon creation.\"\xf0\x08\n\x05Order\x12h\n\x02id\x18\x01 \x01(\tB\\\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03R\x12PID assigned to the order by the server, and potentially nominated by the client.\x12p\n\x04type\x18\x02 \x01(\x0e\x32 .opencannabis.commerce.OrderTypeB@\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x36\x12\x34Type of order requested - either PICKUP or DELIVERY.\x12:\n\x06status\x18\x03 \x01(\x0e\x32\".opencannabis.commerce.OrderStatusB\x06\xca\xb5\x03\x02\x10\x01\x12\x62\n\x08\x63ustomer\x18\x04 \x01(\x0b\x32\x1f.opencannabis.commerce.CustomerB/\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03%\x12#Customer that submitted this order.\x12g\n\nscheduling\x18\x05 \x01(\x0b\x32&.opencannabis.commerce.OrderSchedulingB+\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03!\x12\x1fScheduling spec for this order.\x12l\n\x0b\x64\x65stination\x18\x06 \x01(\x0b\x32*.opencannabis.commerce.DeliveryDestinationB+\xc2\xb5\x03\'\x12%Location for delivery, if applicable.\x12\x15\n\x05notes\x18\x07 \x01(\tB\x06\xca\xb5\x03\x02\x10\x01\x12\x31\n\x04item\x18\x08 \x03(\x0b\x32\x1b.opencannabis.commerce.ItemB\x06\xca\xb5\x03\x02\x10\x01\x12@\n\naction_log\x18\t \x03(\x0b\x32$.opencannabis.commerce.StatusCheckinB\x06\xca\xb5\x03\x02\x10\x01\x12\\\n\ncreated_at\x18\n \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB(\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x1e\x12\x1cWhen this order was created.\x12\'\n\x08subtotal\x18\x0b \x01(\x01\x42\x15\xc2\xb5\x03\x11\x12\x0fOrder subtotal.\x12:\n\nupdated_at\x18\x0c \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB\x06\xca\xb5\x03\x02\x10\x01\x12L\n\x03sid\x18\r \x01(\tB?\xc2\xb5\x03;\x12\x39Session ID that was active when this order was submitted.\x12w\n\x07payment\x18\x0e \x01(\x0b\x32#.opencannabis.commerce.OrderPaymentBA\xc2\xb5\x03=\x12;Payment information/metadata for this order, if applicable.*1\n\tOrderType\x12\n\n\x06PICKUP\x10\x00\x12\x0c\n\x08\x44\x45LIVERY\x10\x01\x12\n\n\x06ONSITE\x10\x02*%\n\x0eSchedulingType\x12\x08\n\x04\x41SAP\x10\x00\x12\t\n\x05TIMED\x10\x01*a\n\x0bOrderStatus\x12\x0b\n\x07PENDING\x10\x00\x12\x0c\n\x08\x41PPROVED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0c\n\x08\x41SSIGNED\x10\x03\x12\x0c\n\x08\x45N_ROUTE\x10\x04\x12\r\n\tFULFILLED\x10\x05\x42<\n\x1fio.opencannabis.schema.commerceB\x0f\x43ommercialOrderH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Item__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Delivery__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Customer__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_payments_dot_Payment__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])

_ORDERTYPE = _descriptor.EnumDescriptor(
  name='OrderType',
  full_name='opencannabis.commerce.OrderType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PICKUP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELIVERY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ONSITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2210,
  serialized_end=2259,
)
_sym_db.RegisterEnumDescriptor(_ORDERTYPE)

OrderType = enum_type_wrapper.EnumTypeWrapper(_ORDERTYPE)
_SCHEDULINGTYPE = _descriptor.EnumDescriptor(
  name='SchedulingType',
  full_name='opencannabis.commerce.SchedulingType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ASAP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2261,
  serialized_end=2298,
)
_sym_db.RegisterEnumDescriptor(_SCHEDULINGTYPE)

SchedulingType = enum_type_wrapper.EnumTypeWrapper(_SCHEDULINGTYPE)
_ORDERSTATUS = _descriptor.EnumDescriptor(
  name='OrderStatus',
  full_name='opencannabis.commerce.OrderStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='APPROVED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REJECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSIGNED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EN_ROUTE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULFILLED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2300,
  serialized_end=2397,
)
_sym_db.RegisterEnumDescriptor(_ORDERSTATUS)

OrderStatus = enum_type_wrapper.EnumTypeWrapper(_ORDERSTATUS)
PICKUP = 0
DELIVERY = 1
ONSITE = 2
ASAP = 0
TIMED = 1
PENDING = 0
APPROVED = 1
REJECTED = 2
ASSIGNED = 3
EN_ROUTE = 4
FULFILLED = 5



_ORDERSCHEDULING = _descriptor.Descriptor(
  name='OrderScheduling',
  full_name='opencannabis.commerce.OrderScheduling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scheduling', full_name='opencannabis.commerce.OrderScheduling.scheduling', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0032\0220Scheduling type, either \'ASAP\' or a target time.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='desired_time', full_name='opencannabis.commerce.OrderScheduling.desired_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Desired delivery time, if specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=517,
)


_ORDERPAYMENT = _descriptor.Descriptor(
  name='OrderPayment',
  full_name='opencannabis.commerce.OrderPayment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.commerce.OrderPayment.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#\022!Status of payment for this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='method', full_name='opencannabis.commerce.OrderPayment.method', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'\022%Method of payment used on this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tax', full_name='opencannabis.commerce.OrderPayment.tax', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&\022$Amount of tax added to the subtotal.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='paid', full_name='opencannabis.commerce.OrderPayment.paid', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Amount the user has paid so far for this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=854,
)


_STATUSCHECKIN = _descriptor.Descriptor(
  name='StatusCheckin',
  full_name='opencannabis.commerce.StatusCheckin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.commerce.StatusCheckin.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='instant', full_name='opencannabis.commerce.StatusCheckin.instant', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='opencannabis.commerce.StatusCheckin.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=857,
  serialized_end=990,
)


_ORDERKEY = _descriptor.Descriptor(
  name='OrderKey',
  full_name='opencannabis.commerce.OrderKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.commerce.OrderKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Order ID, assigned by the server upon creation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=992,
  serialized_end=1069,
)


_ORDER = _descriptor.Descriptor(
  name='Order',
  full_name='opencannabis.commerce.Order',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.commerce.Order.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003R\022PID assigned to the order by the server, and potentially nominated by the client.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.commerce.Order.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0036\0224Type of order requested - either PICKUP or DELIVERY.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.commerce.Order.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='customer', full_name='opencannabis.commerce.Order.customer', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003%\022#Customer that submitted this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduling', full_name='opencannabis.commerce.Order.scheduling', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003!\022\037Scheduling spec for this order.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination', full_name='opencannabis.commerce.Order.destination', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'\022%Location for delivery, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='notes', full_name='opencannabis.commerce.Order.notes', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='opencannabis.commerce.Order.item', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action_log', full_name='opencannabis.commerce.Order.action_log', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='opencannabis.commerce.Order.created_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003\036\022\034When this order was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subtotal', full_name='opencannabis.commerce.Order.subtotal', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\021\022\017Order subtotal.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='opencannabis.commerce.Order.updated_at', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sid', full_name='opencannabis.commerce.Order.sid', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003;\0229Session ID that was active when this order was submitted.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment', full_name='opencannabis.commerce.Order.payment', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003=\022;Payment information/metadata for this order, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1072,
  serialized_end=2208,
)

_ORDERSCHEDULING.fields_by_name['scheduling'].enum_type = _SCHEDULINGTYPE
_ORDERSCHEDULING.fields_by_name['desired_time'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDERPAYMENT.fields_by_name['status'].enum_type = opencannabis_dot_commerce_dot_payments_dot_Payment__pb2._PAYMENTSTATUS
_ORDERPAYMENT.fields_by_name['method'].enum_type = opencannabis_dot_commerce_dot_payments_dot_Payment__pb2._PAYMENTMETHOD
_STATUSCHECKIN.fields_by_name['status'].enum_type = _ORDERSTATUS
_STATUSCHECKIN.fields_by_name['instant'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDER.fields_by_name['type'].enum_type = _ORDERTYPE
_ORDER.fields_by_name['status'].enum_type = _ORDERSTATUS
_ORDER.fields_by_name['customer'].message_type = opencannabis_dot_commerce_dot_Customer__pb2._CUSTOMER
_ORDER.fields_by_name['scheduling'].message_type = _ORDERSCHEDULING
_ORDER.fields_by_name['destination'].message_type = opencannabis_dot_commerce_dot_Delivery__pb2._DELIVERYDESTINATION
_ORDER.fields_by_name['item'].message_type = opencannabis_dot_commerce_dot_Item__pb2._ITEM
_ORDER.fields_by_name['action_log'].message_type = _STATUSCHECKIN
_ORDER.fields_by_name['created_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDER.fields_by_name['updated_at'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_ORDER.fields_by_name['payment'].message_type = _ORDERPAYMENT
DESCRIPTOR.message_types_by_name['OrderScheduling'] = _ORDERSCHEDULING
DESCRIPTOR.message_types_by_name['OrderPayment'] = _ORDERPAYMENT
DESCRIPTOR.message_types_by_name['StatusCheckin'] = _STATUSCHECKIN
DESCRIPTOR.message_types_by_name['OrderKey'] = _ORDERKEY
DESCRIPTOR.message_types_by_name['Order'] = _ORDER
DESCRIPTOR.enum_types_by_name['OrderType'] = _ORDERTYPE
DESCRIPTOR.enum_types_by_name['SchedulingType'] = _SCHEDULINGTYPE
DESCRIPTOR.enum_types_by_name['OrderStatus'] = _ORDERSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrderScheduling = _reflection.GeneratedProtocolMessageType('OrderScheduling', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSCHEDULING,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.OrderScheduling)
  })
_sym_db.RegisterMessage(OrderScheduling)

OrderPayment = _reflection.GeneratedProtocolMessageType('OrderPayment', (_message.Message,), {
  'DESCRIPTOR' : _ORDERPAYMENT,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.OrderPayment)
  })
_sym_db.RegisterMessage(OrderPayment)

StatusCheckin = _reflection.GeneratedProtocolMessageType('StatusCheckin', (_message.Message,), {
  'DESCRIPTOR' : _STATUSCHECKIN,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.StatusCheckin)
  })
_sym_db.RegisterMessage(StatusCheckin)

OrderKey = _reflection.GeneratedProtocolMessageType('OrderKey', (_message.Message,), {
  'DESCRIPTOR' : _ORDERKEY,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.OrderKey)
  })
_sym_db.RegisterMessage(OrderKey)

Order = _reflection.GeneratedProtocolMessageType('Order', (_message.Message,), {
  'DESCRIPTOR' : _ORDER,
  '__module__' : 'opencannabis.commerce.Order_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.commerce.Order)
  })
_sym_db.RegisterMessage(Order)


DESCRIPTOR._options = None
_ORDERSCHEDULING.fields_by_name['scheduling']._options = None
_ORDERSCHEDULING.fields_by_name['desired_time']._options = None
_ORDERPAYMENT.fields_by_name['status']._options = None
_ORDERPAYMENT.fields_by_name['method']._options = None
_ORDERPAYMENT.fields_by_name['tax']._options = None
_ORDERPAYMENT.fields_by_name['paid']._options = None
_ORDERKEY.fields_by_name['id']._options = None
_ORDER.fields_by_name['id']._options = None
_ORDER.fields_by_name['type']._options = None
_ORDER.fields_by_name['status']._options = None
_ORDER.fields_by_name['customer']._options = None
_ORDER.fields_by_name['scheduling']._options = None
_ORDER.fields_by_name['destination']._options = None
_ORDER.fields_by_name['notes']._options = None
_ORDER.fields_by_name['item']._options = None
_ORDER.fields_by_name['action_log']._options = None
_ORDER.fields_by_name['created_at']._options = None
_ORDER.fields_by_name['subtotal']._options = None
_ORDER.fields_by_name['updated_at']._options = None
_ORDER.fields_by_name['sid']._options = None
_ORDER.fields_by_name['payment']._options = None
# @@protoc_insertion_point(module_scope)
