# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/primitives/Integrity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/primitives/Integrity.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n2io.opencannabis.schema.crypto.primitives.integrityH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.opencannabis/crypto/primitives/Integrity.proto\x12\x13opencannabis.crypto\"t\n\x04Hash\x12\x35\n\talgorithm\x18\x01 \x01(\x0e\x32\".opencannabis.crypto.HashAlgorithm\x12\r\n\x03raw\x18\x02 \x01(\x0cH\x00\x12\r\n\x03hex\x18\x03 \x01(\tH\x00\x12\r\n\x03\x62\x36\x34\x18\x04 \x01(\tH\x00\x42\x08\n\x06\x64igest\"C\n\nHashedData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\'\n\x04hash\x18\x02 \x01(\x0b\x32\x19.opencannabis.crypto.Hash*R\n\rHashAlgorithm\x12\x08\n\x04SHA1\x10\x00\x12\x07\n\x03MD5\x10\x01\x12\n\n\x06SHA256\x10\x02\x12\n\n\x06SHA384\x10\x03\x12\n\n\x06SHA512\x10\x04\x12\n\n\x06MURMUR\x10\x06\x42>\n2io.opencannabis.schema.crypto.primitives.integrityH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_HASHALGORITHM = _descriptor.EnumDescriptor(
  name='HashAlgorithm',
  full_name='opencannabis.crypto.HashAlgorithm',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHA1', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MD5', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA256', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA384', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SHA512', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MURMUR', index=5, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=258,
  serialized_end=340,
)
_sym_db.RegisterEnumDescriptor(_HASHALGORITHM)

HashAlgorithm = enum_type_wrapper.EnumTypeWrapper(_HASHALGORITHM)
SHA1 = 0
MD5 = 1
SHA256 = 2
SHA384 = 3
SHA512 = 4
MURMUR = 6



_HASH = _descriptor.Descriptor(
  name='Hash',
  full_name='opencannabis.crypto.Hash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='algorithm', full_name='opencannabis.crypto.Hash.algorithm', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.Hash.raw', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hex', full_name='opencannabis.crypto.Hash.hex', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64', full_name='opencannabis.crypto.Hash.b64', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='digest', full_name='opencannabis.crypto.Hash.digest',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=71,
  serialized_end=187,
)


_HASHEDDATA = _descriptor.Descriptor(
  name='HashedData',
  full_name='opencannabis.crypto.HashedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='opencannabis.crypto.HashedData.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hash', full_name='opencannabis.crypto.HashedData.hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=256,
)

_HASH.fields_by_name['algorithm'].enum_type = _HASHALGORITHM
_HASH.oneofs_by_name['digest'].fields.append(
  _HASH.fields_by_name['raw'])
_HASH.fields_by_name['raw'].containing_oneof = _HASH.oneofs_by_name['digest']
_HASH.oneofs_by_name['digest'].fields.append(
  _HASH.fields_by_name['hex'])
_HASH.fields_by_name['hex'].containing_oneof = _HASH.oneofs_by_name['digest']
_HASH.oneofs_by_name['digest'].fields.append(
  _HASH.fields_by_name['b64'])
_HASH.fields_by_name['b64'].containing_oneof = _HASH.oneofs_by_name['digest']
_HASHEDDATA.fields_by_name['hash'].message_type = _HASH
DESCRIPTOR.message_types_by_name['Hash'] = _HASH
DESCRIPTOR.message_types_by_name['HashedData'] = _HASHEDDATA
DESCRIPTOR.enum_types_by_name['HashAlgorithm'] = _HASHALGORITHM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Hash = _reflection.GeneratedProtocolMessageType('Hash', (_message.Message,), {
  'DESCRIPTOR' : _HASH,
  '__module__' : 'opencannabis.crypto.primitives.Integrity_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.Hash)
  })
_sym_db.RegisterMessage(Hash)

HashedData = _reflection.GeneratedProtocolMessageType('HashedData', (_message.Message,), {
  'DESCRIPTOR' : _HASHEDDATA,
  '__module__' : 'opencannabis.crypto.primitives.Integrity_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.HashedData)
  })
_sym_db.RegisterMessage(HashedData)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
