# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/commerce/payments/Payment.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/commerce/payments/Payment.proto',
  package='opencannabis.commerce',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.commerceB\010PaymentsH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n,opencannabis/commerce/payments/Payment.proto\x12\x15opencannabis.commerce*k\n\rPaymentMethod\x12\x08\n\x04\x43\x41SH\x10\x00\x12\t\n\x05\x43HECK\x10\x01\x12\t\n\x05\x44\x45\x42IT\x10\x02\x12\n\n\x06\x43REDIT\x10\x03\x12\x0b\n\x07\x44IGITAL\x10\x04\x12\x07\n\x03\x41\x43H\x10\x05\x12\x08\n\x04WIRE\x10\x06\x12\x0e\n\nBLOCKCHAIN\x10\x07*s\n\x0fPaymentCardType\x12\x10\n\x0cNO_CARD_TYPE\x10\x00\x12\x08\n\x04VISA\x10\x01\x12\x0e\n\nMASTERCARD\x10\x02\x12\x0c\n\x08\x44ISCOVER\x10\x03\x12\x08\n\x04\x41MEX\x10\x04\x12\x0f\n\x0b\x44INERS_CLUB\x10\x05\x12\x0b\n\x07MAESTRO\x10\x06*S\n\x15\x44igitalPaymentNetwork\x12\x17\n\x13UNSPECIFIED_NETWORK\x10\x00\x12\n\n\x06PAYPAL\x10\x01\x12\t\n\x05VENMO\x10\x02\x12\n\n\x06SQUARE\x10\x03*]\n\rPaymentStatus\x12\x12\n\x0eNOT_APPLICABLE\x10\x00\x12\x0b\n\x07WAITING\x10\x01\x12\x11\n\rPREAUTHORIZED\x10\x02\x12\x0b\n\x07\x42OUNCED\x10\x03\x12\x0b\n\x07RETRIED\x10\x04*4\n\nBillStatus\x12\x0c\n\x08SUSPENSE\x10\x00\x12\x0b\n\x07PARTIAL\x10\x03\x12\x0b\n\x07SETTLED\x10\x04\x42\x35\n\x1fio.opencannabis.schema.commerceB\x08PaymentsH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_PAYMENTMETHOD = _descriptor.EnumDescriptor(
  name='PaymentMethod',
  full_name='opencannabis.commerce.PaymentMethod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CASH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHECK', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEBIT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREDIT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DIGITAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACH', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WIRE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLOCKCHAIN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=71,
  serialized_end=178,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTMETHOD)

PaymentMethod = enum_type_wrapper.EnumTypeWrapper(_PAYMENTMETHOD)
_PAYMENTCARDTYPE = _descriptor.EnumDescriptor(
  name='PaymentCardType',
  full_name='opencannabis.commerce.PaymentCardType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_CARD_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VISA', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MASTERCARD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DISCOVER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AMEX', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DINERS_CLUB', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAESTRO', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=180,
  serialized_end=295,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTCARDTYPE)

PaymentCardType = enum_type_wrapper.EnumTypeWrapper(_PAYMENTCARDTYPE)
_DIGITALPAYMENTNETWORK = _descriptor.EnumDescriptor(
  name='DigitalPaymentNetwork',
  full_name='opencannabis.commerce.DigitalPaymentNetwork',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_NETWORK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAYPAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VENMO', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SQUARE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=297,
  serialized_end=380,
)
_sym_db.RegisterEnumDescriptor(_DIGITALPAYMENTNETWORK)

DigitalPaymentNetwork = enum_type_wrapper.EnumTypeWrapper(_DIGITALPAYMENTNETWORK)
_PAYMENTSTATUS = _descriptor.EnumDescriptor(
  name='PaymentStatus',
  full_name='opencannabis.commerce.PaymentStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NOT_APPLICABLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WAITING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PREAUTHORIZED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BOUNCED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RETRIED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=382,
  serialized_end=475,
)
_sym_db.RegisterEnumDescriptor(_PAYMENTSTATUS)

PaymentStatus = enum_type_wrapper.EnumTypeWrapper(_PAYMENTSTATUS)
_BILLSTATUS = _descriptor.EnumDescriptor(
  name='BillStatus',
  full_name='opencannabis.commerce.BillStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUSPENSE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTIAL', index=1, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SETTLED', index=2, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=477,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_BILLSTATUS)

BillStatus = enum_type_wrapper.EnumTypeWrapper(_BILLSTATUS)
CASH = 0
CHECK = 1
DEBIT = 2
CREDIT = 3
DIGITAL = 4
ACH = 5
WIRE = 6
BLOCKCHAIN = 7
NO_CARD_TYPE = 0
VISA = 1
MASTERCARD = 2
DISCOVER = 3
AMEX = 4
DINERS_CLUB = 5
MAESTRO = 6
UNSPECIFIED_NETWORK = 0
PAYPAL = 1
VENMO = 2
SQUARE = 3
NOT_APPLICABLE = 0
WAITING = 1
PREAUTHORIZED = 2
BOUNCED = 3
RETRIED = 4
SUSPENSE = 0
PARTIAL = 3
SETTLED = 4


DESCRIPTOR.enum_types_by_name['PaymentMethod'] = _PAYMENTMETHOD
DESCRIPTOR.enum_types_by_name['PaymentCardType'] = _PAYMENTCARDTYPE
DESCRIPTOR.enum_types_by_name['DigitalPaymentNetwork'] = _DIGITALPAYMENTNETWORK
DESCRIPTOR.enum_types_by_name['PaymentStatus'] = _PAYMENTSTATUS
DESCRIPTOR.enum_types_by_name['BillStatus'] = _BILLSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
