# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Edible.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import MaterialsData_pb2 as opencannabis_dot_content_dot_MaterialsData__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Edible.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\rEdibleProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/products/Edible.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a(opencannabis/content/MaterialsData.proto\x1a)opencannabis/content/ProductContent.proto\"1\n\x10\x45\x64ibleIngredient\x12\r\n\x05label\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"\xe5\x04\n\x06\x45\x64ible\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x30\n\x04type\x18\x02 \x01(\x0e\x32\".opencannabis.products.Edible.Type\x12\x31\n\x05\x66lags\x18\x03 \x03(\x0e\x32\".opencannabis.products.Edible.Flag\x12\x35\n\x07product\x18\x04 \x01(\x0b\x32$.opencannabis.content.ProductContent\x12\x35\n\x08material\x18\x05 \x01(\x0b\x32#.opencannabis.content.MaterialsData\x12<\n\x0bingredients\x18\x06 \x03(\x0b\x32\'.opencannabis.products.EdibleIngredient\"\xad\x01\n\x04Type\x12\x16\n\x12UNSPECIFIED_EDIBLE\x10\x00\x12\r\n\tCHOCOLATE\x10\x01\x12\x0e\n\nBAKED_GOOD\x10\x02\x12\t\n\x05\x43\x41NDY\x10\x03\x12\x0c\n\x08\x42\x45VERAGE\x10\x04\x12\x0b\n\x07LOZENGE\x10\x05\x12\x0e\n\nSUBLINGUAL\x10\x06\x12\t\n\x05GUMMY\x10\x07\x12\n\n\x06\x42UTTER\x10\x08\x12\x08\n\x04OILS\x10\t\x12\n\n\x06\x43\x45REAL\x10\n\x12\x0b\n\x07\x43\x41PSULE\x10\x0b\"n\n\x04\x46lag\x12\x12\n\x0eNO_EDIBLE_FLAG\x10\x00\x12\t\n\x05VEGAN\x10\x01\x12\x0f\n\x0bGLUTEN_FREE\x10\x02\x12\x0e\n\nSUGAR_FREE\x10\x03\x12\x0e\n\nFAIR_TRADE\x10\x04\x12\x0b\n\x07ORGANIC\x10\x05\x12\t\n\x05LOCAL\x10\x06\x42\x39\n\x1eio.opencannabis.schema.productB\rEdibleProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_MaterialsData__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])



_EDIBLE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Edible.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_EDIBLE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CHOCOLATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BAKED_GOOD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CANDY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEVERAGE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOZENGE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUBLINGUAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUMMY', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BUTTER', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OILS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CEREAL', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAPSULE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=562,
  serialized_end=735,
)
_sym_db.RegisterEnumDescriptor(_EDIBLE_TYPE)

_EDIBLE_FLAG = _descriptor.EnumDescriptor(
  name='Flag',
  full_name='opencannabis.products.Edible.Flag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_EDIBLE_FLAG', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEGAN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLUTEN_FREE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUGAR_FREE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FAIR_TRADE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORGANIC', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCAL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=737,
  serialized_end=847,
)
_sym_db.RegisterEnumDescriptor(_EDIBLE_FLAG)


_EDIBLEINGREDIENT = _descriptor.Descriptor(
  name='EdibleIngredient',
  full_name='opencannabis.products.EdibleIngredient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='opencannabis.products.EdibleIngredient.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='opencannabis.products.EdibleIngredient.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=231,
)


_EDIBLE = _descriptor.Descriptor(
  name='Edible',
  full_name='opencannabis.products.Edible',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Edible.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Edible.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.Edible.flags', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Edible.product', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='material', full_name='opencannabis.products.Edible.material', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ingredients', full_name='opencannabis.products.Edible.ingredients', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _EDIBLE_TYPE,
    _EDIBLE_FLAG,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=847,
)

_EDIBLE.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_EDIBLE.fields_by_name['type'].enum_type = _EDIBLE_TYPE
_EDIBLE.fields_by_name['flags'].enum_type = _EDIBLE_FLAG
_EDIBLE.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_EDIBLE.fields_by_name['material'].message_type = opencannabis_dot_content_dot_MaterialsData__pb2._MATERIALSDATA
_EDIBLE.fields_by_name['ingredients'].message_type = _EDIBLEINGREDIENT
_EDIBLE_TYPE.containing_type = _EDIBLE
_EDIBLE_FLAG.containing_type = _EDIBLE
DESCRIPTOR.message_types_by_name['EdibleIngredient'] = _EDIBLEINGREDIENT
DESCRIPTOR.message_types_by_name['Edible'] = _EDIBLE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EdibleIngredient = _reflection.GeneratedProtocolMessageType('EdibleIngredient', (_message.Message,), {
  'DESCRIPTOR' : _EDIBLEINGREDIENT,
  '__module__' : 'opencannabis.products.Edible_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.EdibleIngredient)
  })
_sym_db.RegisterMessage(EdibleIngredient)

Edible = _reflection.GeneratedProtocolMessageType('Edible', (_message.Message,), {
  'DESCRIPTOR' : _EDIBLE,
  '__module__' : 'opencannabis.products.Edible_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Edible)
  })
_sym_db.RegisterMessage(Edible)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
