# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/products/Merchandise.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.content import ProductContent_pb2 as opencannabis_dot_content_dot_ProductContent__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/products/Merchandise.proto',
  package='opencannabis.products',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.productB\022MerchandiseProductH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'opencannabis/products/Merchandise.proto\x12\x15opencannabis.products\x1a\"opencannabis/base/ProductKey.proto\x1a)opencannabis/content/ProductContent.proto\"\xff\x02\n\x0bMerchandise\x12*\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKey\x12\x35\n\x04type\x18\x02 \x01(\x0e\x32\'.opencannabis.products.Merchandise.Type\x12\x35\n\x05\x66lags\x18\x03 \x03(\x0e\x32&.opencannabis.products.MerchandiseFlag\x12\x35\n\x07product\x18\x04 \x01(\x0b\x32$.opencannabis.content.ProductContent\"\x9e\x01\n\x04Type\x12\x1b\n\x17UNSPECIFIED_MERCHANDISE\x10\x00\x12\x0c\n\x08\x43LOTHING\x10\x01\x12\r\n\tGLASSWARE\x10\x02\x12\r\n\tCONTAINER\x10\x03\x12\x0b\n\x07LIGHTER\x10\x04\x12\n\n\x06TSHIRT\x10\x05\x12\n\n\x06HOODIE\x10\x06\x12\x07\n\x03HAT\x10\x07\x12\x13\n\x0b\x41\x43\x43\x45SSORIES\x10\x08\x1a\x02\x08\x01\x12\n\n\x06PAPERS\x10\t*M\n\x0fMerchandiseFlag\x12\x18\n\x14NO_MERCHANDISE_FLAGS\x10\x00\x12\x10\n\x0cMEDICAL_ONLY\x10\x01\x12\x0e\n\nBRAND_SWAG\x10\x02\x42>\n\x1eio.opencannabis.schema.productB\x12MerchandiseProductH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_content_dot_ProductContent__pb2.DESCRIPTOR,])

_MERCHANDISEFLAG = _descriptor.EnumDescriptor(
  name='MerchandiseFlag',
  full_name='opencannabis.products.MerchandiseFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_MERCHANDISE_FLAGS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MEDICAL_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BRAND_SWAG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=531,
  serialized_end=608,
)
_sym_db.RegisterEnumDescriptor(_MERCHANDISEFLAG)

MerchandiseFlag = enum_type_wrapper.EnumTypeWrapper(_MERCHANDISEFLAG)
NO_MERCHANDISE_FLAGS = 0
MEDICAL_ONLY = 1
BRAND_SWAG = 2


_MERCHANDISE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='opencannabis.products.Merchandise.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_MERCHANDISE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLOTHING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GLASSWARE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONTAINER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIGHTER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TSHIRT', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOODIE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAT', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACCESSORIES', index=8, number=8,
      serialized_options=b'\010\001',
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PAPERS', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=371,
  serialized_end=529,
)
_sym_db.RegisterEnumDescriptor(_MERCHANDISE_TYPE)


_MERCHANDISE = _descriptor.Descriptor(
  name='Merchandise',
  full_name='opencannabis.products.Merchandise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.products.Merchandise.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.products.Merchandise.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='flags', full_name='opencannabis.products.Merchandise.flags', index=2,
      number=3, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.products.Merchandise.product', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MERCHANDISE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=146,
  serialized_end=529,
)

_MERCHANDISE.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_MERCHANDISE.fields_by_name['type'].enum_type = _MERCHANDISE_TYPE
_MERCHANDISE.fields_by_name['flags'].enum_type = _MERCHANDISEFLAG
_MERCHANDISE.fields_by_name['product'].message_type = opencannabis_dot_content_dot_ProductContent__pb2._PRODUCTCONTENT
_MERCHANDISE_TYPE.containing_type = _MERCHANDISE
DESCRIPTOR.message_types_by_name['Merchandise'] = _MERCHANDISE
DESCRIPTOR.enum_types_by_name['MerchandiseFlag'] = _MERCHANDISEFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Merchandise = _reflection.GeneratedProtocolMessageType('Merchandise', (_message.Message,), {
  'DESCRIPTOR' : _MERCHANDISE,
  '__module__' : 'opencannabis.products.Merchandise_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.products.Merchandise)
  })
_sym_db.RegisterMessage(Merchandise)


DESCRIPTOR._options = None
_MERCHANDISE_TYPE.values_by_name["ACCESSORIES"]._options = None
# @@protoc_insertion_point(module_scope)
