# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Time.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Time.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalB\014TemporalTimeH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/temporal/Time.proto\x12\x15opencannabis.temporal\"!\n\x04Time\x12\x11\n\x07iso8601\x18\x01 \x01(\tH\x00\x42\x06\n\x04specB9\n\x1fio.opencannabis.schema.temporalB\x0cTemporalTimeH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)




_TIME = _descriptor.Descriptor(
  name='Time',
  full_name='opencannabis.temporal.Time',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iso8601', full_name='opencannabis.temporal.Time.iso8601', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.temporal.Time.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=59,
  serialized_end=92,
)

_TIME.oneofs_by_name['spec'].fields.append(
  _TIME.fields_by_name['iso8601'])
_TIME.fields_by_name['iso8601'].containing_oneof = _TIME.oneofs_by_name['spec']
DESCRIPTOR.message_types_by_name['Time'] = _TIME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Time = _reflection.GeneratedProtocolMessageType('Time', (_message.Message,), {
  'DESCRIPTOR' : _TIME,
  '__module__' : 'opencannabis.temporal.Time_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Time)
  })
_sym_db.RegisterMessage(Time)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
