# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/temporal/Duration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/temporal/Duration.proto',
  package='opencannabis.temporal',
  syntax='proto3',
  serialized_options=b'\n\037io.opencannabis.schema.temporalH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$opencannabis/temporal/Duration.proto\x12\x15opencannabis.temporal\x1a\x19gust/core/datamodel.proto\"I\n\x08\x44uration\x12-\n\x04unit\x18\x01 \x01(\x0e\x32\x1f.opencannabis.temporal.TimeUnit\x12\x0e\n\x06\x61mount\x18\x02 \x01(\r*\x7f\n\x08TimeUnit\x12\x10\n\x0cMILLISECONDS\x10\x00\x12\x10\n\x0cMICROSECONDS\x10\x01\x12\x0b\n\x07SECONDS\x10\x02\x12\x0b\n\x07MINUTES\x10\x03\x12\t\n\x05HOURS\x10\x04\x12\x08\n\x04\x44\x41YS\x10\x05\x12\t\n\x05WEEKS\x10\x06\x12\n\n\x06MONTHS\x10\x07\x12\t\n\x05YEARS\x10\x08\x42+\n\x1fio.opencannabis.schema.temporalH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_TIMEUNIT = _descriptor.EnumDescriptor(
  name='TimeUnit',
  full_name='opencannabis.temporal.TimeUnit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MILLISECONDS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MICROSECONDS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SECONDS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MINUTES', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOURS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAYS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEKS', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTHS', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YEARS', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=165,
  serialized_end=292,
)
_sym_db.RegisterEnumDescriptor(_TIMEUNIT)

TimeUnit = enum_type_wrapper.EnumTypeWrapper(_TIMEUNIT)
MILLISECONDS = 0
MICROSECONDS = 1
SECONDS = 2
MINUTES = 3
HOURS = 4
DAYS = 5
WEEKS = 6
MONTHS = 7
YEARS = 8



_DURATION = _descriptor.Descriptor(
  name='Duration',
  full_name='opencannabis.temporal.Duration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.temporal.Duration.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='opencannabis.temporal.Duration.amount', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=163,
)

_DURATION.fields_by_name['unit'].enum_type = _TIMEUNIT
DESCRIPTOR.message_types_by_name['Duration'] = _DURATION
DESCRIPTOR.enum_types_by_name['TimeUnit'] = _TIMEUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Duration = _reflection.GeneratedProtocolMessageType('Duration', (_message.Message,), {
  'DESCRIPTOR' : _DURATION,
  '__module__' : 'opencannabis.temporal.Duration_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.temporal.Duration)
  })
_sym_db.RegisterMessage(Duration)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
