# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Location.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.geo import Point_pb2 as opencannabis_dot_geo_dot_Point__pb2
from opencannabis.geo import Address_pb2 as opencannabis_dot_geo_dot_Address__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Location.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/geo/Location.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\x1a\x1copencannabis/geo/Point.proto\x1a\x1eopencannabis/geo/Address.proto\x1a\x1fopencannabis/geo/Distance.proto\x1a\x1fopencannabis/content/Name.proto\"\x87\x03\n\x08Location\x12V\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.NameB,\xc2\xb5\x03(\x12&Name for this location, if applicable.\x12[\n\x07\x61\x64\x64ress\x18\x02 \x01(\x0b\x32\x19.opencannabis.geo.AddressB/\xc2\xb5\x03+\x12)Address for this location, if applicable.\x12^\n\x05point\x18\x03 \x01(\x0b\x32\x17.opencannabis.geo.PointB6\xc2\xb5\x03\x32\x12\x30Geopoint (latitude/longitude) for this location.\x12\x66\n\x08\x61\x63\x63uracy\x18\x04 \x01(\x0b\x32\".opencannabis.geo.LocationAccuracyB0\xc2\xb5\x03,\x12*Specifies the accuracy estimate, if known.B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Point__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Address__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,])




_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='opencannabis.geo.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.geo.Location.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003(\022&Name for this location, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='opencannabis.geo.Location.address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003+\022)Address for this location, if applicable.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='point', full_name='opencannabis.geo.Location.point', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0032\0220Geopoint (latitude/longitude) for this location.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Location.accuracy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Specifies the accuracy estimate, if known.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=600,
)

_LOCATION.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_LOCATION.fields_by_name['address'].message_type = opencannabis_dot_geo_dot_Address__pb2._ADDRESS
_LOCATION.fields_by_name['point'].message_type = opencannabis_dot_geo_dot_Point__pb2._POINT
_LOCATION.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._LOCATIONACCURACY
DESCRIPTOR.message_types_by_name['Location'] = _LOCATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), {
  'DESCRIPTOR' : _LOCATION,
  '__module__' : 'opencannabis.geo.Location_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Location)
  })
_sym_db.RegisterMessage(Location)


DESCRIPTOR._options = None
_LOCATION.fields_by_name['name']._options = None
_LOCATION.fields_by_name['address']._options = None
_LOCATION.fields_by_name['point']._options = None
_LOCATION.fields_by_name['accuracy']._options = None
# @@protoc_insertion_point(module_scope)
