# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Colors.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Colors.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\006ColorsH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!opencannabis/content/Colors.proto\x12\x14opencannabis.content\";\n\rRGBAColorSpec\x12\t\n\x01r\x18\x01 \x01(\x04\x12\t\n\x01g\x18\x02 \x01(\x04\x12\t\n\x01\x62\x18\x03 \x01(\x04\x12\t\n\x01\x61\x18\x04 \x01(\x04\"/\n\x0cHSBColorSpec\x12\t\n\x01h\x18\x01 \x01(\x04\x12\t\n\x01s\x18\x02 \x01(\x04\x12\t\n\x01\x62\x18\x03 \x01(\x04\";\n\rCMYKColorSpec\x12\t\n\x01\x63\x18\x01 \x01(\x04\x12\t\n\x01m\x18\x02 \x01(\x04\x12\t\n\x01y\x18\x03 \x01(\x04\x12\t\n\x01k\x18\x04 \x01(\x04\"\xf4\x01\n\x05\x43olor\x12\x37\n\x08standard\x18\x01 \x01(\x0e\x32#.opencannabis.content.StandardColorH\x00\x12\r\n\x03hex\x18\x02 \x01(\tH\x00\x12\x33\n\x04rgba\x18\x03 \x01(\x0b\x32#.opencannabis.content.RGBAColorSpecH\x00\x12\x31\n\x03hsb\x18\x04 \x01(\x0b\x32\".opencannabis.content.HSBColorSpecH\x00\x12\x33\n\x04\x63myk\x18\x05 \x01(\x0b\x32#.opencannabis.content.CMYKColorSpecH\x00\x42\x06\n\x04spec\"\xc4\x01\n\x0b\x43olorScheme\x12,\n\x07primary\x18\x01 \x01(\x0b\x32\x1b.opencannabis.content.Color\x12.\n\tsecondary\x18\x02 \x01(\x0b\x32\x1b.opencannabis.content.Color\x12*\n\x05\x61lert\x18\x03 \x01(\x0b\x32\x1b.opencannabis.content.Color\x12+\n\x06shades\x18\x04 \x03(\x0b\x32\x1b.opencannabis.content.Color*\x87\x01\n\rStandardColor\x12\x15\n\x11UNSPECIFIED_COLOR\x10\x00\x12\x07\n\x03RED\x10\x01\x12\t\n\x05GREEN\x10\x02\x12\x08\n\x04\x42LUE\x10\x03\x12\n\n\x06YELLOW\x10\x04\x12\n\n\x06PURPLE\x10\x05\x12\n\n\x06ORANGE\x10\x06\x12\x08\n\x04PINK\x10\x07\x12\x08\n\x04GRAY\x10\x08\x12\t\n\x05\x42ROWN\x10\tB2\n\x1eio.opencannabis.schema.contentB\x06\x43olorsH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_STANDARDCOLOR = _descriptor.EnumDescriptor(
  name='StandardColor',
  full_name='opencannabis.content.StandardColor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_COLOR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLUE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PURPLE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORANGE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PINK', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRAY', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROWN', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=677,
  serialized_end=812,
)
_sym_db.RegisterEnumDescriptor(_STANDARDCOLOR)

StandardColor = enum_type_wrapper.EnumTypeWrapper(_STANDARDCOLOR)
UNSPECIFIED_COLOR = 0
RED = 1
GREEN = 2
BLUE = 3
YELLOW = 4
PURPLE = 5
ORANGE = 6
PINK = 7
GRAY = 8
BROWN = 9



_RGBACOLORSPEC = _descriptor.Descriptor(
  name='RGBAColorSpec',
  full_name='opencannabis.content.RGBAColorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='r', full_name='opencannabis.content.RGBAColorSpec.r', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='g', full_name='opencannabis.content.RGBAColorSpec.g', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='opencannabis.content.RGBAColorSpec.b', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='a', full_name='opencannabis.content.RGBAColorSpec.a', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=118,
)


_HSBCOLORSPEC = _descriptor.Descriptor(
  name='HSBColorSpec',
  full_name='opencannabis.content.HSBColorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='h', full_name='opencannabis.content.HSBColorSpec.h', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='s', full_name='opencannabis.content.HSBColorSpec.s', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b', full_name='opencannabis.content.HSBColorSpec.b', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=120,
  serialized_end=167,
)


_CMYKCOLORSPEC = _descriptor.Descriptor(
  name='CMYKColorSpec',
  full_name='opencannabis.content.CMYKColorSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='c', full_name='opencannabis.content.CMYKColorSpec.c', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='m', full_name='opencannabis.content.CMYKColorSpec.m', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='opencannabis.content.CMYKColorSpec.y', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='k', full_name='opencannabis.content.CMYKColorSpec.k', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=228,
)


_COLOR = _descriptor.Descriptor(
  name='Color',
  full_name='opencannabis.content.Color',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='standard', full_name='opencannabis.content.Color.standard', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hex', full_name='opencannabis.content.Color.hex', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rgba', full_name='opencannabis.content.Color.rgba', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hsb', full_name='opencannabis.content.Color.hsb', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cmyk', full_name='opencannabis.content.Color.cmyk', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='spec', full_name='opencannabis.content.Color.spec',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=231,
  serialized_end=475,
)


_COLORSCHEME = _descriptor.Descriptor(
  name='ColorScheme',
  full_name='opencannabis.content.ColorScheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary', full_name='opencannabis.content.ColorScheme.primary', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary', full_name='opencannabis.content.ColorScheme.secondary', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alert', full_name='opencannabis.content.ColorScheme.alert', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shades', full_name='opencannabis.content.ColorScheme.shades', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=478,
  serialized_end=674,
)

_COLOR.fields_by_name['standard'].enum_type = _STANDARDCOLOR
_COLOR.fields_by_name['rgba'].message_type = _RGBACOLORSPEC
_COLOR.fields_by_name['hsb'].message_type = _HSBCOLORSPEC
_COLOR.fields_by_name['cmyk'].message_type = _CMYKCOLORSPEC
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['standard'])
_COLOR.fields_by_name['standard'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['hex'])
_COLOR.fields_by_name['hex'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['rgba'])
_COLOR.fields_by_name['rgba'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['hsb'])
_COLOR.fields_by_name['hsb'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLOR.oneofs_by_name['spec'].fields.append(
  _COLOR.fields_by_name['cmyk'])
_COLOR.fields_by_name['cmyk'].containing_oneof = _COLOR.oneofs_by_name['spec']
_COLORSCHEME.fields_by_name['primary'].message_type = _COLOR
_COLORSCHEME.fields_by_name['secondary'].message_type = _COLOR
_COLORSCHEME.fields_by_name['alert'].message_type = _COLOR
_COLORSCHEME.fields_by_name['shades'].message_type = _COLOR
DESCRIPTOR.message_types_by_name['RGBAColorSpec'] = _RGBACOLORSPEC
DESCRIPTOR.message_types_by_name['HSBColorSpec'] = _HSBCOLORSPEC
DESCRIPTOR.message_types_by_name['CMYKColorSpec'] = _CMYKCOLORSPEC
DESCRIPTOR.message_types_by_name['Color'] = _COLOR
DESCRIPTOR.message_types_by_name['ColorScheme'] = _COLORSCHEME
DESCRIPTOR.enum_types_by_name['StandardColor'] = _STANDARDCOLOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RGBAColorSpec = _reflection.GeneratedProtocolMessageType('RGBAColorSpec', (_message.Message,), {
  'DESCRIPTOR' : _RGBACOLORSPEC,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.RGBAColorSpec)
  })
_sym_db.RegisterMessage(RGBAColorSpec)

HSBColorSpec = _reflection.GeneratedProtocolMessageType('HSBColorSpec', (_message.Message,), {
  'DESCRIPTOR' : _HSBCOLORSPEC,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.HSBColorSpec)
  })
_sym_db.RegisterMessage(HSBColorSpec)

CMYKColorSpec = _reflection.GeneratedProtocolMessageType('CMYKColorSpec', (_message.Message,), {
  'DESCRIPTOR' : _CMYKCOLORSPEC,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.CMYKColorSpec)
  })
_sym_db.RegisterMessage(CMYKColorSpec)

Color = _reflection.GeneratedProtocolMessageType('Color', (_message.Message,), {
  'DESCRIPTOR' : _COLOR,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Color)
  })
_sym_db.RegisterMessage(Color)

ColorScheme = _reflection.GeneratedProtocolMessageType('ColorScheme', (_message.Message,), {
  'DESCRIPTOR' : _COLORSCHEME,
  '__module__' : 'opencannabis.content.Colors_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.ColorScheme)
  })
_sym_db.RegisterMessage(ColorScheme)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
