# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Distance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Distance.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/geo/Distance.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\"\xc4\x01\n\x10LocationAccuracy\x12N\n\x08\x65stimate\x18\x01 \x01(\x08\x42<\xc2\xb5\x03\x38\x12\x36Specifies whether this accuracy rating is an estimate.\x12`\n\x05value\x18\x02 \x01(\x0b\x32\x1f.opencannabis.geo.DistanceValueB0\xc2\xb5\x03,\x12*Distance value for the accuracy specified.\"\xaf\x01\n\rDistanceValue\x12q\n\x04unit\x18\x01 \x01(\x0e\x32\x1e.opencannabis.geo.DistanceUnitBC\xc2\xb5\x03?\x12=Specifies the unit of measurement employed for this distance.\x12+\n\x05value\x18\x03 \x01(\x01\x42\x1c\xc2\xb5\x03\x18\x12\x16\x41\x63tual distance value.\"\xb8\x02\n\x08\x44istance\x12G\n\x08\x65stimate\x18\x01 \x01(\x08\x42\x35\xc2\xb5\x03\x31\x12/Specifies whether this distance is an estimate.\x12~\n\x08\x61\x63\x63uracy\x18\x02 \x01(\x0b\x32\".opencannabis.geo.LocationAccuracyBH\xc2\xb5\x03\x44\x12\x42Specifies the accuracy estimate for the distance values, if known.\x12\x63\n\x04unit\x18\x03 \x01(\x0e\x32\x1e.opencannabis.geo.DistanceUnitB5\xc2\xb5\x03\x31\x12/Specifies whether this distance is an estimate.*m\n\x0c\x44istanceUnit\x12\n\n\x06METERS\x10\x00\x12\n\n\x06INCHES\x10\x01\x12\x08\n\x04\x46\x45\x45T\x10\x02\x12\x0f\n\x0bMILLIMETERS\x10\x03\x12\x0f\n\x0b\x43\x45NTIMETERS\x10\x04\x12\x0e\n\nKILOMETERS\x10\x05\x12\t\n\x05MILES\x10\x06\x42&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_DISTANCEUNIT = _descriptor.EnumDescriptor(
  name='DistanceUnit',
  full_name='opencannabis.geo.DistanceUnit',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='METERS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INCHES', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FEET', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILLIMETERS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CENTIMETERS', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='KILOMETERS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MILES', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=772,
  serialized_end=881,
)
_sym_db.RegisterEnumDescriptor(_DISTANCEUNIT)

DistanceUnit = enum_type_wrapper.EnumTypeWrapper(_DISTANCEUNIT)
METERS = 0
INCHES = 1
FEET = 2
MILLIMETERS = 3
CENTIMETERS = 4
KILOMETERS = 5
MILES = 6



_LOCATIONACCURACY = _descriptor.Descriptor(
  name='LocationAccuracy',
  full_name='opencannabis.geo.LocationAccuracy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='estimate', full_name='opencannabis.geo.LocationAccuracy.estimate', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0038\0226Specifies whether this accuracy rating is an estimate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.geo.LocationAccuracy.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Distance value for the accuracy specified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=277,
)


_DISTANCEVALUE = _descriptor.Descriptor(
  name='DistanceValue',
  full_name='opencannabis.geo.DistanceValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.geo.DistanceValue.unit', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003?\022=Specifies the unit of measurement employed for this distance.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='opencannabis.geo.DistanceValue.value', index=1,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\030\022\026Actual distance value.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=280,
  serialized_end=455,
)


_DISTANCE = _descriptor.Descriptor(
  name='Distance',
  full_name='opencannabis.geo.Distance',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='estimate', full_name='opencannabis.geo.Distance.estimate', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Specifies whether this distance is an estimate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Distance.accuracy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003D\022BSpecifies the accuracy estimate for the distance values, if known.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.geo.Distance.unit', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Specifies whether this distance is an estimate.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=458,
  serialized_end=770,
)

_LOCATIONACCURACY.fields_by_name['value'].message_type = _DISTANCEVALUE
_DISTANCEVALUE.fields_by_name['unit'].enum_type = _DISTANCEUNIT
_DISTANCE.fields_by_name['accuracy'].message_type = _LOCATIONACCURACY
_DISTANCE.fields_by_name['unit'].enum_type = _DISTANCEUNIT
DESCRIPTOR.message_types_by_name['LocationAccuracy'] = _LOCATIONACCURACY
DESCRIPTOR.message_types_by_name['DistanceValue'] = _DISTANCEVALUE
DESCRIPTOR.message_types_by_name['Distance'] = _DISTANCE
DESCRIPTOR.enum_types_by_name['DistanceUnit'] = _DISTANCEUNIT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LocationAccuracy = _reflection.GeneratedProtocolMessageType('LocationAccuracy', (_message.Message,), {
  'DESCRIPTOR' : _LOCATIONACCURACY,
  '__module__' : 'opencannabis.geo.Distance_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.LocationAccuracy)
  })
_sym_db.RegisterMessage(LocationAccuracy)

DistanceValue = _reflection.GeneratedProtocolMessageType('DistanceValue', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCEVALUE,
  '__module__' : 'opencannabis.geo.Distance_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.DistanceValue)
  })
_sym_db.RegisterMessage(DistanceValue)

Distance = _reflection.GeneratedProtocolMessageType('Distance', (_message.Message,), {
  'DESCRIPTOR' : _DISTANCE,
  '__module__' : 'opencannabis.geo.Distance_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Distance)
  })
_sym_db.RegisterMessage(Distance)


DESCRIPTOR._options = None
_LOCATIONACCURACY.fields_by_name['estimate']._options = None
_LOCATIONACCURACY.fields_by_name['value']._options = None
_DISTANCEVALUE.fields_by_name['unit']._options = None
_DISTANCEVALUE.fields_by_name['value']._options = None
_DISTANCE.fields_by_name['estimate']._options = None
_DISTANCE.fields_by_name['accuracy']._options = None
_DISTANCE.fields_by_name['unit']._options = None
# @@protoc_insertion_point(module_scope)
