# ~*~ coding: utf-8 ~*~

__doc__ = """

  OpenCannabis SDK for Python
  ---------------------------

  This library contains interfaces and objects for leveraging the OpenCannabis Specification
  and accompanying Protocol Definitions in Python.

"""

# Deps
from gust import core as gust
