# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/base/ProductKey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.base import ProductKind_pb2 as opencannabis_dot_base_dot_ProductKind__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/base/ProductKey.proto',
  package='opencannabis.base',
  syntax='proto3',
  serialized_options=b'\n\033io.opencannabis.schema.baseB\016BaseProductKeyH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/base/ProductKey.proto\x12\x11opencannabis.base\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/content/Name.proto\x1a#opencannabis/base/ProductKind.proto\"\xc2\x01\n\x10ProductReference\x12P\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.NameB&\xc2\xb5\x03\"\x12 Specifies the name of a product.\x12\\\n\x03key\x18\x02 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB0\xc2\xb5\x03,\x12*Specifies the key, if known, of a product.\"\xf4\x01\n\nProductKey\x12Y\n\x02id\x18\x01 \x01(\tBM\xc2\xb5\x03\x02\x08\x02\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03=\x12;Product ID, an opaque string that is usually autogenerated.\x12\x8a\x01\n\x04type\x18\x02 \x01(\x0e\x32\x1e.opencannabis.base.ProductKindB\\\xc2\xb5\x03\x02\x38\x01\xc2\xb5\x03R\x12PType of product the ID is referring to. In most cases this entry can be omitted.B7\n\x1bio.opencannabis.schema.baseB\x0e\x42\x61seProductKeyH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKind__pb2.DESCRIPTOR,])




_PRODUCTREFERENCE = _descriptor.Descriptor(
  name='ProductReference',
  full_name='opencannabis.base.ProductReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.base.ProductReference.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Specifies the name of a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.base.ProductReference.key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003,\022*Specifies the key, if known, of a product.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=349,
)


_PRODUCTKEY = _descriptor.Descriptor(
  name='ProductKey',
  full_name='opencannabis.base.ProductKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='opencannabis.base.ProductKey.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\332\265\003\002\020\001\302\265\003=\022;Product ID, an opaque string that is usually autogenerated.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.base.ProductKey.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\0028\001\302\265\003R\022PType of product the ID is referring to. In most cases this entry can be omitted.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=596,
)

_PRODUCTREFERENCE.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_PRODUCTREFERENCE.fields_by_name['key'].message_type = _PRODUCTKEY
_PRODUCTKEY.fields_by_name['type'].enum_type = opencannabis_dot_base_dot_ProductKind__pb2._PRODUCTKIND
DESCRIPTOR.message_types_by_name['ProductReference'] = _PRODUCTREFERENCE
DESCRIPTOR.message_types_by_name['ProductKey'] = _PRODUCTKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProductReference = _reflection.GeneratedProtocolMessageType('ProductReference', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTREFERENCE,
  '__module__' : 'opencannabis.base.ProductKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.base.ProductReference)
  })
_sym_db.RegisterMessage(ProductReference)

ProductKey = _reflection.GeneratedProtocolMessageType('ProductKey', (_message.Message,), {
  'DESCRIPTOR' : _PRODUCTKEY,
  '__module__' : 'opencannabis.base.ProductKey_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.base.ProductKey)
  })
_sym_db.RegisterMessage(ProductKey)


DESCRIPTOR._options = None
_PRODUCTREFERENCE.fields_by_name['name']._options = None
_PRODUCTREFERENCE.fields_by_name['key']._options = None
_PRODUCTKEY.fields_by_name['id']._options = None
_PRODUCTKEY.fields_by_name['type']._options = None
# @@protoc_insertion_point(module_scope)
