# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.inventory.rfid`
  --------------------------------
  Definitions related to RFID-powered inventory (typically over LLRP).

"""

# `opencannabis.inventory.rfid`
