# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/InventoryProduct.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2
from opencannabis.commerce import Item_pb2 as opencannabis_dot_commerce_dot_Item__pb2
from opencannabis.products.menu import Menu_pb2 as opencannabis_dot_products_dot_menu_dot_Menu__pb2
from opencannabis.structs.pricing import PricingDescriptor_pb2 as opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/InventoryProduct.proto',
  package='opencannabis.inventory',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-opencannabis/inventory/InventoryProduct.proto\x12\x16opencannabis.inventory\x1a\x19gust/core/datamodel.proto\x1a\"opencannabis/base/ProductKey.proto\x1a#opencannabis/temporal/Instant.proto\x1a opencannabis/commerce/Item.proto\x1a%opencannabis/products/menu/Menu.proto\x1a\x34opencannabis/structs/pricing/PricingDescriptor.proto\"P\n\x0cInventoryKey\x12\x32\n\x03key\x18\x01 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyB\x06\xc2\xb5\x03\x02\x08\x01\x12\x0c\n\x04uuid\x18\x02 \x01(\t\"o\n\x14InventoryCoordinates\x12\x10\n\x08location\x18\x01 \x01(\t\x12\x0c\n\x04zone\x18\x02 \x01(\t\x12\x0c\n\x04rack\x18\x03 \x01(\t\x12\r\n\x05shelf\x18\x04 \x01(\t\x12\x0b\n\x03\x62in\x18\x05 \x01(\t\x12\r\n\x05\x62\x61tch\x18\x06 \x01(\t\"\xb8\x01\n\x0fInventoryAmount\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).opencannabis.structs.pricing.PricingType\x12\x0e\n\x04unit\x18\x02 \x01(\x08H\x00\x12\x41\n\x06weight\x18\x03 \x01(\x0e\x32/.opencannabis.structs.pricing.PricingWeightTierH\x00\x12\x10\n\x08quantity\x18\x04 \x01(\x04\x42\x07\n\x05\x62\x61sis\"\xb6\x03\n\x0eInventoryState\x12=\n\x06status\x18\x01 \x01(\x0e\x32-.opencannabis.inventory.InventoryState.Status\x12\x41\n\x0b\x63oordinates\x18\x02 \x01(\x0b\x32,.opencannabis.inventory.InventoryCoordinates\x12\x14\n\x0c\x66it_for_sale\x18\x03 \x01(\x08\x12\x37\n\x06\x61mount\x18\x04 \x01(\x0b\x32\'.opencannabis.inventory.InventoryAmount\x12/\n\x07\x63reated\x18\x62 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\x12\x30\n\x08modified\x18\x63 \x01(\x0b\x32\x1e.opencannabis.temporal.Instant\"p\n\x06Status\x12\x10\n\x0cUNRECONCILED\x10\x00\x12\r\n\tRECEIVING\x10\x01\x12\x0e\n\nQUARANTINE\x10\x02\x12\x0b\n\x07ON_HAND\x10\x03\x12\x0c\n\x08\x46OR_SALE\x10\x04\x12\x0b\n\x07\x43LAIMED\x10\x05\x12\r\n\tCOMMITTED\x10\x06\"\xc1\x02\n\x10InventoryProduct\x12\x31\n\x03key\x18\x01 \x01(\x0b\x32$.opencannabis.inventory.InventoryKey\x12\x0b\n\x03sku\x18\x02 \x03(\t\x12\x33\n\x07variant\x18\x03 \x03(\x0b\x32\".opencannabis.commerce.VariantSpec\x12\x35\n\x05state\x18\n \x01(\x0b\x32&.opencannabis.inventory.InventoryState\x12\x37\n\x07history\x18\x0b \x03(\x0b\x32&.opencannabis.inventory.InventoryState\x12\x35\n\x04item\x18\x14 \x01(\x0b\x32\'.opencannabis.products.menu.MenuProduct:\x11\x8a\xf7\x02\r\x08\x02\x12\tinventoryB,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,opencannabis_dot_commerce_dot_Item__pb2.DESCRIPTOR,opencannabis_dot_products_dot_menu_dot_Menu__pb2.DESCRIPTOR,opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2.DESCRIPTOR,])



_INVENTORYSTATE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='opencannabis.inventory.InventoryState.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNRECONCILED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RECEIVING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARANTINE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ON_HAND', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FOR_SALE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CLAIMED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMITTED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1009,
  serialized_end=1121,
)
_sym_db.RegisterEnumDescriptor(_INVENTORYSTATE_STATUS)


_INVENTORYKEY = _descriptor.Descriptor(
  name='InventoryKey',
  full_name='opencannabis.inventory.InventoryKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.inventory.InventoryKey.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='opencannabis.inventory.InventoryKey.uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=300,
  serialized_end=380,
)


_INVENTORYCOORDINATES = _descriptor.Descriptor(
  name='InventoryCoordinates',
  full_name='opencannabis.inventory.InventoryCoordinates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.inventory.InventoryCoordinates.location', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone', full_name='opencannabis.inventory.InventoryCoordinates.zone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rack', full_name='opencannabis.inventory.InventoryCoordinates.rack', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shelf', full_name='opencannabis.inventory.InventoryCoordinates.shelf', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bin', full_name='opencannabis.inventory.InventoryCoordinates.bin', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch', full_name='opencannabis.inventory.InventoryCoordinates.batch', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=382,
  serialized_end=493,
)


_INVENTORYAMOUNT = _descriptor.Descriptor(
  name='InventoryAmount',
  full_name='opencannabis.inventory.InventoryAmount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.inventory.InventoryAmount.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='opencannabis.inventory.InventoryAmount.unit', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='weight', full_name='opencannabis.inventory.InventoryAmount.weight', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='opencannabis.inventory.InventoryAmount.quantity', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='basis', full_name='opencannabis.inventory.InventoryAmount.basis',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=496,
  serialized_end=680,
)


_INVENTORYSTATE = _descriptor.Descriptor(
  name='InventoryState',
  full_name='opencannabis.inventory.InventoryState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.inventory.InventoryState.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='coordinates', full_name='opencannabis.inventory.InventoryState.coordinates', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fit_for_sale', full_name='opencannabis.inventory.InventoryState.fit_for_sale', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='opencannabis.inventory.InventoryState.amount', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.inventory.InventoryState.created', index=4,
      number=98, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='opencannabis.inventory.InventoryState.modified', index=5,
      number=99, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INVENTORYSTATE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=1121,
)


_INVENTORYPRODUCT = _descriptor.Descriptor(
  name='InventoryProduct',
  full_name='opencannabis.inventory.InventoryProduct',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.inventory.InventoryProduct.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sku', full_name='opencannabis.inventory.InventoryProduct.sku', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='variant', full_name='opencannabis.inventory.InventoryProduct.variant', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='state', full_name='opencannabis.inventory.InventoryProduct.state', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history', full_name='opencannabis.inventory.InventoryProduct.history', index=4,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='opencannabis.inventory.InventoryProduct.item', index=5,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\r\010\002\022\tinventory',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1124,
  serialized_end=1445,
)

_INVENTORYKEY.fields_by_name['key'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_INVENTORYAMOUNT.fields_by_name['type'].enum_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRICINGTYPE
_INVENTORYAMOUNT.fields_by_name['weight'].enum_type = opencannabis_dot_structs_dot_pricing_dot_PricingDescriptor__pb2._PRICINGWEIGHTTIER
_INVENTORYAMOUNT.oneofs_by_name['basis'].fields.append(
  _INVENTORYAMOUNT.fields_by_name['unit'])
_INVENTORYAMOUNT.fields_by_name['unit'].containing_oneof = _INVENTORYAMOUNT.oneofs_by_name['basis']
_INVENTORYAMOUNT.oneofs_by_name['basis'].fields.append(
  _INVENTORYAMOUNT.fields_by_name['weight'])
_INVENTORYAMOUNT.fields_by_name['weight'].containing_oneof = _INVENTORYAMOUNT.oneofs_by_name['basis']
_INVENTORYSTATE.fields_by_name['status'].enum_type = _INVENTORYSTATE_STATUS
_INVENTORYSTATE.fields_by_name['coordinates'].message_type = _INVENTORYCOORDINATES
_INVENTORYSTATE.fields_by_name['amount'].message_type = _INVENTORYAMOUNT
_INVENTORYSTATE.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_INVENTORYSTATE.fields_by_name['modified'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_INVENTORYSTATE_STATUS.containing_type = _INVENTORYSTATE
_INVENTORYPRODUCT.fields_by_name['key'].message_type = _INVENTORYKEY
_INVENTORYPRODUCT.fields_by_name['variant'].message_type = opencannabis_dot_commerce_dot_Item__pb2._VARIANTSPEC
_INVENTORYPRODUCT.fields_by_name['state'].message_type = _INVENTORYSTATE
_INVENTORYPRODUCT.fields_by_name['history'].message_type = _INVENTORYSTATE
_INVENTORYPRODUCT.fields_by_name['item'].message_type = opencannabis_dot_products_dot_menu_dot_Menu__pb2._MENUPRODUCT
DESCRIPTOR.message_types_by_name['InventoryKey'] = _INVENTORYKEY
DESCRIPTOR.message_types_by_name['InventoryCoordinates'] = _INVENTORYCOORDINATES
DESCRIPTOR.message_types_by_name['InventoryAmount'] = _INVENTORYAMOUNT
DESCRIPTOR.message_types_by_name['InventoryState'] = _INVENTORYSTATE
DESCRIPTOR.message_types_by_name['InventoryProduct'] = _INVENTORYPRODUCT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InventoryKey = _reflection.GeneratedProtocolMessageType('InventoryKey', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYKEY,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryKey)
  })
_sym_db.RegisterMessage(InventoryKey)

InventoryCoordinates = _reflection.GeneratedProtocolMessageType('InventoryCoordinates', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYCOORDINATES,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryCoordinates)
  })
_sym_db.RegisterMessage(InventoryCoordinates)

InventoryAmount = _reflection.GeneratedProtocolMessageType('InventoryAmount', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYAMOUNT,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryAmount)
  })
_sym_db.RegisterMessage(InventoryAmount)

InventoryState = _reflection.GeneratedProtocolMessageType('InventoryState', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYSTATE,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryState)
  })
_sym_db.RegisterMessage(InventoryState)

InventoryProduct = _reflection.GeneratedProtocolMessageType('InventoryProduct', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYPRODUCT,
  '__module__' : 'opencannabis.inventory.InventoryProduct_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.InventoryProduct)
  })
_sym_db.RegisterMessage(InventoryProduct)


DESCRIPTOR._options = None
_INVENTORYKEY.fields_by_name['key']._options = None
_INVENTORYPRODUCT._options = None
# @@protoc_insertion_point(module_scope)
