# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/inventory/rfid/RFID.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/inventory/rfid/RFID.proto',
  package='opencannabis.inventory.rfid',
  syntax='proto3',
  serialized_options=b'\n io.opencannabis.schema.inventoryH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&opencannabis/inventory/rfid/RFID.proto\x12\x1bopencannabis.inventory.rfid\x1a\x19gust/core/datamodel.proto\"\x89\x04\n\x06Reader\x12]\n\x04name\x18\x01 \x01(\tBO\xc2\xb5\x03K\x12ICanonical label/name for the reader device involved in an RFID operation.\x12X\n\x03mac\x18\x02 \x01(\tBK\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x41\x12?MAC address of the reader device involved in an RFID operation.\x12P\n\x02ip\x18\x03 \x01(\tBD\xc2\xb5\x03@\x12>IP address of the reader device involved in an RFID operation.\x12{\n\x06vendor\x18\x04 \x01(\x0e\x32).opencannabis.inventory.rfid.ReaderVendorB@\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x36\x12\x34Vendor for the reader involved in an RFID operation.\x12w\n\x05model\x18\x05 \x01(\x0e\x32(.opencannabis.inventory.rfid.ReaderModelB>\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03\x34\x12\x32Model of the reader involved in an RFID operation.\"X\n\x07\x41ntenna\x12M\n\x05index\x18\x01 \x01(\rB>\xc2\xb5\x03:\x12\x38Port index for the antenna that produced some operation.\"\x85\x02\n\x03Tag\x12\\\n\x03tid\x18\x01 \x01(\tBO\xc2\xb5\x03K\x12ITag ID, assigned to the tag at manufacturing time and never over-written.\x12>\n\x07payload\x18\x02 \x01(\x0c\x42-\xca\xb5\x03\x02\x10\x01\xc2\xb5\x03#\x12!Raw content encoded onto the tag.\x12U\n\x03\x65pc\x18\n \x01(\tBF\xda\xb5\x03\x02\x10\x01\xc2\xb5\x03<\x12:Electronic Product Code (EPC) that was present on the tag.H\x00\x42\t\n\x07\x63ontent*@\n\x0cReaderVendor\x12\x17\n\x13UNRECOGNIZED_VENDOR\x10\x00\x12\x0c\n\x06IMPINJ\x10\x9a\xca\x01\x12\t\n\x05\x41LIEN\x10\x02*\xad\x01\n\x0bReaderModel\x12\x17\n\x13UNRECOGNIZED_READER\x10\x00\x12\x11\n\rSPEEDWAY_R120\x10\x01\x12\x11\n\rSPEEDWAY_R220\x10\x02\x12\x13\n\rSPEEDWAY_R420\x10\xea\x90z\x12\x14\n\x10SPEEDWAY_XPORTAL\x10\x04\x12\x11\n\rALIEN_ALRH450\x10\x05\x12\x0e\n\nALIEN_F800\x10\x06\x12\x11\n\rALIEN_ALR9680\x10\x07\x42,\n io.opencannabis.schema.inventoryH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])

_READERVENDOR = _descriptor.EnumDescriptor(
  name='ReaderVendor',
  full_name='opencannabis.inventory.rfid.ReaderVendor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNRECOGNIZED_VENDOR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IMPINJ', index=1, number=25882,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=976,
  serialized_end=1040,
)
_sym_db.RegisterEnumDescriptor(_READERVENDOR)

ReaderVendor = enum_type_wrapper.EnumTypeWrapper(_READERVENDOR)
_READERMODEL = _descriptor.EnumDescriptor(
  name='ReaderModel',
  full_name='opencannabis.inventory.rfid.ReaderModel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNRECOGNIZED_READER', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_R120', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_R220', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_R420', index=3, number=2001002,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEEDWAY_XPORTAL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN_ALRH450', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN_F800', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALIEN_ALR9680', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1043,
  serialized_end=1216,
)
_sym_db.RegisterEnumDescriptor(_READERMODEL)

ReaderModel = enum_type_wrapper.EnumTypeWrapper(_READERMODEL)
UNRECOGNIZED_VENDOR = 0
IMPINJ = 25882
ALIEN = 2
UNRECOGNIZED_READER = 0
SPEEDWAY_R120 = 1
SPEEDWAY_R220 = 2
SPEEDWAY_R420 = 2001002
SPEEDWAY_XPORTAL = 4
ALIEN_ALRH450 = 5
ALIEN_F800 = 6
ALIEN_ALR9680 = 7



_READER = _descriptor.Descriptor(
  name='Reader',
  full_name='opencannabis.inventory.rfid.Reader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.inventory.rfid.Reader.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003K\022ICanonical label/name for the reader device involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mac', full_name='opencannabis.inventory.rfid.Reader.mac', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003A\022?MAC address of the reader device involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip', full_name='opencannabis.inventory.rfid.Reader.ip', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003@\022>IP address of the reader device involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='opencannabis.inventory.rfid.Reader.vendor', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0036\0224Vendor for the reader involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='opencannabis.inventory.rfid.Reader.model', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\0034\0222Model of the reader involved in an RFID operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=620,
)


_ANTENNA = _descriptor.Descriptor(
  name='Antenna',
  full_name='opencannabis.inventory.rfid.Antenna',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='opencannabis.inventory.rfid.Antenna.index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003:\0228Port index for the antenna that produced some operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=622,
  serialized_end=710,
)


_TAG = _descriptor.Descriptor(
  name='Tag',
  full_name='opencannabis.inventory.rfid.Tag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tid', full_name='opencannabis.inventory.rfid.Tag.tid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003K\022ITag ID, assigned to the tag at manufacturing time and never over-written.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payload', full_name='opencannabis.inventory.rfid.Tag.payload', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001\302\265\003#\022!Raw content encoded onto the tag.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epc', full_name='opencannabis.inventory.rfid.Tag.epc', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\265\003\002\020\001\302\265\003<\022:Electronic Product Code (EPC) that was present on the tag.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='content', full_name='opencannabis.inventory.rfid.Tag.content',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=713,
  serialized_end=974,
)

_READER.fields_by_name['vendor'].enum_type = _READERVENDOR
_READER.fields_by_name['model'].enum_type = _READERMODEL
_TAG.oneofs_by_name['content'].fields.append(
  _TAG.fields_by_name['epc'])
_TAG.fields_by_name['epc'].containing_oneof = _TAG.oneofs_by_name['content']
DESCRIPTOR.message_types_by_name['Reader'] = _READER
DESCRIPTOR.message_types_by_name['Antenna'] = _ANTENNA
DESCRIPTOR.message_types_by_name['Tag'] = _TAG
DESCRIPTOR.enum_types_by_name['ReaderVendor'] = _READERVENDOR
DESCRIPTOR.enum_types_by_name['ReaderModel'] = _READERMODEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Reader = _reflection.GeneratedProtocolMessageType('Reader', (_message.Message,), {
  'DESCRIPTOR' : _READER,
  '__module__' : 'opencannabis.inventory.rfid.RFID_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.Reader)
  })
_sym_db.RegisterMessage(Reader)

Antenna = _reflection.GeneratedProtocolMessageType('Antenna', (_message.Message,), {
  'DESCRIPTOR' : _ANTENNA,
  '__module__' : 'opencannabis.inventory.rfid.RFID_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.Antenna)
  })
_sym_db.RegisterMessage(Antenna)

Tag = _reflection.GeneratedProtocolMessageType('Tag', (_message.Message,), {
  'DESCRIPTOR' : _TAG,
  '__module__' : 'opencannabis.inventory.rfid.RFID_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.inventory.rfid.Tag)
  })
_sym_db.RegisterMessage(Tag)


DESCRIPTOR._options = None
_READER.fields_by_name['name']._options = None
_READER.fields_by_name['mac']._options = None
_READER.fields_by_name['ip']._options = None
_READER.fields_by_name['vendor']._options = None
_READER.fields_by_name['model']._options = None
_ANTENNA.fields_by_name['index']._options = None
_TAG.fields_by_name['tid']._options = None
_TAG.fields_by_name['payload']._options = None
_TAG.fields_by_name['epc']._options = None
# @@protoc_insertion_point(module_scope)
