# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.accounting`
  ---------------------------
  Accounting models, including taxes, GL accounts, and so on.

"""

# `opencannabis.accounting`
from .Taxes_pb2 import Taxes
