# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/Signature.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.crypto.primitives import Keys_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2
from opencannabis.crypto.primitives import Integrity_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/Signature.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.cryptoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/crypto/Signature.proto\x12\x13opencannabis.crypto\x1a)opencannabis/crypto/primitives/Keys.proto\x1a.opencannabis/crypto/primitives/Integrity.proto\"\xab\x01\n\tSignature\x12\x34\n\npublic_key\x18\x01 \x01(\x0b\x32 .opencannabis.crypto.KeyMaterial\x12.\n\x0b\x66ingerprint\x18\x02 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\x12\r\n\x03raw\x18\x05 \x01(\x0cH\x00\x12\r\n\x03\x62\x36\x34\x18\x06 \x01(\tH\x00\x12\r\n\x03hex\x18\x07 \x01(\tH\x00\x42\x0b\n\tsignatureB)\n\x1dio.opencannabis.schema.cryptoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2.DESCRIPTOR,])




_SIGNATURE = _descriptor.Descriptor(
  name='Signature',
  full_name='opencannabis.crypto.Signature',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='opencannabis.crypto.Signature.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.crypto.Signature.fingerprint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw', full_name='opencannabis.crypto.Signature.raw', index=2,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='b64', full_name='opencannabis.crypto.Signature.b64', index=3,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hex', full_name='opencannabis.crypto.Signature.hex', index=4,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='signature', full_name='opencannabis.crypto.Signature.signature',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=152,
  serialized_end=323,
)

_SIGNATURE.fields_by_name['public_key'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._KEYMATERIAL
_SIGNATURE.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['raw'])
_SIGNATURE.fields_by_name['raw'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['b64'])
_SIGNATURE.fields_by_name['b64'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
_SIGNATURE.oneofs_by_name['signature'].fields.append(
  _SIGNATURE.fields_by_name['hex'])
_SIGNATURE.fields_by_name['hex'].containing_oneof = _SIGNATURE.oneofs_by_name['signature']
DESCRIPTOR.message_types_by_name['Signature'] = _SIGNATURE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Signature = _reflection.GeneratedProtocolMessageType('Signature', (_message.Message,), {
  'DESCRIPTOR' : _SIGNATURE,
  '__module__' : 'opencannabis.crypto.Signature_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.Signature)
  })
_sym_db.RegisterMessage(Signature)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
