# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.crypto.primitives`
  -------------------------------------
  Primitive objects and definitions related to cryptography.

"""

# `opencannabis.crypto.primitives`
