# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Brand.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.content import Colors_pb2 as opencannabis_dot_content_dot_Colors__pb2
from opencannabis.content import Name_pb2 as opencannabis_dot_content_dot_Name__pb2
from opencannabis.content import Content_pb2 as opencannabis_dot_content_dot_Content__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Brand.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\014BrandContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n opencannabis/content/Brand.proto\x12\x14opencannabis.content\x1a!opencannabis/content/Colors.proto\x1a\x1fopencannabis/content/Name.proto\x1a\"opencannabis/content/Content.proto\x1a!opencannabis/media/MediaKey.proto\"y\n\rRasterGraphic\x12\x34\n\x08standard\x18\x01 \x01(\x0b\x32\".opencannabis.media.MediaReference\x12\x32\n\x06retina\x18\x02 \x01(\x0b\x32\".opencannabis.media.MediaReference\"u\n\nBrandAsset\x12\x33\n\x06raster\x18\x01 \x01(\x0b\x32#.opencannabis.content.RasterGraphic\x12\x32\n\x06vector\x18\x02 \x01(\x0b\x32\".opencannabis.media.MediaReference\"\x8d\x02\n\x05\x42rand\x12(\n\x04name\x18\x01 \x01(\x0b\x32\x1a.opencannabis.content.Name\x12+\n\x06parent\x18\x02 \x01(\x0b\x32\x1b.opencannabis.content.Brand\x12.\n\x07summary\x18\x03 \x01(\x0b\x32\x1d.opencannabis.content.Content\x12/\n\x05media\x18\x14 \x03(\x0b\x32 .opencannabis.content.BrandAsset\x12\x30\n\x05theme\x18\x15 \x01(\x0b\x32!.opencannabis.content.ColorScheme\x12\x0c\n\x04slug\x18\x16 \x01(\t\x12\x0c\n\x04link\x18\x17 \x01(\tB8\n\x1eio.opencannabis.schema.contentB\x0c\x42randContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_content_dot_Colors__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Name__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Content__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,])




_RASTERGRAPHIC = _descriptor.Descriptor(
  name='RasterGraphic',
  full_name='opencannabis.content.RasterGraphic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='standard', full_name='opencannabis.content.RasterGraphic.standard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='retina', full_name='opencannabis.content.RasterGraphic.retina', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=318,
)


_BRANDASSET = _descriptor.Descriptor(
  name='BrandAsset',
  full_name='opencannabis.content.BrandAsset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raster', full_name='opencannabis.content.BrandAsset.raster', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='opencannabis.content.BrandAsset.vector', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=437,
)


_BRAND = _descriptor.Descriptor(
  name='Brand',
  full_name='opencannabis.content.Brand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.content.Brand.name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='opencannabis.content.Brand.parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='summary', full_name='opencannabis.content.Brand.summary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.content.Brand.media', index=3,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theme', full_name='opencannabis.content.Brand.theme', index=4,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slug', full_name='opencannabis.content.Brand.slug', index=5,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='link', full_name='opencannabis.content.Brand.link', index=6,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=709,
)

_RASTERGRAPHIC.fields_by_name['standard'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_RASTERGRAPHIC.fields_by_name['retina'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_BRANDASSET.fields_by_name['raster'].message_type = _RASTERGRAPHIC
_BRANDASSET.fields_by_name['vector'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAREFERENCE
_BRAND.fields_by_name['name'].message_type = opencannabis_dot_content_dot_Name__pb2._NAME
_BRAND.fields_by_name['parent'].message_type = _BRAND
_BRAND.fields_by_name['summary'].message_type = opencannabis_dot_content_dot_Content__pb2._CONTENT
_BRAND.fields_by_name['media'].message_type = _BRANDASSET
_BRAND.fields_by_name['theme'].message_type = opencannabis_dot_content_dot_Colors__pb2._COLORSCHEME
DESCRIPTOR.message_types_by_name['RasterGraphic'] = _RASTERGRAPHIC
DESCRIPTOR.message_types_by_name['BrandAsset'] = _BRANDASSET
DESCRIPTOR.message_types_by_name['Brand'] = _BRAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RasterGraphic = _reflection.GeneratedProtocolMessageType('RasterGraphic', (_message.Message,), {
  'DESCRIPTOR' : _RASTERGRAPHIC,
  '__module__' : 'opencannabis.content.Brand_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.RasterGraphic)
  })
_sym_db.RegisterMessage(RasterGraphic)

BrandAsset = _reflection.GeneratedProtocolMessageType('BrandAsset', (_message.Message,), {
  'DESCRIPTOR' : _BRANDASSET,
  '__module__' : 'opencannabis.content.Brand_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.BrandAsset)
  })
_sym_db.RegisterMessage(BrandAsset)

Brand = _reflection.GeneratedProtocolMessageType('Brand', (_message.Message,), {
  'DESCRIPTOR' : _BRAND,
  '__module__' : 'opencannabis.content.Brand_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Brand)
  })
_sym_db.RegisterMessage(Brand)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
