# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.content`
  ---------------------------
  Models which hold structured / attribute-based and unstructured data which should be treated as content.

"""

# `opencannabis.content`
