# ~*~ coding: utf-8 ~*~

__doc__ = """

  `opencannabis.commerce.payments`
  -------------------------------------
  Models related to payments made by consumers during retail cannabis transactions.

"""

# `opencannabis.commerce.payments`
