# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaOrientation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaOrientation.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\024MediaItemOrientationH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)opencannabis/media/MediaOrientation.proto\x12\x12opencannabis.media*\x84\x01\n\x10MediaOrientation\x12\x06\n\x02UP\x10\x00\x12\x08\n\x04\x44OWN\x10\x01\x12\x08\n\x04LEFT\x10\x02\x12\t\n\x05RIGHT\x10\x03\x12\x0f\n\x0bUP_MIRRORED\x10\x04\x12\x11\n\rDOWN_MIRRORED\x10\x05\x12\x11\n\rLEFT_MIRRORED\x10\x06\x12\x12\n\x0eRIGHT_MIRRORED\x10\x07\x42>\n\x1cio.opencannabis.schema.mediaB\x14MediaItemOrientationH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)

_MEDIAORIENTATION = _descriptor.EnumDescriptor(
  name='MediaOrientation',
  full_name='opencannabis.media.MediaOrientation',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UP', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP_MIRRORED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN_MIRRORED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_MIRRORED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_MIRRORED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=66,
  serialized_end=198,
)
_sym_db.RegisterEnumDescriptor(_MEDIAORIENTATION)

MediaOrientation = enum_type_wrapper.EnumTypeWrapper(_MEDIAORIENTATION)
UP = 0
DOWN = 1
LEFT = 2
RIGHT = 3
UP_MIRRORED = 4
DOWN_MIRRORED = 5
LEFT_MIRRORED = 6
RIGHT_MIRRORED = 7


DESCRIPTOR.enum_types_by_name['MediaOrientation'] = _MEDIAORIENTATION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
