# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/crypto/Container.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from opencannabis.base import Compression_pb2 as opencannabis_dot_base_dot_Compression__pb2
from opencannabis.content import Content_pb2 as opencannabis_dot_content_dot_Content__pb2
from opencannabis.crypto.primitives import Keys_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2
from opencannabis.crypto.primitives import Integrity_pb2 as opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/crypto/Container.proto',
  package='opencannabis.crypto',
  syntax='proto3',
  serialized_options=b'\n\035io.opencannabis.schema.cryptoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#opencannabis/crypto/Container.proto\x12\x13opencannabis.crypto\x1a#opencannabis/base/Compression.proto\x1a\"opencannabis/content/Content.proto\x1a)opencannabis/crypto/primitives/Keys.proto\x1a.opencannabis/crypto/primitives/Integrity.proto\"\xb4\x01\n\rEncryptedData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\x30\n\x08\x65ncoding\x18\x02 \x01(\x0e\x32\x1e.opencannabis.content.Encoding\x12\x33\n\x0b\x63ompression\x18\x03 \x01(\x0b\x32\x1e.opencannabis.base.Compression\x12.\n\x0b\x66ingerprint\x18\x04 \x01(\x0b\x32\x19.opencannabis.crypto.Hash\"\xc1\x02\n\x12\x45ncryptedContainer\x12\x33\n\x07payload\x18\x01 \x01(\x0b\x32\".opencannabis.crypto.EncryptedData\x12,\n\x06keying\x18\x02 \x01(\x0e\x32\x1c.opencannabis.crypto.KeyType\x12\x39\n\x06vector\x18\x03 \x01(\x0b\x32).opencannabis.crypto.InitializationVector\x12:\n\x03key\x18\x04 \x01(\x0b\x32+.opencannabis.crypto.SymmetricKeyParametersH\x00\x12\x43\n\x07keypair\x18\x05 \x01(\x0b\x32\x30.opencannabis.crypto.AsymmetricKeypairParametersH\x00\x42\x0c\n\nparametersB)\n\x1dio.opencannabis.schema.cryptoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[opencannabis_dot_base_dot_Compression__pb2.DESCRIPTOR,opencannabis_dot_content_dot_Content__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2.DESCRIPTOR,opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2.DESCRIPTOR,])




_ENCRYPTEDDATA = _descriptor.Descriptor(
  name='EncryptedData',
  full_name='opencannabis.crypto.EncryptedData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='opencannabis.crypto.EncryptedData.data', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encoding', full_name='opencannabis.crypto.EncryptedData.encoding', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression', full_name='opencannabis.crypto.EncryptedData.compression', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fingerprint', full_name='opencannabis.crypto.EncryptedData.fingerprint', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=225,
  serialized_end=405,
)


_ENCRYPTEDCONTAINER = _descriptor.Descriptor(
  name='EncryptedContainer',
  full_name='opencannabis.crypto.EncryptedContainer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='payload', full_name='opencannabis.crypto.EncryptedContainer.payload', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keying', full_name='opencannabis.crypto.EncryptedContainer.keying', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vector', full_name='opencannabis.crypto.EncryptedContainer.vector', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.crypto.EncryptedContainer.key', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='keypair', full_name='opencannabis.crypto.EncryptedContainer.keypair', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='parameters', full_name='opencannabis.crypto.EncryptedContainer.parameters',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=408,
  serialized_end=729,
)

_ENCRYPTEDDATA.fields_by_name['encoding'].enum_type = opencannabis_dot_content_dot_Content__pb2._ENCODING
_ENCRYPTEDDATA.fields_by_name['compression'].message_type = opencannabis_dot_base_dot_Compression__pb2._COMPRESSION
_ENCRYPTEDDATA.fields_by_name['fingerprint'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Integrity__pb2._HASH
_ENCRYPTEDCONTAINER.fields_by_name['payload'].message_type = _ENCRYPTEDDATA
_ENCRYPTEDCONTAINER.fields_by_name['keying'].enum_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._KEYTYPE
_ENCRYPTEDCONTAINER.fields_by_name['vector'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._INITIALIZATIONVECTOR
_ENCRYPTEDCONTAINER.fields_by_name['key'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._SYMMETRICKEYPARAMETERS
_ENCRYPTEDCONTAINER.fields_by_name['keypair'].message_type = opencannabis_dot_crypto_dot_primitives_dot_Keys__pb2._ASYMMETRICKEYPAIRPARAMETERS
_ENCRYPTEDCONTAINER.oneofs_by_name['parameters'].fields.append(
  _ENCRYPTEDCONTAINER.fields_by_name['key'])
_ENCRYPTEDCONTAINER.fields_by_name['key'].containing_oneof = _ENCRYPTEDCONTAINER.oneofs_by_name['parameters']
_ENCRYPTEDCONTAINER.oneofs_by_name['parameters'].fields.append(
  _ENCRYPTEDCONTAINER.fields_by_name['keypair'])
_ENCRYPTEDCONTAINER.fields_by_name['keypair'].containing_oneof = _ENCRYPTEDCONTAINER.oneofs_by_name['parameters']
DESCRIPTOR.message_types_by_name['EncryptedData'] = _ENCRYPTEDDATA
DESCRIPTOR.message_types_by_name['EncryptedContainer'] = _ENCRYPTEDCONTAINER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncryptedData = _reflection.GeneratedProtocolMessageType('EncryptedData', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDDATA,
  '__module__' : 'opencannabis.crypto.Container_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.EncryptedData)
  })
_sym_db.RegisterMessage(EncryptedData)

EncryptedContainer = _reflection.GeneratedProtocolMessageType('EncryptedContainer', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDCONTAINER,
  '__module__' : 'opencannabis.crypto.Container_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.crypto.EncryptedContainer)
  })
_sym_db.RegisterMessage(EncryptedContainer)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
