# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/geo/Geohash.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.geo import Distance_pb2 as opencannabis_dot_geo_dot_Distance__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/geo/Geohash.proto',
  package='opencannabis.geo',
  syntax='proto3',
  serialized_options=b'\n\032io.opencannabis.schema.geoH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1eopencannabis/geo/Geohash.proto\x12\x10opencannabis.geo\x1a\x19gust/core/datamodel.proto\x1a\x1fopencannabis/geo/Distance.proto\"\x8e\x02\n\x07Geohash\x12G\n\tcomponent\x18\x01 \x03(\tB4\xc2\xb5\x03\x30\x12.Entire string, and substrings, of the geohash.\x12U\n\televation\x18\x02 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB&\xc2\xb5\x03\"\x12 Elevation of this point, if any.\x12\x63\n\x08\x61\x63\x63uracy\x18\x03 \x01(\x0b\x32\x1a.opencannabis.geo.DistanceB5\xc2\xb5\x03\x31\x12/Accuracy rating attached to this point, if any.B&\n\x1aio.opencannabis.schema.geoH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_geo_dot_Distance__pb2.DESCRIPTOR,])




_GEOHASH = _descriptor.Descriptor(
  name='Geohash',
  full_name='opencannabis.geo.Geohash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='component', full_name='opencannabis.geo.Geohash.component', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0030\022.Entire string, and substrings, of the geohash.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='elevation', full_name='opencannabis.geo.Geohash.elevation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Elevation of this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accuracy', full_name='opencannabis.geo.Geohash.accuracy', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0031\022/Accuracy rating attached to this point, if any.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=383,
)

_GEOHASH.fields_by_name['elevation'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
_GEOHASH.fields_by_name['accuracy'].message_type = opencannabis_dot_geo_dot_Distance__pb2._DISTANCE
DESCRIPTOR.message_types_by_name['Geohash'] = _GEOHASH
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Geohash = _reflection.GeneratedProtocolMessageType('Geohash', (_message.Message,), {
  'DESCRIPTOR' : _GEOHASH,
  '__module__' : 'opencannabis.geo.Geohash_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.geo.Geohash)
  })
_sym_db.RegisterMessage(Geohash)


DESCRIPTOR._options = None
_GEOHASH.fields_by_name['component']._options = None
_GEOHASH.fields_by_name['elevation']._options = None
_GEOHASH.fields_by_name['accuracy']._options = None
# @@protoc_insertion_point(module_scope)
