# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/media/MediaItem.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2
from opencannabis.media import MediaKey_pb2 as opencannabis_dot_media_dot_MediaKey__pb2
from opencannabis.media import MediaType_pb2 as opencannabis_dot_media_dot_MediaType__pb2
from opencannabis.base import ProductKey_pb2 as opencannabis_dot_base_dot_ProductKey__pb2
from opencannabis.temporal import Instant_pb2 as opencannabis_dot_temporal_dot_Instant__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/media/MediaItem.proto',
  package='opencannabis.media',
  syntax='proto3',
  serialized_options=b'\n\034io.opencannabis.schema.mediaB\rAttachedMediaH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/media/MediaItem.proto\x12\x12opencannabis.media\x1a\x19gust/core/datamodel.proto\x1a!opencannabis/media/MediaKey.proto\x1a\"opencannabis/media/MediaType.proto\x1a\"opencannabis/base/ProductKey.proto\x1a#opencannabis/temporal/Instant.proto\"\x98\x01\n\x0cMediaSubject\x12\x30\n\x07product\x18\x02 \x01(\x0b\x32\x1d.opencannabis.base.ProductKeyH\x00\x12\x11\n\x07partner\x18\x03 \x01(\tH\x00\x12\x12\n\x08location\x18\x04 \x01(\tH\x00\x12\x0f\n\x05\x62rand\x18\x05 \x01(\tH\x00\x12\x10\n\x06global\x18\x06 \x01(\x08H\x00\x42\x0c\n\nattachment\"\xa0\x08\n\x0bMediaUpload\x12\x45\n\x05token\x18\x01 \x01(\tB6\xc2\xb5\x03\x02\x08\x02\xc2\xb5\x03,J*Unique ID/token for this upload operation.\x12>\n\toperation\x18\x02 \x01(\tB+\xc2\xb5\x03\'J%Upload operation ID, assigned by GCS.\x12s\n\x05media\x18\x03 \x01(\x0b\x32\x1d.opencannabis.media.MediaItemBE\xd2\xb5\x03\x02\x08\x00\xc2\xb5\x03;J9Media item to be attached after this operation completes.\x12S\n\x04mime\x18\x04 \x01(\tBE\xc2\xb5\x03\x41J?Mimetype for the file uploaded as part of this media operation.\x12K\n\x04size\x18\x05 \x01(\x04\x42=\xc2\xb5\x03\x39J7Size, in bytes, of the item uploaded in this operation.\x12K\n\x08\x66inished\x18\x06 \x01(\x08\x42\x39\xc2\xb5\x03\x35J3Whether this upload operation has completed or not.\x12\x32\n\x03md5\x18\x07 \x01(\tB%\xc2\xb5\x03!J\x1fMD5 hash for the data uploaded.\x12\x36\n\x05\x63rc32\x18\x08 \x01(\tB\'\xc2\xb5\x03#J!CRC32 hash for the data uploaded.\x12G\n\x05owner\x18\t \x01(\tB8\xc2\xb5\x03\x34J2User account that initiated this upload operation.\x12\x37\n\x04path\x18\n \x01(\tB)\xc2\xb5\x03%J#Path in GCS to the underlying file.\x12G\n\x06parent\x18\x0b \x01(\tB7\xc2\xb5\x03\x33J1Previous upload version for this same media item.\x12l\n\x07\x63reated\x18\x14 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB;\xc2\xb5\x03\x37J5Timestamp for when this upload operation was created.\x12p\n\tcompleted\x18\x15 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB=\xc2\xb5\x03\x39J7Timestamp for when this upload operation was completed.:\x0f\x8a\xf7\x02\x0b\x08\x02\x12\x07uploads\"\x90\x08\n\tMediaItem\x12`\n\x03key\x18\x01 \x01(\x0b\x32\x1c.opencannabis.media.MediaKeyB5\xc2\xb5\x03\x02\x08\x01\xc2\xb5\x03+J)Key uniquely identifying this media item.\x12]\n\x06status\x18\x02 \x01(\x0e\x32\x1f.opencannabis.media.MediaStatusB,\xc2\xb5\x03(J&Status for this individual media item.\x12T\n\x04type\x18\x03 \x01(\x0b\x32\x1d.opencannabis.media.MediaTypeB\'\xc2\xb5\x03#J!Type of media this is describing.\x12\x31\n\x04name\x18\x04 \x01(\tB#\xc2\xb5\x03\x1fJ\x1d\x46riendly name for this media.\x12.\n\x03uri\x18\x05 \x01(\tB!\xc2\xb5\x03\x1dJ\x1b\x41\x62solute URI to this media.\x12Y\n\x0bserving_uri\x18\x06 \x01(\tBD\xc2\xb5\x03@J>Serving URI for this media, if it differs from the origin URI.\x12Z\n\x07privacy\x18\x07 \x01(\x0e\x32 .opencannabis.media.MediaPrivacyB\'\xc2\xb5\x03#J!Privacy mode for this media item.\x12\x62\n\x07\x63reated\x18\x08 \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB1\xc2\xb5\x03-J+Timestamp for when this record was created.\x12i\n\x08modified\x18\t \x01(\x0b\x32\x1e.opencannabis.temporal.InstantB7\xc2\xb5\x03\x33J1Timestamp for when this record was last modified.\x12u\n\tpublished\x18\n \x01(\x0b\x32\x1e.opencannabis.temporal.InstantBB\xc2\xb5\x03>J<Timestamp for when this media item was originally published.\x12\x39\n\x05scope\x18\x0b \x01(\tB*\xc2\xb5\x03&J$Ownership scope for this media item.\x12\x42\n\x05token\x18\x0c \x01(\tB3\xc2\xb5\x03/J-Most recent upload token for this media item.:\r\x8a\xf7\x02\t\x08\x02\x12\x05media*D\n\x0bMediaStatus\x12\x0f\n\x0bPROVISIONED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08UPLOADED\x10\x02\x12\t\n\x05READY\x10\x03*<\n\x0cMediaPrivacy\x12\x13\n\x0f\x44\x45\x46\x41ULT_PRIVACY\x10\x00\x12\x0b\n\x07PARTNER\x10\x01\x12\n\n\x06PUBLIC\x10\x02\x42\x37\n\x1cio.opencannabis.schema.mediaB\rAttachedMediaH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaKey__pb2.DESCRIPTOR,opencannabis_dot_media_dot_MediaType__pb2.DESCRIPTOR,opencannabis_dot_base_dot_ProductKey__pb2.DESCRIPTOR,opencannabis_dot_temporal_dot_Instant__pb2.DESCRIPTOR,])

_MEDIASTATUS = _descriptor.EnumDescriptor(
  name='MediaStatus',
  full_name='opencannabis.media.MediaStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROVISIONED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PENDING', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPLOADED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2486,
  serialized_end=2554,
)
_sym_db.RegisterEnumDescriptor(_MEDIASTATUS)

MediaStatus = enum_type_wrapper.EnumTypeWrapper(_MEDIASTATUS)
_MEDIAPRIVACY = _descriptor.EnumDescriptor(
  name='MediaPrivacy',
  full_name='opencannabis.media.MediaPrivacy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_PRIVACY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTNER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2556,
  serialized_end=2616,
)
_sym_db.RegisterEnumDescriptor(_MEDIAPRIVACY)

MediaPrivacy = enum_type_wrapper.EnumTypeWrapper(_MEDIAPRIVACY)
PROVISIONED = 0
PENDING = 1
UPLOADED = 2
READY = 3
DEFAULT_PRIVACY = 0
PARTNER = 1
PUBLIC = 2



_MEDIASUBJECT = _descriptor.Descriptor(
  name='MediaSubject',
  full_name='opencannabis.media.MediaSubject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='product', full_name='opencannabis.media.MediaSubject.product', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partner', full_name='opencannabis.media.MediaSubject.partner', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='location', full_name='opencannabis.media.MediaSubject.location', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brand', full_name='opencannabis.media.MediaSubject.brand', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='global', full_name='opencannabis.media.MediaSubject.global', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='attachment', full_name='opencannabis.media.MediaSubject.attachment',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=230,
  serialized_end=382,
)


_MEDIAUPLOAD = _descriptor.Descriptor(
  name='MediaUpload',
  full_name='opencannabis.media.MediaUpload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='opencannabis.media.MediaUpload.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\002\302\265\003,J*Unique ID/token for this upload operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='opencannabis.media.MediaUpload.operation', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\'J%Upload operation ID, assigned by GCS.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='media', full_name='opencannabis.media.MediaUpload.media', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\322\265\003\002\010\000\302\265\003;J9Media item to be attached after this operation completes.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mime', full_name='opencannabis.media.MediaUpload.mime', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003AJ?Mimetype for the file uploaded as part of this media operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='opencannabis.media.MediaUpload.size', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039J7Size, in bytes, of the item uploaded in this operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='finished', full_name='opencannabis.media.MediaUpload.finished', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0035J3Whether this upload operation has completed or not.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='md5', full_name='opencannabis.media.MediaUpload.md5', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003!J\037MD5 hash for the data uploaded.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc32', full_name='opencannabis.media.MediaUpload.crc32', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#J!CRC32 hash for the data uploaded.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='owner', full_name='opencannabis.media.MediaUpload.owner', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0034J2User account that initiated this upload operation.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='opencannabis.media.MediaUpload.path', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003%J#Path in GCS to the underlying file.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parent', full_name='opencannabis.media.MediaUpload.parent', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0033J1Previous upload version for this same media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.media.MediaUpload.created', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0037J5Timestamp for when this upload operation was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='completed', full_name='opencannabis.media.MediaUpload.completed', index=12,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0039J7Timestamp for when this upload operation was completed.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\013\010\002\022\007uploads',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=385,
  serialized_end=1441,
)


_MEDIAITEM = _descriptor.Descriptor(
  name='MediaItem',
  full_name='opencannabis.media.MediaItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='opencannabis.media.MediaItem.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\002\010\001\302\265\003+J)Key uniquely identifying this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='opencannabis.media.MediaItem.status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003(J&Status for this individual media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opencannabis.media.MediaItem.type', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#J!Type of media this is describing.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='opencannabis.media.MediaItem.name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\037J\035Friendly name for this media.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.media.MediaItem.uri', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\035J\033Absolute URI to this media.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serving_uri', full_name='opencannabis.media.MediaItem.serving_uri', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003@J>Serving URI for this media, if it differs from the origin URI.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='privacy', full_name='opencannabis.media.MediaItem.privacy', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003#J!Privacy mode for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created', full_name='opencannabis.media.MediaItem.created', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003-J+Timestamp for when this record was created.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modified', full_name='opencannabis.media.MediaItem.modified', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\0033J1Timestamp for when this record was last modified.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='published', full_name='opencannabis.media.MediaItem.published', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003>J<Timestamp for when this media item was originally published.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scope', full_name='opencannabis.media.MediaItem.scope', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003&J$Ownership scope for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='token', full_name='opencannabis.media.MediaItem.token', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003/J-Most recent upload token for this media item.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\212\367\002\t\010\002\022\005media',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1444,
  serialized_end=2484,
)

_MEDIASUBJECT.fields_by_name['product'].message_type = opencannabis_dot_base_dot_ProductKey__pb2._PRODUCTKEY
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['product'])
_MEDIASUBJECT.fields_by_name['product'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['partner'])
_MEDIASUBJECT.fields_by_name['partner'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['location'])
_MEDIASUBJECT.fields_by_name['location'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['brand'])
_MEDIASUBJECT.fields_by_name['brand'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIASUBJECT.oneofs_by_name['attachment'].fields.append(
  _MEDIASUBJECT.fields_by_name['global'])
_MEDIASUBJECT.fields_by_name['global'].containing_oneof = _MEDIASUBJECT.oneofs_by_name['attachment']
_MEDIAUPLOAD.fields_by_name['media'].message_type = _MEDIAITEM
_MEDIAUPLOAD.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAUPLOAD.fields_by_name['completed'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAITEM.fields_by_name['key'].message_type = opencannabis_dot_media_dot_MediaKey__pb2._MEDIAKEY
_MEDIAITEM.fields_by_name['status'].enum_type = _MEDIASTATUS
_MEDIAITEM.fields_by_name['type'].message_type = opencannabis_dot_media_dot_MediaType__pb2._MEDIATYPE
_MEDIAITEM.fields_by_name['privacy'].enum_type = _MEDIAPRIVACY
_MEDIAITEM.fields_by_name['created'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAITEM.fields_by_name['modified'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
_MEDIAITEM.fields_by_name['published'].message_type = opencannabis_dot_temporal_dot_Instant__pb2._INSTANT
DESCRIPTOR.message_types_by_name['MediaSubject'] = _MEDIASUBJECT
DESCRIPTOR.message_types_by_name['MediaUpload'] = _MEDIAUPLOAD
DESCRIPTOR.message_types_by_name['MediaItem'] = _MEDIAITEM
DESCRIPTOR.enum_types_by_name['MediaStatus'] = _MEDIASTATUS
DESCRIPTOR.enum_types_by_name['MediaPrivacy'] = _MEDIAPRIVACY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MediaSubject = _reflection.GeneratedProtocolMessageType('MediaSubject', (_message.Message,), {
  'DESCRIPTOR' : _MEDIASUBJECT,
  '__module__' : 'opencannabis.media.MediaItem_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaSubject)
  })
_sym_db.RegisterMessage(MediaSubject)

MediaUpload = _reflection.GeneratedProtocolMessageType('MediaUpload', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAUPLOAD,
  '__module__' : 'opencannabis.media.MediaItem_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaUpload)
  })
_sym_db.RegisterMessage(MediaUpload)

MediaItem = _reflection.GeneratedProtocolMessageType('MediaItem', (_message.Message,), {
  'DESCRIPTOR' : _MEDIAITEM,
  '__module__' : 'opencannabis.media.MediaItem_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.media.MediaItem)
  })
_sym_db.RegisterMessage(MediaItem)


DESCRIPTOR._options = None
_MEDIAUPLOAD.fields_by_name['token']._options = None
_MEDIAUPLOAD.fields_by_name['operation']._options = None
_MEDIAUPLOAD.fields_by_name['media']._options = None
_MEDIAUPLOAD.fields_by_name['mime']._options = None
_MEDIAUPLOAD.fields_by_name['size']._options = None
_MEDIAUPLOAD.fields_by_name['finished']._options = None
_MEDIAUPLOAD.fields_by_name['md5']._options = None
_MEDIAUPLOAD.fields_by_name['crc32']._options = None
_MEDIAUPLOAD.fields_by_name['owner']._options = None
_MEDIAUPLOAD.fields_by_name['path']._options = None
_MEDIAUPLOAD.fields_by_name['parent']._options = None
_MEDIAUPLOAD.fields_by_name['created']._options = None
_MEDIAUPLOAD.fields_by_name['completed']._options = None
_MEDIAUPLOAD._options = None
_MEDIAITEM.fields_by_name['key']._options = None
_MEDIAITEM.fields_by_name['status']._options = None
_MEDIAITEM.fields_by_name['type']._options = None
_MEDIAITEM.fields_by_name['name']._options = None
_MEDIAITEM.fields_by_name['uri']._options = None
_MEDIAITEM.fields_by_name['serving_uri']._options = None
_MEDIAITEM.fields_by_name['privacy']._options = None
_MEDIAITEM.fields_by_name['created']._options = None
_MEDIAITEM.fields_by_name['modified']._options = None
_MEDIAITEM.fields_by_name['published']._options = None
_MEDIAITEM.fields_by_name['scope']._options = None
_MEDIAITEM.fields_by_name['token']._options = None
_MEDIAITEM._options = None
# @@protoc_insertion_point(module_scope)
