# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/structs/labtesting/Terpenes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/structs/labtesting/Terpenes.proto',
  package='opencannabis.structs.labtesting',
  syntax='proto3',
  serialized_options=b'\n-io.opencannabis.schema.product.struct.testingB\020TerpeneCompoundsH\001P\001\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.opencannabis/structs/labtesting/Terpenes.proto\x12\x1fopencannabis.structs.labtesting*\xae\x05\n\x07Terpene\x12\x0c\n\x08\x43\x41MPHENE\x10\x00\x12\n\n\x06\x43\x41RENE\x10\x01\x12\x16\n\x12\x42\x45TA_CARYOPHYLLENE\x10\x02\x12\x17\n\x13\x43\x41RYOPHYLLENE_OXIDE\x10\x03\x12\x0e\n\nEUCALYPTOL\x10\x04\x12\x0b\n\x07\x46\x45NCHOL\x10\x05\x12\x12\n\x0e\x41LPHA_HUMULENE\x10\x06\x12\x0c\n\x08LIMONENE\x10\x07\x12\x0c\n\x08LINALOOL\x10\x08\x12\x0b\n\x07MYRCENE\x10\t\x12\x11\n\rALPHA_OCIMENE\x10\n\x12\x10\n\x0c\x42\x45TA_OCIMENE\x10\x0b\x12\x16\n\x12\x41LPHA_PHELLANDRENE\x10\x0c\x12\x10\n\x0c\x41LPHA_PINENE\x10\r\x12\x0f\n\x0b\x42\x45TA_PINENE\x10\x0e\x12\x13\n\x0f\x41LPHA_TERPINEOL\x10\x0f\x12\x13\n\x0f\x41LPHA_TERPININE\x10\x10\x12\x13\n\x0fGAMMA_TERPININE\x10\x11\x12\x0f\n\x0bTERPINOLENE\x10\x12\x12\r\n\tVALENCENE\x10\x13\x12\x0c\n\x08GERANIOL\x10\x14\x12\x10\n\x0cPHELLANDRENE\x10\x15\x12\x0b\n\x07\x42ORNEOL\x10\x16\x12\x0e\n\nISOBORNEOL\x10\x17\x12\r\n\tBISABOLOL\x10\x18\x12\n\n\x06PHYTOL\x10\x19\x12\x0c\n\x08SABINENE\x10\x1a\x12\x0b\n\x07\x43\x41MPHOR\x10\x1b\x12\x0b\n\x07MENTHOL\x10\x1c\x12\x0b\n\x07\x43\x45\x44RENE\x10\x1d\x12\t\n\x05NEROL\x10\x1e\x12\r\n\tNEROLIDOL\x10\x1f\x12\n\n\x06GUAIOL\x10 \x12\x0e\n\nISOPULEGOL\x10!\x12\x13\n\x0fGERANYL_ACETATE\x10\"\x12\n\n\x06\x43YMENE\x10#\x12\x0c\n\x08PULEGONE\x10$\x12\x0b\n\x07\x43INEOLE\x10%\x12\x0c\n\x08\x46\x45NCHONE\x10&\x12\r\n\tTERPINENE\x10\'\x12\x0f\n\x0b\x43ITRONELLOL\x10(\x12\x12\n\x0e\x44\x45LTA_3_CARENE\x10)BK\n-io.opencannabis.schema.product.struct.testingB\x10TerpeneCompoundsH\x01P\x01\xa2\x02\x03OCSb\x06proto3'
)

_TERPENE = _descriptor.EnumDescriptor(
  name='Terpene',
  full_name='opencannabis.structs.labtesting.Terpene',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CAMPHENE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARENE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BETA_CARYOPHYLLENE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CARYOPHYLLENE_OXIDE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EUCALYPTOL', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FENCHOL', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_HUMULENE', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LIMONENE', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINALOOL', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MYRCENE', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_OCIMENE', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BETA_OCIMENE', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_PHELLANDRENE', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_PINENE', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BETA_PINENE', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_TERPINEOL', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALPHA_TERPININE', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GAMMA_TERPININE', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERPINOLENE', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VALENCENE', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GERANIOL', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHELLANDRENE', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BORNEOL', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISOBORNEOL', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BISABOLOL', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PHYTOL', index=25, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SABINENE', index=26, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CAMPHOR', index=27, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MENTHOL', index=28, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CEDRENE', index=29, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEROL', index=30, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NEROLIDOL', index=31, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GUAIOL', index=32, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ISOPULEGOL', index=33, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GERANYL_ACETATE', index=34, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CYMENE', index=35, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PULEGONE', index=36, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CINEOLE', index=37, number=37,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FENCHONE', index=38, number=38,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TERPINENE', index=39, number=39,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITRONELLOL', index=40, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELTA_3_CARENE', index=41, number=41,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=84,
  serialized_end=770,
)
_sym_db.RegisterEnumDescriptor(_TERPENE)

Terpene = enum_type_wrapper.EnumTypeWrapper(_TERPENE)
CAMPHENE = 0
CARENE = 1
BETA_CARYOPHYLLENE = 2
CARYOPHYLLENE_OXIDE = 3
EUCALYPTOL = 4
FENCHOL = 5
ALPHA_HUMULENE = 6
LIMONENE = 7
LINALOOL = 8
MYRCENE = 9
ALPHA_OCIMENE = 10
BETA_OCIMENE = 11
ALPHA_PHELLANDRENE = 12
ALPHA_PINENE = 13
BETA_PINENE = 14
ALPHA_TERPINEOL = 15
ALPHA_TERPININE = 16
GAMMA_TERPININE = 17
TERPINOLENE = 18
VALENCENE = 19
GERANIOL = 20
PHELLANDRENE = 21
BORNEOL = 22
ISOBORNEOL = 23
BISABOLOL = 24
PHYTOL = 25
SABINENE = 26
CAMPHOR = 27
MENTHOL = 28
CEDRENE = 29
NEROL = 30
NEROLIDOL = 31
GUAIOL = 32
ISOPULEGOL = 33
GERANYL_ACETATE = 34
CYMENE = 35
PULEGONE = 36
CINEOLE = 37
FENCHONE = 38
TERPINENE = 39
CITRONELLOL = 40
DELTA_3_CARENE = 41


DESCRIPTOR.enum_types_by_name['Terpene'] = _TERPENE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
