# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/contact/Website.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gust.core import datamodel_pb2 as gust_dot_core_dot_datamodel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/contact/Website.proto',
  package='opencannabis.contact',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contactB\016ContactWebsiteH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"opencannabis/contact/Website.proto\x12\x14opencannabis.contact\x1a\x19gust/core/datamodel.proto\"\x7f\n\x07Website\x12\'\n\x03uri\x18\x01 \x01(\tB\x1a\xc2\xb5\x03\x16\x12\x14URI for the website.\x12\x35\n\x05title\x18\x02 \x01(\tB&\xc2\xb5\x03\"\x12 Title from the HTML page at URI.\x12\x14\n\x04icon\x18\x03 \x01(\x0c\x42\x06\xca\xb5\x03\x02\x10\x01\x42:\n\x1eio.opencannabis.schema.contactB\x0e\x43ontactWebsiteH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
  ,
  dependencies=[gust_dot_core_dot_datamodel__pb2.DESCRIPTOR,])




_WEBSITE = _descriptor.Descriptor(
  name='Website',
  full_name='opencannabis.contact.Website',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='uri', full_name='opencannabis.contact.Website.uri', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\026\022\024URI for the website.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='title', full_name='opencannabis.contact.Website.title', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\302\265\003\"\022 Title from the HTML page at URI.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='icon', full_name='opencannabis.contact.Website.icon', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\312\265\003\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=214,
)

DESCRIPTOR.message_types_by_name['Website'] = _WEBSITE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Website = _reflection.GeneratedProtocolMessageType('Website', (_message.Message,), {
  'DESCRIPTOR' : _WEBSITE,
  '__module__' : 'opencannabis.contact.Website_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.contact.Website)
  })
_sym_db.RegisterMessage(Website)


DESCRIPTOR._options = None
_WEBSITE.fields_by_name['uri']._options = None
_WEBSITE.fields_by_name['title']._options = None
_WEBSITE.fields_by_name['icon']._options = None
# @@protoc_insertion_point(module_scope)
