# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: opencannabis/content/Name.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='opencannabis/content/Name.proto',
  package='opencannabis.content',
  syntax='proto3',
  serialized_options=b'\n\036io.opencannabis.schema.contentB\013NameContentH\001P\000\242\002\003OCS',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fopencannabis/content/Name.proto\x12\x14opencannabis.content\"(\n\x04Name\x12\x0f\n\x07primary\x18\x01 \x01(\t\x12\x0f\n\x07\x64isplay\x18\x02 \x01(\tB7\n\x1eio.opencannabis.schema.contentB\x0bNameContentH\x01P\x00\xa2\x02\x03OCSb\x06proto3'
)




_NAME = _descriptor.Descriptor(
  name='Name',
  full_name='opencannabis.content.Name',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary', full_name='opencannabis.content.Name.primary', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='display', full_name='opencannabis.content.Name.display', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=57,
  serialized_end=97,
)

DESCRIPTOR.message_types_by_name['Name'] = _NAME
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Name = _reflection.GeneratedProtocolMessageType('Name', (_message.Message,), {
  'DESCRIPTOR' : _NAME,
  '__module__' : 'opencannabis.content.Name_pb2'
  # @@protoc_insertion_point(class_scope:opencannabis.content.Name)
  })
_sym_db.RegisterMessage(Name)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
